************************************************************************    
*
       SUBROUTINE GEN_COINC
*
C--    History
*      -------
*
C--    Purpose: to simulate random coincidences, double, triple and quad
*
C-     102195 EF created
*
************************************************************************    
*
      IMPLICIT NONE
      INCLUDE '../common.inc'

C--   Next two common blocks for (Super)Clustering and Triggers
C--   (FORTRAN sources electronics/cluster.f and triggers/gen_trig.f)

      COMMON /FCLUSTER/CC(9,60),SCC(6,10),CADC(60),CTDC(60),
     +       FIREDL(60),FIREDH(60),BFIREDL(60),BFIREDH(60),
     +       NFIREDL,NFIREDH,SFIREDL(10),SFIREDH(10),
     +       BSFIREDL(10),BSFIREDH(10),NSFIREDL,
     +       NSFIREDH,CLTHT(60),CLPHI(60),THT12,HTRIGGER(50),
     +       LTRIGGER(50),ICLUST,THT1,PHI1,TDC1,TDC2

      REAL CADC,CTDC,THT1,PHI1,THT2,THT3,THT12,CLTHT,CLPHI,
     +     TDC1,TDC2
      INTEGER CC,SCC,FIREDL,FIREDH,BFIREDL,BFIREDH,NFIREDL,
     +        NFIREDH,SFIREDL,SFIREDH,BSFIREDL,BSFIREDH,NSFIREDL,
     +        NSFIREDH,HTRIGGER,LTRIGGER,ICLUST

      REAL    XCOINC1(L101),XCOINC2(L101),XCOINC3(L101),XCOINC4(L101),
     +        AVE_N,W1EVNT,W2EVNT,W3EVNT,W4EVNT
      INTEGER N,I1,I2,ICOINC1,ICOINC2,ICOINC3,ICOINC4,
     +        IERROR1,IERROR2,IERROR3,IERROR4,NCOINC,J
      CHARACTER*15 CHROUT

C--   References: HBOOK 4.15 Manual, Chapter 3: Ntples event access
C--               Knoll, G.F.: Radiation Detection and Measurement,
C--               (Wiley, 2nd Ed., New York, 1989) pp. 120, pp. 614,
C--               about random coincidences

      IF(ICOINCID.LT.2) GOTO 9999 ! NO random coincidences required !

C--   Uses the PIBETA calorimeter response for single events stored in NTP101,
C--   and single-event arrays EDEP(240) for energy, TDEP(240) for timing

C--   Zero storage arrays
      CALL VZERO(XNTP101,L101)
      CALL VZERO(XCOINC1,L101)
      CALL VZERO(XCOINC2,L101)
      CALL VZERO(XCOINC3,L101)
      CALL VZERO(XCOINC4,L101)

C--   We will be using more efficient HGNF for NTP-event access, therefore:
      IF(IFORMAT.EQ.1) CALL HGNPAR(101,CHROUT)
C--   Get the number of events in NTP101
      CALL HNOENT(101,NCOINC)
      WRITE (6,345) NCOINC
 345  FORMAT (/,' DOING ',I10,' RANDOM COINCIDENCES',/)

C--   Beam rate (s^-1)=FBEAM, ADC gate width (ns)=WADC
C--   Average number of TRUE events in ADC gate:
      AVE_N=FBEAM*1.E-9*WADC

C--   Probability of ONE event in WADC (Poisson distribution, Knoll, p.614)
      W1EVNT=EXP(-AVE_N)
C--   Probability of TWO events in WADC
      W2EVNT=AVE_N*EXP(-AVE_N)
C--   Probability of THREE events in WADC
      W3EVNT=(AVE_N**2)*EXP(-AVE_N)/(1.*2.)
C--   Probability of FOUR events in WADC
      W4EVNT=(AVE_N**3)*EXP(-AVE_N)/(1.*2.*3.)

C--   Double coincidences:
      WRITE (6,*) 'Doing Double Coincidences...'
      N=0
      DO WHILE (N.LE.NCOINC)       ! start of DOUBLE coincidence loop
 2221   CALL RANLUX(RVEC,ILEN) ! 0 and 1 excluded
        ICOINC1=RVEC(1)*NCOINC
        CALL RANLUX(RVEC,ILEN)

C--     HGNF: Copy contents of first N101 event ICOINC1 into an array XCOINC1
        CALL HGNF(101,ICOINC1+1,XCOINC1,IERROR1)

 2222   CALL RANLUX(RVEC,ILEN)
        ICOINC2=RVEC(1)*NCOINC
        CALL HGNF(101,ICOINC2+1,XCOINC2,IERROR2)
        IF (XCOINC1(1).EQ.XCOINC2(1))GOTO 2222
        N=N+1
        IF(MOD(N,ITEST).EQ.0) WRITE(6,122) N
 122    FORMAT(' **** GEN_2COINC:  IEVENT=', I10)

C--     Reconstruct the coincident event
        DO I2=1,L101
          CALL RANLUX(RVEC,ILEN)
          XNTP101(I2)=XCOINC1(I2)+RVEC(1)*XCOINC2(I2)
          IF(I2.GE.298.AND.I2.LE.304)XNTP101(I2)=XCOINC1(I2)
          J=I2-49
          IF(J.GE.1) EDEP(J)=XNTP101(I2)
        ENDDO

C--     Redo clustering and simulate triggers
        CALL CLUSTER
        CALL GEN_TRIG

        XNTP101(1)=XCOINC1(1)+XCOINC2(1)
        XNTP101(305)=XCOINC1(305)*XCOINC2(305)
        XNTP101(306)=XCOINC1(306)*XCOINC2(306)
        XNTP101(313)=HTRIGGER(7)
        XNTP101(314)=HTRIGGER(8)
        XNTP101(315)=HTRIGGER(11)
C--     Coincidence weigth
        XNTP101(316)=W2EVNT
        XNTP101(317)=XCOINC1(317)+XCOINC2(317)
        XNTP101(318)=XCOINC1(318)+XCOINC2(318)

        XNTP101(333)=LTRIGGER(7)
        XNTP101(334)=LTRIGGER(8)
        XNTP101(335)=LTRIGGER(11)
        XNTP101(336)=TDC1
        XNTP101(337)=TDC2

C--     Fill coincidence NTP102
        IF (IFORMAT.EQ.1) THEN
          CALL HFN(102,XNTP101)   ! raw-wise
        ELSEIF (IFORMAT.EQ.2) THEN
*WL HFNT > HFNTB ??
          CALL HFNTB(102,XNTP101)  ! column-wise
        ELSE
          PAUSE
        ENDIF

      ENDDO                       ! end of DOUBLE coincidence loop 

      IF(ICOINCID.LT.3) GOTO 9999 ! ONLY DOUBLES Coincidences

C--   Triple coincidences:
      WRITE (6,*) 'Doing Triple Coincidences...'
      N=0
      DO WHILE (N.LE.NCOINC)      ! start of TRIPLE coincidence loop
 3331   CALL RANLUX(RVEC,ILEN) ! 0 and 1 excluded
        ICOINC1=RVEC(1)*NCOINC
        CALL RANLUX(RVEC,ILEN)

C--     HGNF: Copy the contents of first N101 event ICOINC1 into an array XCOINC1
        CALL HGNF(101,ICOINC1+1,XCOINC1,IERROR1)

 3333   CALL RANLUX(RVEC,ILEN)
        ICOINC2=RVEC(1)*NCOINC
        CALL HGNF(101,ICOINC2+1,XCOINC2,IERROR2)
 
 3334   CALL RANLUX(RVEC,ILEN)
        ICOINC3=RVEC(1)*NCOINC
        CALL HGNF(101,ICOINC3+1,XCOINC3,IERROR3)
        N=N+1
        IF(MOD(N,ITEST).EQ.0) WRITE(6,123) N
 123    FORMAT(' **** GEN_3COINC:  IEVENT=', I10) 

C--     Reconstruct triple coincidence event
        DO I2=1,L101
          CALL RANLUX(RVEC,ILEN)
          XNTP101(I2)=XCOINC1(I2)+RVEC(1)*XCOINC2(I2)
          CALL RANLUX(RVEC,ILEN)
          XNTP101(I2)=XNTP101(I2)+RVEC(1)*XCOINC3(I2)
          IF(I2.GE.298.AND.I2.LE.304)XNTP101(I2)=XCOINC1(I2)
          J=I2-49
          IF(J.GE.1) EDEP(J)=XNTP101(I2)
        ENDDO

C--     Redo clustering and simulate triggers
        CALL CLUSTER
        CALL GEN_TRIG

        XNTP101(1)=XCOINC1(1)+XCOINC2(1)+XCOINC3(1)
        XNTP101(305)=XCOINC1(305)*XCOINC2(305)*XCOINC3(305)
        XNTP101(306)=XCOINC1(306)*XCOINC2(306)*XCOINC3(306)
        XNTP101(313)=HTRIGGER(7)
        XNTP101(314)=HTRIGGER(8)
        XNTP101(315)=HTRIGGER(11)
C--     Coincidence weigth
        XNTP101(316)=W3EVNT
        XNTP101(317)=XCOINC1(317)+XCOINC2(317)+XCOINC3(317)
        XNTP101(318)=XCOINC1(318)+XCOINC2(318)+XCOINC3(318)

        XNTP101(333)=LTRIGGER(7)
        XNTP101(334)=LTRIGGER(8)
        XNTP101(335)=LTRIGGER(11)
        XNTP101(336)=TDC1
        XNTP101(337)=TDC2

C--     Fill coincidence NTP103
        IF (IFORMAT.EQ.1) THEN
          CALL HFN(103,XNTP101)   ! raw-wise
        ELSEIF (IFORMAT.EQ.2) THEN
*WL HFNT > HFNTB
          CALL HFNTB(103,XNTP101)  ! column-wise
        ELSE
          PAUSE
        ENDIF

      ENDDO                       ! end of TRIPLE coincidence loop 

      IF(ICOINCID.LT.4) GOTO 9999 ! ONLY TRIPLES Coincidences

C--   Quad coincidences:
      WRITE (6,*) 'Doing Quad Coincidences...'
      N=0
      DO WHILE (N.LE.NCOINC)      ! start of QUAD coincidence loop
 4441   CALL RANLUX(RVEC,ILEN) ! 0 and 1 excluded
        ICOINC1=RVEC(1)*NCOINC
        CALL RANLUX(RVEC,ILEN)

C--     HGNF: Copy the contents of first N101 event ICOINC1 into an array XCOINC1
        CALL HGNF(101,ICOINC1+1,XCOINC1,IERROR1)

 4444   CALL RANLUX(RVEC,ILEN)
        ICOINC2=RVEC(1)*NCOINC
        CALL HGNF(101,ICOINC2+1,XCOINC2,IERROR2)

 4445   CALL RANLUX(RVEC,ILEN)
        ICOINC3=RVEC(1)*NCOINC
        CALL HGNF(101,ICOINC3+1,XCOINC3,IERROR3)

 4446   CALL RANLUX(RVEC,ILEN)
        ICOINC4=RVEC(1)*NCOINC
        CALL HGNF(101,ICOINC4+1,XCOINC4,IERROR4)

        N=N+1
        IF(MOD(N,ITEST).EQ.0) WRITE(6,124) N
 124    FORMAT(' **** GEN_4COINC:  IEVENT=', I10)

C--     Reconstruct quad coincidence event
        DO I2=1,L101
          CALL RANLUX(RVEC,ILEN)
          XNTP101(I2)=XCOINC1(I2)+RVEC(1)*XCOINC2(I2)
          CALL RANLUX(RVEC,ILEN)
          XNTP101(I2)=XNTP101(I2)+RVEC(1)*XCOINC3(I2)
          CALL RANLUX(RVEC,ILEN)
          XNTP101(I2)=XNTP101(I2)+RVEC(1)*XCOINC4(I2)
          IF(I2.GE.298.AND.I2.LE.304)XNTP101(I2)=XCOINC1(I2)
          J=I2-49
          IF(J.GE.1) EDEP(J)=XNTP101(I2)
        ENDDO

C--     Redo clustering and simulate triggers
        CALL CLUSTER
        CALL GEN_TRIG

        XNTP101(1)=XCOINC1(1)+XCOINC2(1)+XCOINC3(1)+XCOINC4(1)
        XNTP101(305)=XCOINC1(305)*XCOINC2(305)*
     +               XCOINC3(305)*XCOINC4(305)
        XNTP101(306)=XCOINC1(306)*XCOINC2(306)*
     +               XCOINC3(306)*XCOINC4(306)
        XNTP101(313)=HTRIGGER(7)
        XNTP101(314)=HTRIGGER(8)
        XNTP101(315)=HTRIGGER(11)
C--     Coincident weigth
        XNTP101(316)=W4EVNT
        XNTP101(317)=XCOINC1(317)+XCOINC2(317)+
     +               XCOINC3(317)+XCOINC4(317)
        XNTP101(318)=XCOINC1(318)+XCOINC2(318)+
     +               XCOINC3(318)+XCOINC4(318)

        XNTP101(333)=LTRIGGER(7)
        XNTP101(334)=LTRIGGER(8)
        XNTP101(335)=LTRIGGER(11)
        XNTP101(336)=TDC1
        XNTP101(337)=TDC2

C--     Fill coincidence NTP104
        IF (IFORMAT.EQ.1) THEN
          CALL HFN(104,XNTP101)   ! raw-wise
        ELSEIF (IFORMAT.EQ.2) THEN
*WL HFNT > HFNTB
          CALL HFNTB(104,XNTP101)  ! column-wise
        ELSE
          PAUSE
        ENDIF

      ENDDO                         ! end of QUAD coincidence loop 

 9999 CONTINUE

      RETURN
      END   
