************************************************************************    
*
       SUBROUTINE ADC2
*
*      History
*      -------
*
*      101095 EF created
*
************************************************************************    
*
      IMPLICIT NONE

      INCLUDE '../common.inc'
      INCLUDE '../geometry/cryscommon.inc'

      REAL AMVEC(1),DESSTEP,VECTTMP(3)
      REAL VECTTM(3),NAIVECT(3)
      INTEGER NPVEC(1)

C--   No summing after ADC gate closes
      IF(1.E9*TOFG.gt.150.) RETURN

C--   Do only if we are in sensitive detector and energy is deposited
      IF (ISVOL.EQ.0.OR.DESTEP.EQ.0.) RETURN
      
C--   smeared energy step (nonuniformity+photoelectron statistics) DESSTEP
      DESSTEP=DESTEP

C--   CsI modules
      IF (NUMED.EQ.MED_CSI) THEN

      VECTTMP(1)=VECT(1)
      VECTTMP(2)=VECT(2)
      VECTTMP(3)=VECT(3)
C--   transformation to daughter coordinate system
      CALL GMTOD(VECTTMP(1),CSIVECT,1)

C--    Total energy deposited in calorimeter, MeV
*        EDEPCAL=EDEPCAL+1000.*DESTEP
C- disabled (T.F.) This was calculated in track.f       

C--     z=0 at front CsI detector face
        CSIVECT(3)=CSIVECT(3)+11.

C--     Take into account the optical nonuniformity of CsI detector response
C--     UNIFORMITY(1), and photoelectron statistics PHOTOELECTRON(1)

        AMVEC(1)=1000.*DESTEP*PHOTOELECTRON(1) ! average number of phel created
        CALL GPOISS(AMVEC,NPVEC,1)             ! Poisson number of phel created

C--     Axial nonuniformity -> z-region:[0,11]cm, 5x more nonunif [11,22]cm
        IF(UNIFORMITY(1).NE.0.) THEN      ! all crystals same
          IF (CSIVECT(3).LE.11.) THEN
            DESSTEP=( 1.+UNIFORMITY(1)*CSIVECT(3)/100. ) * DESTEP 
          ELSE
            DESSTEP=( 1.+UNIFORMITY(1)*11./100.+ 
     +      (-1.44+1.19*UNIFORMITY(1))*(CSIVECT(3)-11.)/100.) 
     +          * DESTEP
          ENDIF
         ELSE                             ! individual nonuniformities in %/cm
          IF (CSIVECT(3).LE.11.) THEN
            DESSTEP=(1.+A1T_CSI_G(IDTYPE)*CSIVECT(3)/100.)*DESTEP 
          ELSE
            DESSTEP=( 1.+A1T_CSI_G(IDTYPE)*11./100.+ 
     +      A2T_CSI_G(IDTYPE)*(CSIVECT(3)-11.)/100.) 
     +          * DESTEP
          ENDIF
         ENDIF

C--      Transverse nonuniformity
c          DESSTEP=( 1.+UNIFORMITY(2)*
c     +    (SQRT(CSIVECT(1)**2+CSIVECT(2)**2)-4.5)/(7.4*100.) ) * DESTEP 
c     +           * (AMVEC(1)-NPVEC(1))/AMVEC(1)

C--     Nonuniformity function UNIF_VAL(I,J,K)
C        DESSTEP= UNIF_VAL(
C     +  IFIX(CSIVECT(1)),IFIX(CSIVECT(2)),IFIX(CSIVECT(3))) 
C     +  * DESTEP

C-- HEX-A detector axial non-uniformity for TkOptics
C   hexa_9.rz simulation, fit with P5, comment out if using 
C   the TOMO/RASTA method (factor 0.90195/0.90593 for e70/g70)
C      IF(CSIVECT(3).GT.0.00001.and.CSIVECT(3).LE.21.99999) 
C     +  DESSTEP= 0.90195*(1./23.62)*(
C     +  28.001-1.3450*CSIVECT(3)+0.29983*CSIVECT(3)**2
C     +  -0.20535E-01*CSIVECT(3)**3+0.74061E-04*CSIVECT(3)**4
C     +  +0.15422E-04*CSIVECT(3)**5) * DESTEP
c      DESSTEP=DESTEP ! uniform detector

C-- HEXD1/2 detector axial non-uniformity for TkOptics
C   hh1d_9.rz simulation, fit with P5comment out if using 
C   the TOMO/RASTA method
C       IF(CSIVECT(3).GT.0.00001.and.CSIVECT(3).LE.21.99999) 
c     +  DESSTEP= (1./32.10)*(
c     +  31.856+0.10010*CSIVECT(3)+0.25532*CSIVECT(3)**2
c     +  -0.31715E-01*CSIVECT(3)**3+0.10267E-02*CSIVECT(3)**4
c     +  -0.66693E-05*CSIVECT(3)**5) * DESTEP

        IF (DESSTEP.LT.0.) DESSTEP=0.
        EDEP(IDTYPE)=EDEP(IDTYPE)+1000.*DESSTEP
      
      ENDIF   ! endif for sensitive CsI detectors

C--   Plastic veto staves 
      IF (IDTYPE.GE.241.AND.IDTYPE.LE.260.AND.
     +    NUMED.EQ.MED_PLASTIC)THEN
        AMVEC(1)=1000.*DESTEP*50.              ! average number of phel created
        CALL GPOISS(AMVEC,NPVEC,1)             ! Poisson number of phel created
        DESSTEP=DESTEP*(AMVEC(1)-NPVEC(1))/AMVEC(1)
        IF (DESSTEP.LT.0.) DESSTEP=0.
        EDEP(IDTYPE)=EDEP(IDTYPE)+1000.*DESTEP ! No smearing here
      ENDIF

C--   B0 Counter 
      IF (NR.EQ.4.AND.IDTYPE.EQ.500.AND.NUMED.EQ.MED_PLASTIC) THEN
        EDEP(IDTYPE)=EDEP(IDTYPE)+1000.*DESTEP
      ENDIF 

C--   Target 
      IF (IDTYPE.GE.261.AND.IDTYPE.LE.329.AND.
     +    NUMED.EQ.MED_PLASTIC) THEN
        EDEP(IDTYPE)=EDEP(IDTYPE)+1000.*DESTEP
      ENDIF        

C--   Cosmic Veto 
      IF (IDTYPE.GE.331.AND.IDTYPE.LE.335.AND.
     +    NUMED.EQ.13) THEN
        EDEP(IDTYPE)=EDEP(IDTYPE)+1000.*DESTEP
      ENDIF        

C--   Degrader 
      IF (IDTYPE.EQ.330) THEN
        EDEP(IDTYPE)=EDEP(IDTYPE)+1000.*DESTEP
      ENDIF        

C--   NaI Counters
      IF (ISWIT(1).EQ.1997) THEN
        IF (IDTYPE.GE.401.AND.IDTYPE.LE.464) THEN
c          VECTTM(1)=VECT(1)
c          VECTTM(2)=VECT(2)
c          VECTTM(3)=VECT(3)
c          CALL GMTOD(VECTTM(1),NAIVECT,1)
c          NAIVECT(3)=NAIVECT(3)+20.3
         EDEP(IDTYPE)=EDEP(IDTYPE)+1000.*DESTEP
c     +                *(1.-15.0*NAIVECT(3)/(100.*40.6))   
        ENDIF
      ENDIF

      RETURN
      END   
