************************************************************************    
*
       SUBROUTINE CLUMP
*
C--    History
*      -------
*
C--    Purpose: Clustering in PIBETA Calorimeter
*
C-     100698 EF created
*      090700 WL added weight selection
************************************************************************    
*
C--   Reference: M. J. OREGLIA, P.h. D. THESIS, STANFORD UNIVERITY, 1980

      IMPLICIT NONE
      EXTERNAL LVMAX
      INCLUDE '../common.inc'
C-- (wl) put this common block to test angular resolution.
C-- this block is filled in gen_gamma.f. T means throw,AR angular resolution
      COMMON/GEOMTMP/THT_G_T,PHI_G_T
      REAL THT_G_T,PHI_G_T,AR

*yw4f add parameter
      real anum
      parameter (anum=180.0/3.14159)
*yw4f end

      COMMON /FCLUSTER/CC(9,60),SCC(6,10),CADC(60),CTDC(60),
     +       FIREDL(60),FIREDH(60),BFIREDL(60),BFIREDH(60),
     +       NFIREDL,NFIREDH,SFIREDL(10),SFIREDH(10),
     +       BSFIREDL(10),BSFIREDH(10),NSFIREDL,
     +       NSFIREDH,CLTHT(60),CLPHI(60),THT12,HTRIGGER(50),
     +       LTRIGGER(50),ICLUST,THT1,PHI1,TDC1,TDC2
      REAL CADC,CTDC,THT1,PHI1,THT2,THT3,THT12,CLTHT,CLPHI,
     +     TDC1,TDC2
      INTEGER CC,SCC,FIREDL,FIREDH,BFIREDL,BFIREDH,NFIREDL,
     +        NFIREDH,SFIREDL,SFIREDH,BSFIREDL,BSFIREDH,NSFIREDL,
     +        NSFIREDH,HTRIGGER,LTRIGGER,ICLUST

	COMMON/CLUMPS/EDEP_CL1,EDEP_CL2,EDEP_CL3,
     +                THT_B12,THT_B13,THT_B23,
     +                SHARE12,SHARE13,SHARE23,PSQ,LAMM
     
	REAL SHARE12,SHARE13,SHARE23,PSQ,LAMM,EDEP_CL1,EDEP_CL2,
     +  EDEP_CL3,X_CL1,Y_CL1,Z_CL1,XS_CL1,YS_CL1,ZS_CL1,
     +  X_CL2,Y_CL2,Z_CL2,XS_CL2,YS_CL2,ZS_CL2,
     +  X_CL3,Y_CL3,Z_CL3,XS_CL3,YS_CL3,ZS_CL3,
     +  THT_CL1,PHI_CL1,THT_CL2,PHI_CL2,THT_CL3,PHI_CL3,
     +  THT_B12,THT_B13,THT_B23,THR_CL,
     +  EDEP_TMP0(240),EDEP_TMP1(240),EDEP_TMP2(240),EDEP_TMP3(240)    

      REAL TDEP_CL1, TDEP_CL2, TDEP_CL3  
      INTEGER N_TDC_TMP


        REAL X,Y,TH,PH,A1,A2,A3

        COMMON/IND_MCSI/I_MAX1,I_MAX2,I_MAX3
	
	INTEGER I,J,I_MAX1,I_MAX2,I_MAX3,N_HIT
        INTEGER LVMAX
        
        REAL E_OUTER

      COMMON/SUPERDEP/EDEPS(10),GA1D,GA2D,IGA1D,IGA2D,THTC
      REAL EDEPS,GA1D,GA2D,THTC
      INTEGER IGA1D,IGA2D
      REAL WEIGHT, W_NORM
      INTEGER LINEAR, POWER, LOGARITHMIC
      PARAMETER (LINEAR=1,POWER=2,LOGARITHMIC=3)

C--   Clump Thershold in MeV

        THR_CL = 0.5
        TDEP_CL1 = 0.
        TDEP_CL2 = 0.
        TDEP_CL3 = 0.
        N_TDC_TMP = 0

C--     Find Three Crystals with Maximum Energy Depositions (in Descending
C       Order) that are NOT the Nearest Neighbors (They Don't Have Common
C       Boundary); EDEP(240)-> Array Containing the Deposited Energies

C--     Temporary Single-Detector Energy Deposition Arrays

	DO I=1,240
	  EDEP_TMP0(I)=EDEP(I)
	  EDEP_TMP1(I)=EDEP(I)
	  EDEP_TMP2(I)=EDEP(I)
	  EDEP_TMP3(I)=EDEP(I)
	ENDDO

	I_MAX1=0
	I_MAX2=0
	I_MAX3=0
        N_HIT=0

	I_MAX1=LVMAX(EDEP_TMP0,240)     ! (Index of) First Crystal with Maximum Energy
	IF (EDEP(I_MAX1).LE.THR_CL) THEN   ! Below Software Threshold, 15 ADC Ch ~ 0.5 MeV
	  N_HIT=0
	  RETURN
	ENDIF

	EDEP_TMP0(I_MAX1)=0.0 ! Zero First Crystal Together with Nearest Neighbors
	DO I=1,7 
          IF (I_MAX1.GT.0.AND.I_MAX1.LE.240.AND.
     +                      NN240(I,I_MAX1).NE.0)THEN
	    EDEP_TMP0(NN240(I,I_MAX1))=0.0
	  ENDIF
      	ENDDO

	I_MAX2=LVMAX(EDEP_TMP0,240)      ! Second Crystal with Maximum Energy

	EDEP_TMP0(I_MAX2)=0.0 ! Zero Second Crystal Together with Nearest Neighbors
	DO I=1,7
          IF (I_MAX2.GT.0.AND.I_MAX2.LE.240.AND.
     +                        NN240(I,I_MAX2).NE.0)THEN
	    EDEP_TMP0(NN240(I,I_MAX2))=0.0
	  ENDIF
      	ENDDO

	I_MAX3=LVMAX(EDEP_TMP0,240)      ! Third Crystal with Maximum Energy

	IF (EDEP(I_MAX2).GT.THR_CL.AND.EDEP(I_MAX3).GE.THR_CL) THEN
           N_HIT=3
	ELSEIF(EDEP(I_MAX2).GT.THR_CL.AND.EDEP(I_MAX3).LT.THR_CL)THEN    
           N_HIT=2
        ELSE
           N_HIT=1
        ENDIF
C--     Energy Sharing Between the Cluster Central Crystals
	
        SHARE12=0.0
        SHARE13=0.0
        SHARE23=0.0

	IF (N_HIT.EQ.2) SHARE12=EDEP(I_MAX2)/(EDEP(I_MAX1)+
     +                          EDEP(I_MAX2))
	IF (N_HIT.EQ.3) SHARE13=EDEP(I_MAX3)/(EDEP(I_MAX1)+
     +                          EDEP(I_MAX3))
	IF (N_HIT.EQ.3) SHARE23=EDEP(I_MAX3)/(EDEP(I_MAX2)+
     +                          EDEP(I_MAX3))

C--     Do Two Clumps Share Nearest Neighbors?
C       Two Clumps Can Share at Most ONE Nearest Neighbor!
C       First Do Energy Sharing!

C--     1&2
	
	DO I=1,7
         IF (I_MAX1.GT.0.AND.I_MAX1.LE.240.AND.
     +                        NN240(I,I_MAX1).NE.0) THEN
	  DO J=1,7
           IF (I_MAX2.GT.0.AND.I_MAX2.LE.240.AND.
     +                        NN240(J,I_MAX2).NE.0) THEN

	    IF(NN240(I,I_MAX1).EQ.NN240(J,I_MAX2)) THEN 
              EDEP_TMP1(NN240(I,I_MAX1))=(1.-SHARE12)*
     +                                   EDEP(NN240(I,I_MAX1))
              EDEP_TMP2(NN240(J,I_MAX2))=SHARE12*
     +                                   EDEP(NN240(J,I_MAX2))
            ENDIF

           ENDIF
	  ENDDO
         ENDIF
	ENDDO

C--     1&3
	
	DO I=1,7
          IF (I_MAX1.GT.0.AND.I_MAX1.LE.240.AND.
     +                        NN240(I,I_MAX1).NE.0)THEN
	 DO J=1,7
           IF (I_MAX3.GT.0.AND.I_MAX3.LE.240.AND.
     +                        NN240(J,I_MAX3).NE.0)THEN
	    IF(NN240(I,I_MAX1).EQ.NN240(J,I_MAX3)) THEN 
              EDEP_TMP1(NN240(I,I_MAX1))=(1.-SHARE13)*
     +                                   EDEP(NN240(I,I_MAX1))
              EDEP_TMP3(NN240(J,I_MAX3))=SHARE13*
     +                                   EDEP(NN240(J,I_MAX3))
            ENDIF
           ENDIF
            ENDDO
          ENDIF
	ENDDO

C--     2&3
	
	DO I=1,7
          IF (I_MAX2.GT.0.AND.I_MAX2.LE.240.AND.
     +                        NN240(I,I_MAX2).NE.0)THEN
	 DO J=1,7
           IF (I_MAX3.GT.0.AND.I_MAX3.LE.240.AND.
     +                        NN240(J,I_MAX3).NE.0)THEN
	    IF(NN240(I,I_MAX2).EQ.NN240(J,I_MAX3)) THEN 
              EDEP_TMP2(NN240(I,I_MAX2))=(1.-SHARE23)*
     +                                   EDEP(NN240(I,I_MAX2))
              EDEP_TMP3(NN240(J,I_MAX3))=SHARE23*
     +                                   EDEP(NN240(J,I_MAX3))
            ENDIF
           ENDIF
	 ENDDO
          ENDIF
	ENDDO

C--     Clump Energy Sums, Sum over up to 8 Detectors

	IF (N_HIT.GE.1) EDEP_CL1=EDEP(I_MAX1)
	IF (N_HIT.GE.2) EDEP_CL2=EDEP(I_MAX2)
	IF (N_HIT.GE.3) EDEP_CL3=EDEP(I_MAX3)

	DO I=1,7
          IF (N_HIT.GE.1.AND.NN240(I,I_MAX1).NE.0)
     .      EDEP_CL1=EDEP_CL1+EDEP_TMP1(NN240(I,I_MAX1))
          IF (N_HIT.GE.2.AND.NN240(I,I_MAX2).NE.0)
     .      EDEP_CL2=EDEP_CL2+EDEP_TMP2(NN240(I,I_MAX2))	  
          IF (N_HIT.GE.3.AND.NN240(I,I_MAX3).NE.0)
     .      EDEP_CL3=EDEP_CL3+EDEP_TMP3(NN240(I,I_MAX3))	  
	ENDDO

C--     Directions of Clumps 1,2, and 3, Sum over up to 8 Detectors

C-------------------------------Clump 1----------------------------------
      
        WEIGHT=MAX(0., A0+LOG(EDEP(I_MAX1))-LOG(EDEP_CL1))
 	SELECT CASE(IWEIGHT)
	CASE (LINEAR)
	  WEIGHT=EDEP(I_MAX1)
        CASE (POWER)
          WEIGHT=EDEP(I_MAX1)**ALPHA
        END SELECT
	XS_CL1=WEIGHT*SIN(CSITHT(I_MAX1)/anum)
     +       *COS(CSIPHI(I_MAX1)/anum)
	YS_CL1=WEIGHT*SIN(CSITHT(I_MAX1)/anum)
     +       *SIN(CSIPHI(I_MAX1)/anum)
	ZS_CL1=WEIGHT*COS(CSITHT(I_MAX1)/anum)
        W_NORM=WEIGHT

        TDEP_CL1 = TDEP(I_MAX1)
        N_TDC_TMP=1

	DO I=1,7
         IF(NN240(I,I_MAX1) .EQ. 0) EXIT
         X_CL1=SIN(CSITHT(NN240(I,I_MAX1))/anum)*
     +         COS(CSIPHI(NN240(I,I_MAX1))/anum)
         Y_CL1=SIN(CSITHT(NN240(I,I_MAX1))/anum)*
     +         SIN(CSIPHI(NN240(I,I_MAX1))/anum)
         Z_CL1=COS(CSITHT(NN240(I,I_MAX1))/anum)

         WEIGHT=MAX(0., A0+LOG(EDEP_TMP1(NN240(I,I_MAX1)))
     +              -LOG(EDEP_CL1))
         SELECT CASE (IWEIGHT)
         CASE (LINEAR)
          WEIGHT=EDEP_TMP1(NN240(I,I_MAX1))
         CASE (POWER)
          WEIGHT=EDEP_TMP1(NN240(I,I_MAX1))**ALPHA
         END SELECT
         XS_CL1=XS_CL1+WEIGHT*X_CL1
         YS_CL1=YS_CL1+WEIGHT*Y_CL1
         ZS_CL1=ZS_CL1+WEIGHT*Z_CL1
         W_NORM=W_NORM+WEIGHT

C WL clump tdc, by averaging tdcs in each clump          
         TDEP_CL1 = TDEP_CL1+TDEP(NN240(I,I_MAX1))
         N_TDC_TMP = N_TDC_TMP+1
	ENDDO

	X_CL1=XS_CL1/W_NORM
	Y_CL1=YS_CL1/W_NORM
	Z_CL1=ZS_CL1/W_NORM
       
        TDEP_CL1=TDEP_CL1/N_TDC_TMP

	IF ((X_CL1**2+Y_CL1**2+Z_CL1**2).GT.0.) THEN
          THT_CL1=Z_CL1/SQRT(X_CL1**2+Y_CL1**2+Z_CL1**2)
	  IF (ABS(THT_CL1).LE.1.) THEN
	      THT_CL1=anum*ACOS(THT_CL1)
	  ELSEIF (THT_CL1.GT.1.) THEN
	      THT_CL1=0.
	  ELSEIF (THT_CL1.LT.-1.) THEN
              THT_CL1=180.
	  ENDIF
          IF(X_CL1.NE.0.0.AND.Y_CL1.NE.0.0)
     +       PHI_CL1=anum*ATAN2(Y_CL1,X_CL1)
          IF(PHI_CL1.LT.0.0) PHI_CL1=PHI_CL1+360.
        ENDIF

C WL testing angular resolution
          AR=anum*ACOS(SIN(THT_CL1/anum)*COS(PHI_CL1/anum)
     +       *SIN(THT_G_T/anum)*COS(PHI_G_T/anum)+SIN(THT_CL1/anum)
     +       *SIN(PHI_CL1/anum)*SIN(THT_G_T/anum)*SIN(PHI_G_T/anum)
     +       +COS(THT_CL1/anum)*COS(THT_G_T/anum))


C-------------------------------Clump 2----------------------------------

        IF (N_HIT.EQ.1) GOTO 9999 
       WEIGHT=MAX(0., A0+LOG(EDEP(I_MAX2))-LOG(EDEP_CL2))
       SELECT CASE (IWEIGHT)
       CASE (LINEAR)
        WEIGHT=EDEP(I_MAX2)
       CASE (POWER)
        WEIGHT=EDEP(I_MAX2)**ALPHA
       END SELECT
       XS_CL2=WEIGHT*SIN(CSITHT(I_MAX2)/anum)
     +        *COS(CSIPHI(I_MAX2)/anum)
       YS_CL2=WEIGHT*SIN(CSITHT(I_MAX2)/anum)
     +        *SIN(CSIPHI(I_MAX2)/anum)
       ZS_CL2=WEIGHT*COS(CSITHT(I_MAX2)/anum)
       W_NORM=WEIGHT

       TDEP_CL2=TDEP(I_MAX2)
       N_TDC_TMP=1

       DO I=1,7
        IF(NN240(I,I_MAX2) .EQ. 0) EXIT
          X_CL2=SIN(CSITHT(NN240(I,I_MAX2))/anum)*
     +          COS(CSIPHI(NN240(I,I_MAX2))/anum)
          Y_CL2=SIN(CSITHT(NN240(I,I_MAX2))/anum)*
     +          SIN(CSIPHI(NN240(I,I_MAX2))/anum)
          Z_CL2=COS(CSITHT(NN240(I,I_MAX2))/anum)

        WEIGHT=MAX(0., A0+LOG(EDEP_TMP2(NN240(I,I_MAX2)))
     +               -LOG(EDEP_CL2))
      SELECT CASE (IWEIGHT)
      CASE (LINEAR)
        WEIGHT=EDEP_TMP2(NN240(I,I_MAX2))
      CASE (POWER)
        WEIGHT=EDEP_TMP2(NN240(I,I_MAX2))**ALPHA
      END SELECT
        XS_CL2=XS_CL2+WEIGHT*X_CL2
        YS_CL2=YS_CL2+WEIGHT*Y_CL2
        ZS_CL2=ZS_CL2+WEIGHT*Z_CL2
        W_NORM=W_NORM+WEIGHT     

C clump timing
          TDEP_CL2 = TDEP_CL2+TDEP(NN240(I,I_MAX2))
          N_TDC_TMP = N_TDC_TMP+1

       ENDDO

       X_CL2=XS_CL2/EDEP_CL2
       Y_CL2=YS_CL2/EDEP_CL2
       Z_CL2=ZS_CL2/EDEP_CL2

       TDEP_CL2=TDEP_CL2/N_TDC_TMP

       IF ((X_CL2**2+Y_CL2**2+Z_CL2**2).GT.0.) THEN
         THT_CL2=Z_CL2/SQRT(X_CL2**2+Y_CL2**2+Z_CL2**2)
	  IF (ABS(THT_CL2).LE.1.) THEN
	      THT_CL2=anum*ACOS(THT_CL2)
	  ELSEIF (THT_CL2.GT.1.) THEN
	      THT_CL2=0.
	  ELSEIF (THT_CL2.LT.-1.) THEN
              THT_CL2=180.
	  ENDIF
          IF(X_CL2.NE.0.0.AND.Y_CL2.NE.0.0)
     +       PHI_CL2=anum*ATAN2(Y_CL2,X_CL2)
          IF(PHI_CL2.LT.0.0) PHI_CL2=PHI_CL2+360.
        ENDIF

C-      Find the Angle Between Clumps (1,2)

*yw4f ommit D and add anum
*        THT_B12=COSD(THT_CL1)*COSD(THT_CL2)+
*     +          SIND(THT_CL1)*SIND(THT_CL2)*COSD(PHI_CL1-PHI_CL2)

        THT_B12=COS(THT_CL1/anum)*COS(THT_CL2/anum)+
     +          SIN(THT_CL1/anum)*SIN(THT_CL2/anum)
     +          *COS((PHI_CL1-PHI_CL2)/anum)
*yw4f end

	IF (ABS(THT_B12).LE.1.) THEN
*yw4f ommit D and add anum
*	  THT_B12=ACOSD(THT_B12)
	  THT_B12=anum*ACOS(THT_B12)
*yw4f end
	ELSEIF (THT_B12.GT.1.) THEN
	  THT_B12=0.
	ELSEIF (THT_B12.LT.-1.) THEN
          THT_B12=180.
	ENDIF

C--     Clump Discriminator (1,2)

C--     Redefine Sharing Fractions

	SHARE12=EDEP_CL2/(EDEP_CL1+EDEP_CL2)

        IF(HTRIGGER(7).EQ.1)
     .   CALL HFILL(743,SHARE12,THT_B12,WT*SQME)

C--     Fill in Single Particle Discriminator Histogram
        E_OUTER=0.0
        DO I=221,240
           E_OUTER=E_OUTER+EDEP(I)
        ENDDO
        DO I=1,220
         IF(EDEP(I).GT.0.5 .AND. EDEP(I_MAX1).GT.10.0 .AND.
     +      E_OUTER.LT.1.) THEN
          X=EDEP(I)/EDEP(I_MAX1) !                  EDEP_CL1
*yw4f ommit D and add anum
*          Y=COSD(CSITHT(I))*COSD(CSITHT(I_MAX1))+SIND(CSITHT(I))*
*     +      SIND(CSITHT(I_MAX1))*COSD(CSIPHI(I)-CSIPHI(I_MAX1))

          Y=COS(CSITHT(I)/anum)*COS(CSITHT(I_MAX1)/anum)
     +        +SIN(CSITHT(I)/anum)*
     +      SIN(CSITHT(I_MAX1)/anum)*COS((CSIPHI(I)
     +        -CSIPHI(I_MAX1))/anum)
*yw4f end
  	  IF (ABS(Y).LE.1.) THEN
*yw4f ommit D and add anum
*	    Y=ACOSD(Y)
	    Y=anum*ACOS(Y)
*yw4f end
          ELSEIF (Y.GT.1.) THEN
	    Y=0.
	  ELSEIF (Y.LT.-1.) THEN
            Y=180.
	  ENDIF
C        IF (HTRIGGER(7).EQ.1)
         IF(EDEP(I_MAX1).GT.10.0 .AND. HTRIGGER(7).EQ.1 
     +    .AND. I_MAX1.LT.221)
     .     CALL HFILL(746,X,Y,WT*SQME)
         ENDIF
        ENDDO

C-------------------------------Clump 3----------------------------------

       IF (N_HIT.LE.2) GOTO 9999 
       WEIGHT=MAX(0., A0+LOG(EDEP(I_MAX3))-LOG(EDEP_CL3))
       SELECT CASE (IWEIGHT)
       CASE (LINEAR)
        WEIGHT=EDEP(I_MAX3)
       CASE (POWER)
        WEIGHT=EDEP(I_MAX3)**ALPHA
       END SELECT
       
       XS_CL3=WEIGHT*SIN(CSITHT(I_MAX3)/anum)
     +         *COS(CSIPHI(I_MAX3)/anum)
       YS_CL3=WEIGHT*SIN(CSITHT(I_MAX3)/anum)
     +         *SIN(CSIPHI(I_MAX3)/anum)
       ZS_CL3=WEIGHT*COS(CSITHT(I_MAX3)/anum)
       W_NORM=WEIGHT

       TDEP_CL3=TDEP(I_MAX3)
       N_TDC_TMP=1

	DO I=1,7
         IF(NN240(I,I_MAX3) .EQ. 0) EXIT
         X_CL3=SIN(CSITHT(NN240(I,I_MAX3))/anum)*
     +          COS(CSIPHI(NN240(I,I_MAX3))/anum)
         Y_CL3=SIN(CSITHT(NN240(I,I_MAX3))/anum)*
     +          SIN(CSIPHI(NN240(I,I_MAX3))/anum)
         Z_CL3=COS(CSITHT(NN240(I,I_MAX3))/anum)
 
         WEIGHT=MAX(0., A0+LOG(EDEP_TMP3(NN240(I,I_MAX3)))
     +               -LOG(EDEP_CL3))
         SELECT CASE (IWEIGHT)
         CASE (LINEAR)
           WEIGHT=EDEP_TMP3(NN240(I,I_MAX3))
         CASE (POWER)
           WEIGHT=EDEP_TMP3(NN240(I,I_MAX3))**ALPHA
         END SELECT
       
         XS_CL3=XS_CL3+WEIGHT*X_CL3
         YS_CL3=YS_CL3+WEIGHT*Y_CL3
         ZS_CL3=ZS_CL3+WEIGHT*Z_CL3


         TDEP_CL3 = TDEP_CL3+TDEP(NN240(I,I_MAX3))
         N_TDC_TMP = N_TDC_TMP+1

        ENDDO

	X_CL3=XS_CL3/EDEP_CL3
	Y_CL3=YS_CL3/EDEP_CL3
	Z_CL3=ZS_CL3/EDEP_CL3

        TDEP_CL3=TDEP_CL3/N_TDC_TMP

	IF ((X_CL3**2+Y_CL3**2+Z_CL3**2).GT.0.) THEN
          THT_CL3=Z_CL3/SQRT(X_CL3**2+Y_CL3**2+Z_CL3**2)
	  IF (ABS(THT_CL3).LE.1.) THEN
*yw4f ommit D and add anum
*	      THT_CL3=ACOSD(THT_CL3)
	      THT_CL3=anum*ACOS(THT_CL3)
*yw4f end
	  ELSEIF (THT_CL3.GT.1.) THEN
	      THT_CL3=0.
	  ELSEIF (THT_CL3.LT.-1.) THEN
              THT_CL3=180.
	  ENDIF
          IF(X_CL3.NE.0.0.AND.Y_CL3.NE.0.0)
*yw4f ommit D and add anum
*     +       PHI_CL3=ATAN2D(Y_CL3,X_CL3)
     +       PHI_CL3=anum*ATAN2(Y_CL3,X_CL3)
*yw4f end
          IF(PHI_CL3.LT.0.0) PHI_CL3=PHI_CL3+360.
        ENDIF

C-      Find the Angle Between Clumps (1,3 and (2,3))

*yw4f ommit D and add anum
*        THT_B13=COSD(THT_CL1)*COSD(THT_CL3)+
*     +          SIND(THT_CL1)*SIND(THT_CL3)*COSD(PHI_CL1-PHI_CL3)
*
*        THT_B23=COSD(THT_CL2)*COSD(THT_CL3)+
*     +          SIND(THT_CL2)*SIND(THT_CL3)*COSD(PHI_CL2-PHI_CL3)
        THT_B13=COS(THT_CL1/anum)*COS(THT_CL3/anum)+
     +          SIN(THT_CL1/anum)*SIN(THT_CL3/anum)
     +          *COS((PHI_CL1-PHI_CL3)/anum)

        THT_B23=COS(THT_CL2/anum)*COS(THT_CL3/anum)+
     +          SIN(THT_CL2/anum)*SIN(THT_CL3/anum)
     +          *COS((PHI_CL2-PHI_CL3)/anum)
*yw4f end

	IF (ABS(THT_B13).LE.1.) THEN
*yw4f ommit D and add anum
*	  THT_B13=ACOSD(THT_B13)
	  THT_B13=anum*ACOS(THT_B13)
*yw4f end
	ELSEIF (THT_B13.GT.1.) THEN
	  THT_B13=0.
	ELSEIF (THT_B13.LT.-1.) THEN
          THT_B13=180.
	ENDIF

	IF (ABS(THT_B23).LE.1.) THEN
*yw4f ommit D and add anum
*	  THT_B23=ACOSD(THT_B23)
	  THT_B23=anum*ACOS(THT_B23)
*yw4f end
	ELSEIF (THT_B23.GT.1.) THEN
	  THT_B23=0.
	ELSEIF (THT_B23.LT.-1.) THEN
          THT_B23=180.
	ENDIF

C--     Clump Discriminators (1,3), (2,3)

C--     Redefine Sharing Fractions

	SHARE13=EDEP_CL3/(EDEP_CL1+EDEP_CL3)
        SHARE23=EDEP_CL3/(EDEP_CL2+EDEP_CL3)
        IF(HTRIGGER(7).EQ.1)
     .   CALL HFILL(744,SHARE13,THT_B13,WT*SQME)
        IF(HTRIGGER(7).EQ.1)
     .   CALL HFILL(745,SHARE23,THT_B23,WT*SQME)

C MAGNITUDE OF MOMENTUM SUM OF THE DETECTED CLUSTERS

        PSQ=0.0
        IF (NR.EQ.8.OR.NR.EQ.14) THEN
*yw4f ommit D and add anum
*          PSQ=(EDEP_CL1*SIND(THT_CL1)*COSD(PHI_CL1)+
*     .         EDEP_CL2*SIND(THT_CL2)*COSD(PHI_CL2))**2+
*     .        (EDEP_CL1*SIND(THT_CL1)*SIND(PHI_CL1)+
*     .         EDEP_CL2*SIND(THT_CL2)*SIND(PHI_CL2))**2+
*     .        (EDEP_CL1*COSD(THT_CL1)+EDEP_CL2*COSD(THT_CL2))**2
          PSQ=(EDEP_CL1*SIN(THT_CL1/anum)*COS(PHI_CL1/anum)+
     .         EDEP_CL2*SIN(THT_CL2/anum)*COS(PHI_CL2/anum))**2+
     .        (EDEP_CL1*SIN(THT_CL1/anum)*SIN(PHI_CL1/anum)+
     .         EDEP_CL2*SIN(THT_CL2/anum)*SIN(PHI_CL2/anum))**2+
     .        (EDEP_CL1*COS(THT_CL1/anum)
     .        +EDEP_CL2*COS(THT_CL2/anum))**2
*yw4f end
          IF (PSQ.GT.0.) PSQ=SQRT(PSQ)
        ELSEIF (NR.EQ.9.OR.NR.EQ.15) THEN
*yw4f ommit D and add anum
*          PSQ=(EDEP_CL1*SIND(THT_CL1)*COSD(PHI_CL1)+
*     .         EDEP_CL2*SIND(THT_CL2)*COSD(PHI_CL2)+
*     .         EDEP_CL3*SIND(THT_CL3)*COSD(PHI_CL3) )**2+
*     .        (EDEP_CL1*SIND(THT_CL1)*SIND(PHI_CL1)+
*     .         EDEP_CL2*SIND(THT_CL2)*SIND(PHI_CL2)+
*     .         EDEP_CL3*SIND(THT_CL3)*SIND(PHI_CL3) )**2+
*     .        (EDEP_CL1*COSD(THT_CL1)+EDEP_CL2*COSD(THT_CL2)+
*     .         EDEP_CL3*COSD(THT_CL3))**2

          PSQ=(EDEP_CL1*SIN(THT_CL1/anum)*COS(PHI_CL1/anum)+
     .         EDEP_CL2*SIN(THT_CL2/anum)*COS(PHI_CL2/anum)+
     .         EDEP_CL3*SIN(THT_CL3/anum)*COS(PHI_CL3/anum))**2+
     .        (EDEP_CL1*SIN(THT_CL1/anum)*SIN(PHI_CL1/anum)+
     .         EDEP_CL2*SIN(THT_CL2/anum)*SIN(PHI_CL2/anum)+
     .         EDEP_CL3*SIN(THT_CL3/anum)*SIN(PHI_CL3/anum))**2+
     .        (EDEP_CL1*COS(THT_CL1/anum)
     .        +EDEP_CL2*COS(THT_CL2/anum)+
     .         EDEP_CL3*COS(THT_CL3/anum))**2
*yw4f end
          IF (PSQ.GT.0.) PSQ=SQRT(PSQ)
        ENDIF
C (wl) add histos 
        IF (THT_B12 .GE. 160.) THEN
         CALL HFILL(200000, THT_B12, 0., 1.)
         CALL HFILL(200001, EDEP_CL1+EDEP_CL2, 0., WT*SQME)
         CALL HFILL(200002, TDEP_CL1-TDEP_CL2, 0., WT*SQME)
         CALL HFILL(200003, THT_CL1, PHI_CL1, WT*SQME)
         CALL HFILL(200004, THT_CL1, 0., WT*SQME)
         CALL HFILL(200005, PHI_CL1, 0., WT*SQME)
        ENDIF
C angular resolutions 
        CALL HFILL(200009, AR, 0., WT*SQME)
        IF(AR .LE. 90.) CALL HFILL(200010, AR, 0.
     +                           , WT*SQME/(26.*TAN(AR/anum)))
         
C ASSOCIATE POSITRON AND PHOTON ENERGIES/ANGLES FOR PI_ENUG, PIBETA, MU_ENUNUG 
        IF(NR.EQ.8.OR.NR.EQ.11.OR.NR.EQ.14) THEN   ! angle between CL1 and positron
        GA1D=0.
        GA2D=0.
        THT12=0.
        LAMM=-0.05
        TH=PART(3,1,NR)/SQRT(PART(1,1,NR)**2+PART(2,1,NR)**2
     +                      +PART(3,1,NR)**2)
*yw4f ommit D and add anum
*        TH=ACOSD(TH)
*        PH=ATAN2D(PART(2,1,NR),PART(1,1,NR))
*        A1=ACOSD(COSD(THT_CL1)*COSD(TH)+
*     +  SIND(THT_CL1)*SIND(TH)*COSD(PHI_CL1-PH))
*        GA1D=EDEP_CL1
*        A2=ACOSD(COSD(THT_CL2)*COSD(TH)+
*     +  SIND(THT_CL2)*SIND(TH)*COSD(PHI_CL2-PH))
*        IF(A2.LT.A1) GA1D=EDEP_CL2
*        A3=ACOSD(COSD(THT_CL3)*COSD(TH)+
*     +  SIND(THT_CL3)*SIND(TH)*COSD(PHI_CL3-PH))

        TH=anum*ACOS(TH)
        PH=anum*ATAN2(PART(2,1,NR),PART(1,1,NR))
        A1=anum*ACOS(COS(THT_CL1/anum)*COS(TH/anum)+
     +  SIN(THT_CL1/anum)*SIN(TH/anum)*COS((PHI_CL1-PH)/anum))
        IF(A1.LT.18.) GA1D=EDEP_CL1
        A2=anum*ACOS(COS(THT_CL2/anum)*COS(TH/anum)+
     +  SIN(THT_CL2/anum)*SIN(TH/anum)*COS((PHI_CL2-PH)/anum))
        IF(A2.LT.A1.AND.A2.LT.18.) GA1D=EDEP_CL2
        A3=anum*ACOS(COS(THT_CL3/anum)*COS(TH/anum)+
     +  SIN(THT_CL3/anum)*SIN(TH/anum)*COS((PHI_CL3-PH)/anum))
*yw4f end
        IF((A3.LT.A1).AND.(A3.LT.A2).AND.A3.LT.18.) GA1D=EDEP_CL3

c        write(55,56) a1,a2,a3,EDEP_CL1,EDEP_CL2,EDEP_CL3,ga1d
c 56     format(7f10.3)

C Photon
        TH=PART(3,2,NR)/SQRT(PART(1,2,NR)**2+PART(2,2,NR)**2
     +                      +PART(3,2,NR)**2)
*yw4f ommit D and add anum
*        TH=ACOSD(TH)
*        PH=ATAN2D(PART(2,2,NR),PART(1,2,NR))
*        A1=ACOSD(COSD(THT_CL1)*COSD(TH)+
*     +  SIND(THT_CL1)*SIND(TH)*COSD(PHI_CL1-PH))
*        GA2D=EDEP_CL1
*        A2=ACOSD(COSD(THT_CL2)*COSD(TH)+
*     +  SIND(THT_CL2)*SIND(TH)*COSD(PHI_CL2-PH))
*        IF(A2.LT.A1) GA2D=EDEP_CL2
*        A3=ACOSD(COSD(THT_CL3)*COSD(TH)+
*     +  SIND(THT_CL3)*SIND(TH)*COSD(PHI_CL3-PH))

        TH=anum*ACOS(TH)
        PH=anum*ATAN2(PART(2,2,NR),PART(1,2,NR))
        A1=anum*ACOS(COS(THT_CL1/anum)*COS(TH/anum)+
     +  SIN(THT_CL1/anum)*SIN(TH/anum)*COS((PHI_CL1-PH)/anum))
        IF (A1.LT.18.) GA2D=EDEP_CL1
        A2=anum*ACOS(COS(THT_CL2/anum)*COS(TH/anum)+
     +  SIN(THT_CL2/anum)*SIN(TH/anum)*COS((PHI_CL2-PH)/anum))
        IF(A2.LT.A1.AND.A2.LT.18.) GA2D=EDEP_CL2
        A3=anum*ACOS(COS(THT_CL3/anum)*COS(TH/anum)+
     +  SIN(THT_CL3/anum)*SIN(TH/anum)*COS((PHI_CL3-PH)/anum))
*yw4f end
        IF((A3.LT.A1).AND.(A3.LT.A2).AND.A3.LT.18.) GA2D=EDEP_CL3
        
c        write(55,56) a1,a2,a3,EDEP_CL1,EDEP_CL2,EDEP_CL3,ga2d
c        write(55,*) ' '

c reset the cluster energies in accordance with a cut in analyzer:clump.c
c clump cut=4 MeV
        if(edep(i_max1).lt.4.) edep_cl1=0.
        if(edep(i_max2).lt.4.) edep_cl2=0.
        if(edep(i_max3).lt.4.) edep_cl3=0.

        IF((GA1D.EQ.EDEP_CL1.AND.GA2D.EQ.EDEP_CL2).OR.
     +     (GA1D.EQ.EDEP_CL2.AND.GA2D.EQ.EDEP_CL1)) THEN
           THT12=THT_B12
*yw4f ommit D and add anum
*           PSQ=(EDEP_CL1*SIND(THT_CL1)*COSD(PHI_CL1)+
*     +         EDEP_CL2*SIND(THT_CL2)*COSD(PHI_CL2))**2+
*     +        (EDEP_CL1*SIND(THT_CL1)*SIND(PHI_CL1)+
*     +         EDEP_CL2*SIND(THT_CL2)*SIND(PHI_CL2))**2+
*     +        (EDEP_CL1*COSD(THT_CL1)+EDEP_CL2*COSD(THT_CL2))**2

           PSQ=(EDEP_CL1*SIN(THT_CL1/anum)*COS(PHI_CL1/anum)+
     +         EDEP_CL2*SIN(THT_CL2/anum)*COS(PHI_CL2/anum))**2+
     +        (EDEP_CL1*SIN(THT_CL1/anum)*SIN(PHI_CL1/anum)+
     +         EDEP_CL2*SIN(THT_CL2/anum)*SIN(PHI_CL2/anum))**2+
     +        (EDEP_CL1*COS(THT_CL1/anum)
     +         +EDEP_CL2*COS(THT_CL2/anum))**2
*yw4f end
              IF (PSQ.GT.0.) PSQ=SQRT(PSQ)
        ENDIF

        IF((GA1D.EQ.EDEP_CL1.AND.GA2D.EQ.EDEP_CL3).OR.
     +     (GA1D.EQ.EDEP_CL3.AND.GA2D.EQ.EDEP_CL1)) THEN
           THT12=THT_B13
*yw4f ommit D and and anum
*           PSQ=(EDEP_CL1*SIND(THT_CL1)*COSD(PHI_CL1)+
*     +         EDEP_CL3*SIND(THT_CL3)*COSD(PHI_CL3))**2+
*     +        (EDEP_CL1*SIND(THT_CL1)*SIND(PHI_CL1)+
*     +         EDEP_CL3*SIND(THT_CL3)*SIND(PHI_CL3))**2+
*     +        (EDEP_CL1*COSD(THT_CL1)+EDEP_CL3*COSD(THT_CL3))**2

           PSQ=(EDEP_CL1*SIN(THT_CL1/anum)*COS(PHI_CL1/anum)+
     +         EDEP_CL3*SIN(THT_CL3/anum)*COS(PHI_CL3/anum))**2+
     +        (EDEP_CL1*SIN(THT_CL1/anum)*SIN(PHI_CL1/anum)+
     +         EDEP_CL3*SIN(THT_CL3/anum)*SIN(PHI_CL3/anum))**2+
     +        (EDEP_CL1*COS(THT_CL1/anum)
     +         +EDEP_CL3*COS(THT_CL3/anum))**2
*yw4f end
              IF (PSQ.GT.0.) PSQ=SQRT(PSQ)
        ENDIF

        IF((GA1D.EQ.EDEP_CL2.AND.GA2D.EQ.EDEP_CL3).OR.
     +     (GA1D.EQ.EDEP_CL3.AND.GA2D.EQ.EDEP_CL2)) THEN
           THT12=THT_B23
*yw4f ommit D and add anum
*           PSQ=(EDEP_CL2*SIND(THT_CL2)*COSD(PHI_CL2)+
*     +         EDEP_CL3*SIND(THT_CL3)*COSD(PHI_CL3))**2+
*     +        (EDEP_CL2*SIND(THT_CL2)*SIND(PHI_CL2)+
*     +         EDEP_CL3*SIND(THT_CL3)*SIND(PHI_CL3))**2+
*     +        (EDEP_CL2*COSD(THT_CL2)+EDEP_CL3*COSD(THT_CL3))**2

           PSQ=(EDEP_CL2*SIN(THT_CL2/anum)*COS(PHI_CL2/anum)+
     +         EDEP_CL3*SIN(THT_CL3/anum)*COS(PHI_CL3/anum))**2+
     +        (EDEP_CL2*SIN(THT_CL2/anum)*SIN(PHI_CL2/anum)+
     +         EDEP_CL3*SIN(THT_CL3/anum)*SIN(PHI_CL3/anum))**2+
     +        (EDEP_CL2*COS(THT_CL2/anum)
     +         +EDEP_CL3*COS(THT_CL3/anum))**2
*yw4f end
              IF (PSQ.GT.0.) PSQ=SQRT(PSQ)
        ENDIF

C measured lambda
*yw4f ommit D and add anum
*        IF(GA1D.NE.GA2D) LAMM=2.*GA1D*(SIND(THT12/2.))**2/139.57
        IF(GA1D.NE.GA2D) 
     +    LAMM=2.*GA1D*(SIN(THT12/2./anum))**2/139.57
*yw4f end
        IF(GA2D.EQ.GA1D) THEN
          GA2D=0.
          LAMM=-1.
        ENDIF

C Pibeta photon conversion
        IF(NR.EQ.11)
*yw4f ommit D and add anum
*     .  LAMM=2.*MIN(GA1D,GA2D)*(SIND(THT12/2.))**2/139.57

     .  LAMM=2.*MIN(GA1D,GA2D)*(SIN(THT12/2./anum))**2/139.57
*yw4f end

        ENDIF ! end ASSOCIATE

 9999   CONTINUE

        IF((edep_cl1.gt.edep_cl2.and.edep_cl1.lt.14.).or.
     .     (edep_cl2.gt.edep_cl1.and.edep_cl2.lt.14.).or.  
     .     (edep_cl3.gt.edep_cl2.and.edep_cl3.lt.15.)) then
        write(81,*) ltrigger(7),edep_cl1,edep_cl2,edep_cl3,idevt
        write(81,*) ' '
        endif

        RETURN
        END















