/***********************************************************/
/*                                                         */
/*           Program Placement                             */
/*                                                         */
/*           Purpose: This program calculates which channel*/
/*                    of which summer module should be     */
/*                    used for each cluster. It also       */
/*                    determines which channel of which    */
/*                    1 to 3 splitter should be used for   */
/*                    each crystal.                        */
/*                    The output is printed to the screen  */
/*                    and the file "layout.out"            */
/*                                                         */
/*      Written June 21, 1996 by DL                        */
/***********************************************************/

#include "placement.h"


float crystal_x[256],crystal_y[256];
float cluster_x[64],cluster_y[64];
short clusters[64][16];	//first index is cluster number , second index is list

void Sort(float *list,short *list_index,short num);

void main(void)
{
	FILE *file;
	short i,j,k;
	float X,Y;
	short y_ordered_clusters[64];
	short up_list[60],low_list[60];
	short y_ordered_crystals[240];
	short up_crystal[100],mid_crystal[100],low_crystal[100];

	LoadCoordinates();
	ReadClusters();

	//Find center of mass of each cluster.
	for(i=0;i<60;i++){
		X=Y=0.0;
		for(j=0;j<9;j++){
			X+=crystal_x[clusters[i][j]];
			Y+=crystal_y[clusters[i][j]];
		};
		cluster_x[i]=X/9.0;
		cluster_y[i]=Y/9.0;
	};


	file=fopen("layout.out","w");

	//sort cluster list by y-coordinates
	for(i=0;i<60;i++)y_ordered_clusters[i]=i;	//initialize
	Sort(cluster_y,y_ordered_clusters,60);

	//Find CM of all 220 trigger crystals
	X=Y=0.0;
	for(i=0;i<60;i++){
		X+=cluster_x[i];
		Y+=cluster_y[i];
	};
	printf("Total CM Coordinates: theta:%5.2f  phi:%5.2f\n",Y/60.0,X/60.0);

//	printf("cluster order:%d",y_ordered_clusters[0]);
//	for(i=1;i<60;i++)printf(",%d",y_ordered_clusters[i]);printf("\n");


	//Separate list into upper and lower halves
	// 7 Upper modules, 8 lower modules
	for(i=0;i<28;i++)up_list[i]=y_ordered_clusters[i];
	for(i=0;i<32;i++)low_list[i]=y_ordered_clusters[i+28];

//	printf("upper cluster :%d",up_list[0]);
//	for(i=1;i<28;i++)printf(",%d",up_list[i]);printf("\n");

//	printf("lower cluster :%d",low_list[0]);
//	for(i=1;i<32;i++)printf(",%d",low_list[i]);printf("\n");

	//Sort Upper list by x-coordinates
	Sort(cluster_x,up_list,28);

//	printf("upper cluster :%d",up_list[0]);
//	for(i=1;i<28;i++)printf(",%d",up_list[i]);printf("\n");

	//Sort Lower list by x-coordinates
	Sort(cluster_x,low_list,32);

//	printf("lower cluster :%d",low_list[0]);
//	for(i=1;i<32;i++)printf(",%d",low_list[i]);printf("\n");

	//Sort Upper list by y coordinates in groups of 4 
	for(i=0;i<7;i++){
		Sort(cluster_y,&up_list[i*4],4);
	};

	//Sort Lower list by y coordinates in groups of 4 
	for(i=0;i<8;i++){
		Sort(cluster_y,&low_list[i*4],4);
	};


	//Print results to screen
	printf("\nUpper bin summer modules\n");
	fprintf(file,"\nUpper bin summer modules\n");
	for(i=0;i<7;i++){
		printf("Module  #%d: %d",i,up_list[0+(6-i)*4]+1);
		for(j=1;j<4;j++)printf(", %d",up_list[j+(6-i)*4]+1); printf("\n");
		
		fprintf(file,"Module   #%d: %d",i,up_list[0+(6-i)*4]+1);
		for(j=1;j<4;j++)fprintf(file,", %d",up_list[j+(6-i)*4]+1);fprintf(file,"\n");
	};
	printf("\nLower bin summer modules\n");
	fprintf(file,"\n Lower bin summer modules\n");
	for(i=0;i<8;i++){
		printf("Module  #%d: %d",i,low_list[0+(7-i)*4]+1);
		for(j=1;j<4;j++)printf(", %d",low_list[j+(7-i)*4]+1); printf("\n");

		fprintf(file,"Module  #%d: %d",i,low_list[0+(7-i)*4]+1);
		for(j=1;j<4;j++)fprintf(file,", %d",low_list[j+(7-i)*4]+1);fprintf(file,"\n");
	};

	
	/*****************************************/
	/*	Find Splitter Order		*/
	/*****************************************/
	//Initialize
	for(i=0;i<220;i++)y_ordered_crystals[i]=i;
	Sort(crystal_y,y_ordered_crystals,220);
	
	//Sort groups of 73,74,73 by x coordinates
	Sort(crystal_x,y_ordered_crystals,73);
	Sort(crystal_x,&y_ordered_crystals[73],74);
	Sort(crystal_x,&y_ordered_crystals[73+74],73);

	//Sort groups of 4 by y-coordinate
	for(i=0;i<55;i++)Sort(crystal_y,&y_ordered_crystals[i*4],4);

	/*Print Results*/
	//Splitter #1
	printf("\nSplitter #1:\n ");
	for(j=0;j<19;j++)printf("%3d,",y_ordered_crystals[0+(18-j)*4]);printf("\n     ");
	for(j=0;j<18;j++)printf("%3d,",y_ordered_crystals[1+(17-j)*4]);printf("\n");
	fprintf(file,"\nSplitter #1:\n ");
	for(j=0;j<19;j++)fprintf(file,"%3d,",y_ordered_crystals[0+(18-j)*4]);fprintf(file,"\n     ");
	for(j=0;j<18;j++)fprintf(file,"%3d,",y_ordered_crystals[1+(17-j)*4]);fprintf(file,"\n");

	//Splitter #2
	printf("\nSplitter #2:\n     ");
	for(j=0;j<18;j++)printf("%3d,",y_ordered_crystals[2+(17-j)*4]);printf("\n     ");
	for(j=0;j<18;j++)printf("%3d,",y_ordered_crystals[3+(17-j)*4]);printf("\n");
	fprintf(file,"\nSplitter #2:\n     ");
	for(j=0;j<18;j++)fprintf(file,"%3d,",y_ordered_crystals[2+(17-j)*4]);fprintf(file,"\n     ");
	for(j=0;j<18;j++)fprintf(file,"%3d,",y_ordered_crystals[3+(17-j)*4]);fprintf(file,"\n");

	//Splitter #3
	printf("\nSplitter #3:\n ");
	for(j=0;j<19;j++)printf("%3d,",y_ordered_crystals[73+0+(18-j)*4]);printf("\n ");
	for(j=0;j<19;j++)printf("%3d,",y_ordered_crystals[73+1+(18-j)*4]);printf("\n");
	fprintf(file,"\nSplitter #3:\n ");
	for(j=0;j<19;j++)fprintf(file,"%3d,",y_ordered_crystals[73+0+(18-j)*4]);fprintf(file,"\n ");
	for(j=0;j<19;j++)fprintf(file,"%3d,",y_ordered_crystals[73+1+(18-j)*4]);fprintf(file,"\n");

	//Splitter #4
	printf("\nSplitter #4:\n     ");
	for(j=0;j<18;j++)printf("%3d,",y_ordered_crystals[73+2+(17-j)*4]);printf("\n     ");
	for(j=0;j<18;j++)printf("%3d,",y_ordered_crystals[73+3+(17-j)*4]);printf("\n");
	fprintf(file,"\nSplitter #4:\n     ");
	for(j=0;j<18;j++)fprintf(file,"%3d,",y_ordered_crystals[73+2+(17-j)*4]);fprintf(file,"\n     ");
	for(j=0;j<18;j++)fprintf(file,"%3d,",y_ordered_crystals[73+3+(17-j)*4]);fprintf(file,"\n");

	//Splitter #5
	printf("\nSplitter #5:\n ");
	for(j=0;j<19;j++)printf("%3d,",y_ordered_crystals[73+74+0+(18-j)*4]);printf("\n     ");
	for(j=0;j<18;j++)printf("%3d,",y_ordered_crystals[73+74+1+(17-j)*4]);printf("\n");
	fprintf(file,"\nSplitter #5:\n ");
	for(j=0;j<19;j++)fprintf(file,"%3d,",y_ordered_crystals[73+74+0+(18-j)*4]);fprintf(file,"\n     ");
	for(j=0;j<18;j++)fprintf(file,"%3d,",y_ordered_crystals[73+74+1+(17-j)*4]);fprintf(file,"\n");

	//Splitter #6
	printf("\nSplitter #6:\n     ");
	for(j=0;j<18;j++)printf("%3d,",y_ordered_crystals[73+74+2+(17-j)*4]);printf("\n     ");
	for(j=0;j<18;j++)printf("%3d,",y_ordered_crystals[73+74+3+(17-j)*4]);printf("\n");
	fprintf(file,"\nSplitter #6:\n     ");
	for(j=0;j<18;j++)fprintf(file,"%3d,",y_ordered_crystals[73+74+2+(17-j)*4]);fprintf(file,"\n     ");
	for(j=0;j<18;j++)fprintf(file,"%3d,",y_ordered_crystals[73+74+3+(17-j)*4]);fprintf(file,"\n");

	
      
	
	
	if(file)fclose(file);

	exit(0);
}

void Sort(float *list,short *list_index,short num)
{
	/*********************************************************/
	/* This sorts an array of indicies to another array into descending order */
	/*********************************************************/
	short i,k;

	do{
		for(i=0;i<num-1;i++){
			if(list[list_index[i]] < list[list_index[i+1]]){
				k=list_index[i+1];
				list_index[i+1]=list_index[i];
				list_index[i]=k;
				break;
			};
		};
	}while(i<num-1);


}





