************************************************************************
* 
* event.f 
* 
* Event generator 
* 
* History 
* ------- 
* 16DEC91 KAA created 
* 15AUG95 SR Combined different event generators 
* 04OCT95 EF Expanded generator list, added scaling factors 
* 19OCT95 SR Added some comments (:-) 
* 
* Contents 
* -------- 
* 
* This file contains GUKINE, the GEANT event generator. In order 
* to switch between different event generators without recom- 
* piling, following technique was implemented:
* The routine UGINIT in init.f reads in a data card for each 
* event generator. The data cards are named COSMIC, GAMMA, 
* POSITRON, PISTOP, PIMUNU etc and contain two real values.  
* The first value is the branching ratio (BR) for that event, the 
* second is the weighting (W). This values get stored in arrays 
* Wxxx where 'xxx' is the event type. The arrays are defined 
* in the common block GPARAM in common.inc.
* 
* The events are then generated according to their probability 
* BR*W. By setting all W=0 except one specific being 1, only 
* this event is generated. To combine two events in the data 
* output, several W's can be set to a nonzero value. The 
* following data cards 
* 
* GAMMA 1. 0.3 
* POSITRON 1. 0.7 
* 
* for example will produce 30% gamma events and 70% positron 
* events in the data output. The following cards 
* 
* PIMUNU 0.9998770 1.  PI > MU NU 
* PIGMUNU 1.24e-4 1.  PI > MU NU G 
* PIENU 1.23e-4 1.  PI > E NU 
* ....  
* 
* will produce all pion decays according to their branching ratio.  
*
************************************************************************
*
      SUBROUTINE GUKINE 
*   
      IMPLICIT NONE
      INCLUDE 'common.inc'
*WL   
      INCLUDE 'dtor.inc'
*   
*-----------------------------------------------------------------------
*
      REAL X         ! uniformely distr. random number [0,SUM[
      REAL SUM       ! sum of all weights, used for normalization
      REAL ACC       ! accumulated probability
      INTEGER PASSFLAG
*
      real th,ph,pl
      integer j
*-----------------------------------------------------------------------
*
 1111 ACC = 0.0
      PASSFLAG=0
      SUM = WCOSMIC(1)*WCOSMIC(2)+WGAMMA(1)*WGAMMA(2)+
     +      WPOSITRON(1)*WPOSITRON(2)+WPISTOP(1)*WPISTOP(2)+
     +      WPI_MUNU(1)*WPI_MUNU(2)+WPI_MUNUG(1)*WPI_MUNUG(2)+
     +      WPI_ENU(1)*WPI_ENU(2)+WPI_ENUG(1)*WPI_ENUG(2)+
     +      WPI_3ENU(1)*WPI_3ENU(2)+WPI_E3NU(1)*WPI_E3NU(2)+
     +      WPIBETA(1)*WPIBETA(2)+WPI_MU2ENU(1)*WPI_MU2ENU(2)+
     +      WMICHEL(1)*WMICHEL(2)+WMU_E2NUG(1)*WMU_E2NUG(2)+
     +      WMU_3E2NU(1)*WMU_3E2NU(2)+WMU_3E(1)*WMU_3E(2)+
     +      WMU_GE(1)*WMU_GE(2)+WMU_E2G(1)*WMU_E2G(2)+
     +      WMUE_GG(1)*WMUE_GG(2)+WPIMP_NG(1)*WPIMP_NG(2)+
     +      WPIMP_NGG(1)*WPIMP_NGG(2)+WPIMP_PI0N(1)*WPIMP_PI0N(2)+
     +      WPIPP_PIPPI0P(1)*WPIPP_PIPPI0P(2)+
     +      WPIPP_PIPPIPN(1)*WPIPP_PIPPIPN(2)+
     +      WPIMP_PI0PI0N(1)*WPIMP_PI0PI0N(2)+
     +      WPIMP_PIMPI0P(1)*WPIMP_PIMPI0P(2)+
     +      WPIMP_PIMPIPN(1)*WPIMP_PIMPIPN(2)
*
*     Set random number generator seed in regenerate mode
*
      IF (ISEED1.GT.0)
     +  CALL GRNDMQ(ISEED1, ISEED2, ISEQ, 'S')
*    
*     Save current random number generator seeds which will go into
*     NTP101 in order to regenerate a specific event 
*
c      CALL GRNDMQ(IACTSEED1, IACTSEED2, 0, 'G')
      IACTSEED1 = NRNDM(1)
      IACTSEED2 = NRNDM(2)
c      PRINT *, "####",IACTSEED1,IACTSEED2
*
*     Generate a random number uniformely distributed between [0,SUM]
*
      CALL RANLUX(RVEC,ILEN)
      X = RVEC(1)*SUM
      IF (X.EQ.0..OR.X.EQ.SUM) GOTO 1111
*
*     All event types get a "probability-slot" between ACC (which is
*     the accumulated probability of all previous event types) and
*     ACC + BR*W. If the random number X falls inside this slot, the
*     according generator gets called.
*
      IF (X.GE.ACC.AND.X.LE.ACC+WCOSMIC(1)*WCOSMIC(2))
     +    CALL GEN_COSMIC
      ACC = ACC + WCOSMIC(1)*WCOSMIC(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WGAMMA(1)*WGAMMA(2))
     +    CALL GEN_GAMMA
      ACC = ACC + WGAMMA(1)*WGAMMA(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPOSITRON(1)*WPOSITRON(2))
     +    CALL GEN_POSITRON
      ACC = ACC + WPOSITRON(1)*WPOSITRON(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPISTOP(1)*WPISTOP(2))
     +   CALL GEN_PISTOP
      ACC = ACC + WPISTOP(1)*WPISTOP(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPI_MUNU(1)*WPI_MUNU(2))
     +    CALL GEN_PI_MUNU
      ACC = ACC + WPI_MUNU(1)*WPI_MUNU(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPI_MUNUG(1)*WPI_MUNUG(2))
     +    CALL GEN_PI_MUNUG
      ACC = ACC + WPI_MUNUG(1)*WPI_MUNUG(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPI_ENU(1)*WPI_ENU(2))
     +    CALL GEN_PI_ENU
      ACC = ACC + WPI_ENU(1)*WPI_ENU(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPI_ENUG(1)*WPI_ENUG(2))
     +    CALL GEN_PI_ENUG
      ACC = ACC + WPI_ENUG(1)*WPI_ENUG(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPI_3ENU(1)*WPI_3ENU(2))
     +    CALL GEN_PI_ENUEE
      ACC = ACC + WPI_3ENU(1)*WPI_3ENU(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPI_E3NU(1)*WPI_E3NU(2))
     +    CALL GEN_PI_ENUNUNU
      ACC = ACC + WPI_E3NU(1)*WPI_E3NU(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPIBETA(1)*WPIBETA(2))
c     +    CALL GEN_DALITZ
c     +     CALL GEN_PI0_GGG
c     +     CALL GEN_PI02GG
     +    CALL GEN_PI_PI0ENU

      ACC = ACC + WPIBETA(1)*WPIBETA(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPI_MU2ENU(1)*WPI_MU2ENU(2))
     +    CALL GEN_PI_MUEENU
      ACC = ACC + WPI_MU2ENU(1)*WPI_MU2ENU(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WMICHEL(1)*WMICHEL(2)) 
     +    CALL GEN_MU_ENUNU
      ACC = ACC + WMICHEL(1)*WMICHEL(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WMU_E2NUG(1)*WMU_E2NUG(2))
     +    CALL GEN_MU_ENUNUG
      ACC = ACC + WMU_E2NUG(1)*WMU_E2NUG(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WMU_3E2NU(1)*WMU_3E2NU(2))
     +    CALL GEN_MU_ENUNUEE
      ACC = ACC + WMU_3E2NU(1)*WMU_3E2NU(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WMU_3E(1)*WMU_3E(2))
     +    CALL GEN_MU_EEE
      ACC = ACC + WMU_3E(1)*WMU_3E(2) 
C
      IF (X.GT.ACC.AND.X.LE.ACC+WMU_GE(1)*WMU_GE(2))
     +    CALL GEN_MU_EG
      ACC = ACC + WMU_GE(1)*WMU_GE(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WMU_E2G(1)*WMU_E2G(2))
     +    CALL GEN_MU_EGG
      ACC = ACC + WMU_E2G(1)*WMU_E2G(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WMUE_GG(1)*WMUE_GG(2))
     +    CALL GEN_MUE_GG
      ACC = ACC + WMUE_GG(1)*WMUE_GG(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPIMP_NG(1)*WPIMP_NG(2))
     +    CALL GEN_PIMP_NG
      ACC = ACC + WPIMP_NG(1)*WPIMP_NG(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPIMP_NGG(1)*WPIMP_NGG(2))
     +    CALL GEN_PIMP_NEE
      ACC = ACC + WPIMP_NGG(1)*WPIMP_NGG(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPIMP_PI0N(1)*WPIMP_PI0N(2))
     +    CALL GEN_PIMP_PI0N
      ACC = ACC + WPIMP_PI0N(1)*WPIMP_PI0N(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPIPP_PIPPI0P(1)*WPIPP_PIPPI0P(2))
     +    CALL GEN_PIPP_PI0PIPP
      ACC = ACC + WPIPP_PIPPI0P(1)*WPIPP_PIPPI0P(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPIPP_PIPPIPN(1)*WPIPP_PIPPIPN(2))
     +    CALL GEN_PIPP_PI0PIPP
      ACC = ACC + WPIPP_PIPPIPN(1)*WPIPP_PIPPIPN(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPIMP_PI0PI0N(1)*WPIMP_PI0PI0N(2))
     +    CALL GEN_PIMP_PI0PI0N
      ACC = ACC + WPIMP_PI0PI0N(1)*WPIMP_PI0PI0N(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPIMP_PIMPI0P(1)*WPIMP_PIMPI0P(2))
     +    CALL GEN_PIMP_PI0PIMP
      ACC = ACC + WPIMP_PIMPI0P(1)*WPIMP_PIMPI0P(2)
C
      IF (X.GT.ACC.AND.X.LE.ACC+WPIMP_PIMPIPN(1)*WPIMP_PIMPIPN(2))
     +    CALL GEN_PIMP_PIMPIPN
      ACC = ACC + WPIMP_PIMPIPN(1)*WPIMP_PIMPIPN(2)

C--   Keep track of maximum event weigth for normalization
      WEIGTHMAX(NR)=MAX(WEIGTHMAX(NR),WT*SQME)


C--  Addition for cluster finding (NR 8 : PI-> ENUG)
      IF (IPLANAR.EQ.5.AND.NR.EQ.8) THEN
*         print *,idevt,j,part(5,1,NR)
**         if (part(3,1,NR).lt.0) goto 1111  
         pl= part(5,1,NR)
*WL acosd -> acos atan2d -> atan2
         th=(1/dtor)*acos(part(3,1,NR)/pl)
         ph=(1/dtor)*atan2(part(2,1,nr),part(1,1,nr))
*        write(6,*) th,ph,plab(2),plab(1)
         if (ph.lt.0) ph=ph+360
         if (th.lt.34.OR.th.gt.146.) goto 1111
         if (part(5,1,NR)/part(5,2,NR).gt.10.) goto 1111
      ENDIF
C--          find more cuts in output.f

C--  For the array of 1996 there will be a cut for all those secondary particle
C--  (firstly pion decays into positrons or muons) which wouldn't reach the 
C--  calorimeter
C--      T.F.

      IF (iyear.eq.1996) THEN
       do j=5,12
        if (part(5,1,j).gt.0) THEN 
*         print *,idevt,j,part(5,1,j)      
         if (part(3,1,j).lt.0) goto 1111  
         pl= part(5,1,j)
*WL acosd -> acos atan2d -> atan2
         th=(1/dtor)*acos(part(3,1,j)/pl)
         ph=(1/dtor)*atan2(part(2,1,j),part(1,1,j))
*        write(6,*) th,ph,plab(2),plab(1)
         if (ph.lt.0) ph=ph+360
         if (th.lt.26.OR.th.gt.94.OR.ph.lt.108.OR.ph.gt.252.) goto 1111
        endif
        enddo
*        print *,j,pl,edepcal,th,part(5,1,NR)      
       endif

      END

*     To limit the file size of event.f, all event generators are
*     stored in the subdirectory '../generators/gen_xxx.f' where xxx
*     is the name of the event. These files are included in event.f
*     via the INCLUDE statement.
*
      INCLUDE 'generators/genbod.f'
      INCLUDE 'generators/boost.f'
      INCLUDE 'generators/gboost.f'
      INCLUDE 'generators/gen_cosmic.f'
      INCLUDE 'generators/gen_gamma.f'
      INCLUDE 'generators/gen_positron.f'
      INCLUDE 'generators/gen_pistop.f'
      INCLUDE 'generators/gen_pi_munu.f'  
      INCLUDE 'generators/gen_pi_munug.f'  
      INCLUDE 'generators/gen_pi_enu.f'   
      INCLUDE 'generators/gen_pi_enug.f'      
      INCLUDE 'generators/gen_pi_enuee.f'
      INCLUDE 'generators/gen_pi_enununu.f'
      INCLUDE 'generators/gen_pi_pi0enu.f'
      INCLUDE 'generators/gen_dalitz.f'
      INCLUDE 'generators/gen_pi0_ggg.f'
      INCLUDE 'generators/gen_pi_mueenu.f'
      INCLUDE 'generators/gen_mu_enunu.f'
      INCLUDE 'generators/gen_mu_enunug.f'
      INCLUDE 'generators/gen_mu_enunuee.f'
      INCLUDE 'generators/gen_mu_eee.f'
      INCLUDE 'generators/gen_mu_eg.f'
      INCLUDE 'generators/gen_mu_egg.f'      
      INCLUDE 'generators/gen_mue_gg.f'
      INCLUDE 'generators/gen_pi-p_ng.f'
      INCLUDE 'generators/gen_pi-p_nee.f'
      INCLUDE 'generators/gen_pi-p_pi0n.f'
      INCLUDE 'generators/gen_pi+p_pi0pi+p.f'
      INCLUDE 'generators/gen_pi+p_pi+pi+n.f'
      INCLUDE 'generators/gen_pi-p_pi0pi0n.f'
      INCLUDE 'generators/gen_pi-p_pi0pi-p.f'
      INCLUDE 'generators/gen_pi-p_pi-pi+n.f'
      INCLUDE 'generators/gen_pi02gg.f'















