c==============================================================================
c
c			CPIZ
c			++++
c
c	Purpose:
c	CALCULATION OF MATRIX ELEMENT FOR MU DECAY INTO E+, E-, E+, 2NU
C       WITH LAMPF ROUTINE CPIZ(XDUM) WRITTEN BY SAPIRSTINE
c	Momenta and phase space weight is supposed to be supplied via Y(6)
c	(e.g. by FOWL routine (F.James, CERN).
C       THE VARIABLES ARE:
C       Y(1) ENERGY OF PARTICLE 1 (POSITRON)
C       Y(2) ENERGY OF PARTICLE 2 (ELECTRON)
C       Y(3) ENERGY OF PARTICLE 3 (POSITRON)
C       Y(4) COSINE OF ANGLE BETWEEN POSITRON AND ELECTRON
C       Y(5) COSINE OF ANGLE BETWEEN POSITRON AND POSITRON
C       Y(6) COSINE OF ANGLE BETWEEN M2' AND M3'; M2' AND M3' ARE THE
C            MOMENTA OF PARTICLES 2 AND 3 PROJECTED ON A PLANE PERPENDICULAR
C            TO THE MOMENTA OF PARTICLE 1
C       SINCE THE PHASE SPACE WEIGHT IS ALREADY CALCULATED BY FOWL,
C       PS IS SET TO 1.0 IN FUNCTION CPIZ
c
c	Coded by:   H.Pruys (198?)
c==============================================================================
      DOUBLE PRECISION FUNCTION MATRIX_MU_ENUNUEE(ZDUM)
      IMPLICIT DOUBLE PRECISION (A-Z)
      COMMON/MUDEC/Y(6)
      ME=.0048363315D0
      R1=Y(1)
      R2=Y(2)
      R123=R1+R2+Y(3)
      R4=Y(4)
      R5=Y(5)
      R6=Y(6)
      PI=3.1415926536D0
      M=1.D0
      AL=1.D0/137.036D0
      P1=SQRT(R1**2-ME**2)
      P2=SQRT(R2**2-ME**2)
      E3=R123-R1-R2
      IF(E3.GT..5D0) GO TO 27
      IF(E3.LT.ME) GO TO 27
      P3=SQRT(E3**2-ME**2)
      PS=1.0D0
      Z1=R4
      Z2=R5
      Z3=Z1*Z2+SQRT((1.D0-Z1**2)*(1.D0-Z2**2))*R6
      A1=M**2*R1
      A2=M**2*R2
      A3=M**2*E3
      A4=M**2*(R1*R2-Z1*P1*P2)
      A5=M**2*(R1*E3-Z2*P1*P3)
      A6=M**2*(R2*E3-Z3*P2*P3)
      THETA=R123-(A4+A5+A6)-1.5*ME**2
      IF(THETA.GT..5) GO TO 27
      D12=2.*ME**2+2.*A4
      DB=2.*(ME**2+A4-A1-A2)
      DA=2.*(ME**2+A4+A5+A6)
      DC=2.*(ME**2+A6-A2-A3)
      D23=2.*(ME**2+A6)
      TEST=0.D0
      CPIZ1=0.D0
   32 STALL=0.D0
      IF (TEST.LT..1) GO TO 33
      A1=E3
      A3=R1
      A4=(R2*E3-Z3*P2*P3)
      A6=(R1*R2-Z1*P1*P2)
      D12=2.*ME**2+2.*A4
      DB=2.*(ME**2+A4-A1-A2)
      DA=2.*(ME**2+A4+A5+A6)
      DC=2.*(ME**2+A6-A2-A3)
      D23=2.*(ME**2+A6)
   33 S11=-14*ME**6*A3-11*ME**6*A2-11*ME**6*A1+8*ME**6+ME**4*
     XA6*A3+6*ME**4*A6*A2+3*ME**4*A6*A1-2*ME**4*A6+ME**4*A5*A3+3*
     XME**4*A5*A2+6*ME**4*A5*A1-2*ME**4*A5-22*ME**4*A4*A3-17*ME**4
     X*A4*A2-17*ME**4*A4*A1+12*ME**4*A4+8*ME**4*A3**2+12*ME**4*A3*
     XA2
      S11=S11+12*ME**4*A3*A1-6*ME**4*A3+4*ME**4*A2**2+8*ME**4*A2*A1
     $-3*
     XME**4*A2+4*ME**4*A1**2-3*ME**4*A1+6*ME**2*A6**2*A3+8*ME**2*
     XA6**2*A2+3*ME**2*A6**2*A1-4*ME**2*A6**2+26*ME**2*A6*A5*A3+25
     X*ME**2*A6*A5*A2+25*ME**2*A6*A5*A1-16*ME**2*A6*A5+5*ME**2*A6*
     XA4*A3
      S11=S11+9*ME**2*A6*A4*A2+4*ME**2*A6*A4*A1-4*ME**2*A6*A4-4*
     $ME**
     X2*A6*A3**2-12*ME**2*A6*A3*A2-8*ME**2*A6*A3*A1+3*ME**2*A6*A3-
     X8*ME**2*A6*A2**2-12*ME**2*A6*A2*A1+6*ME**2*A6*A2-4*ME**2*A6*
     XA1**2+3*ME**2*A6*A1+6*ME**2*A5**2*A3+3*ME**2*A5**2*A2+8*ME**
     X2*A5**2*A1-4*ME**2*A5**2
      S11=S11+5*ME**2*A5*A4*A3+4*ME**2*A5*A4*
     $A2+9
     X*ME**2*A5*A4*A1-4*ME**2*A5*A4-4*ME**2*A5*A3**2-8*ME**2*A5*A3
     X*A2-12*ME**2*A5*A3*A1+3*ME**2*A5*A3-4*ME**2*A5*A2**2-12*ME**
     X2*A5*A2*A1+3*ME**2*A5*A2-8*ME**2*A5*A1**2+6*ME**2*A5*A1-8*ME
     X**2*A4**2*A3-6*ME**2*A4**2*A2-6*ME**2*A4**2*A1
      S11=S11+4*ME**2*A
     $4**2
     X+8*ME**2*A4*A3**2+12*ME**2*A4*A3*A2+12*ME**2*A4*A3*A1-6*ME**
     X2*A4*A3+4*ME**2*A4*A2**2+8*ME**2*A4*A2*A1-3*ME**2*A4*A2+4*ME
     X**2*A4*A1**2
      S11=S11-3*ME**2*A4*A1-2*A6**3*A1+8*A6**2*A5*A3+6*A6**2
     X*A5*A2+4*A6**2*A5*A1-4*A6**2*A5+4*A6**2*A4*A3+4*A6**2*A4*A2-
     X2*A6**2*A4+4*A6**2*A3*A1+4*A6**2*A2*A1+4*A6**2*A1**2-3*A6**2
     X*A1+8*A6*A5**2*A3+4*A6*A5**2*A2+6*A6*A5**2*A1-4*A6*A5**2+16*
     XA6*A5*A4*A3
      S11=S11+12*A6*A5*A4*A2+12*A6*A5*A4*A1-8*A6*A5*A4-8*A
     $6*A5
     X*A3**2-12*A6*A5*A3*A2-12*A6*A5*A3*A1+6*A6*A5*A3-4*A6*A5*A2**
     X2-8*A6*A5*A2*A1+3*A6*A5*A2-4*A6*A5*A1**2+3*A6*A5*A1+4*A6*A4
     X**2*A3+4*A6*A4**2*A2+2*A6*A4**2*A1-2*A6*A4**2-4*A6*A4*A3**2-
     X8*A6*A4*A3*A2-4*A6*A4*A3*A1
      S11=S11+3*A6*A4*A3-4*A6*A4*A2**2-4*A
     $6*A4
     X*A2*A1+3*A6*A4*A2-2*A5**3*A2+4*A5**2*A4*A3+4*A5**2*A4*A1-2*
     XA5**2*A4+4*A5**2*A3*A2+4*A5**2*A2**2+4*A5**2*A2*A1-3*A5**2*
     XA2+4*A5*A4**2*A3+2*A5*A4**2*A2+4*A5*A4**2*A1-2*A5*A4**2-4*A5
     X*A4*A3**2-4*A5*A4*A3*A2-8*A5*A4*A3*A1
      S11=S11+3*A5*A4*A3-4*A5*A4
     $*A2*
     XA1-4*A5*A4*A1**2+3*A5*A4*A1
      S11=64*S11
      S22=-5*ME**6*A3+4*ME**6*A2+4*ME**6*A1+6*ME**6-4*ME**4*A6
     X*A3+14*ME**4*A6*A2+9*ME**4*A6*A1+11*ME**4*A6-4*ME**4*A5*A3+9
     X*ME**4*A5*A2+14*ME**4*A5*A1+11*ME**4*A5-7*ME**4*A4*A3+6*ME**
     X4*A4*A2+6*ME**4*A4*A1+10*ME**4*A4+4*ME**4*A3**2-7*ME**4*A3*
     XA2
      S22=S22-7*ME**4*A3*A1-12*ME**4*A3-4*ME**4*A2**2-12*ME**4*A2*A
     $1-2*
     XME**4*A2-4*ME**4*A1**2-2*ME**4*A1+2*ME**4+8*ME**2*A6**2*A2+4
     X*ME**2*A6**2*A1+4*ME**2*A6**2+12*ME**2*A6*A5*A2+12*ME**2*A6*
     XA5*A1+8*ME**2*A6*A5-4*ME**2*A6*A4*A3+15*ME**2*A6*A4*A2+8*ME
     X**2*A6*A4*A1
      S22=S22+17*ME**2*A6*A4-12*ME**2*A6*A3*A2-8*ME**2*A6
     $*A3*
     XA1-8*ME**2*A6*A3-8*ME**2*A6*A2**2-23*ME**2*A6*A2*A1-2*ME**2*
     XA6*A2-ME**2*A6*A1**2-3*ME**2*A6*A1+3*ME**2*A6+4*ME**2*A5**2*
     XA2+8*ME**2*A5**2*A1+4*ME**2*A5**2-4*ME**2*A5*A4*A3+8*ME**2*
     XA5*A4*A2
      S22=S22+15*ME**2*A5*A4*A1+17*ME**2*A5*A4-8*ME**2*A5*A3*
     $A2-
     X12*ME**2*A5*A3*A1-8*ME**2*A5*A3-ME**2*A5*A2**2-23*ME**2*A5*
     XA2*A1-3*ME**2*A5*A2-8*ME**2*A5*A1**2-2*ME**2*A5*A1+3*ME**2*
     XA5-2*ME**2*A4**2*A3+2*ME**2*A4**2*A2+2*ME**2*A4**2*A1+4*ME**
     X2*A4**2
      S22=S22+4*ME**2*A4*A3**2-11*ME**2*A4*A3*A2-11*ME**2*A4*A
     $3*A1
     X-18*ME**2*A4*A3-2*ME**2*A4*A2**2-8*ME**2*A4*A2*A1-2*ME**2*A4
     X*A2-2*ME**2*A4*A1**2-2*ME**2*A4*A1+2*ME**2*A4+4*ME**2*A3**2*
     XA2
      S22=S22+4*ME**2*A3**2*A1+4*ME**2*A3**2+6*ME**2*A3*A2**
     X2+26*ME**2*A3*A2*A1+3*ME**2*A3*A2+6*ME**2*A3*A1**2+3*ME**2*
     XA3*A1-3*ME**2*A3+4*ME**2*A2**2*A1+4*ME**2*A2*A1**2-4*ME**2*
     XA2*A1+4*A6**2*A4*A2+4*A6**2*A4-4*A6**2*A2*A1+4*A6**2*A1**2+4
     X*A6*A5*A4*A2
      S22=S22+4*A6*A5*A4*A1+8*A6*A5*A4+4*A6*A5*A2**2-8*A6
     $*A5*
     XA2*A1+4*A6*A5*A1**2+4*A6*A4**2*A2+2*A6*A4**2*A1+6*A6*A4**2-8
     X*A6*A4*A3*A2-4*A6*A4*A3*A1-8*A6*A4*A3-4*A6*A4*A2**2-12*A6*A4
     X*A2*A1-3*A6*A4*A2-4*A6*A4*A1+3*A6*A4+12*A6*A3*A2*A1-4*A6*A3*
     XA1**2
      S22=S22+6*A6*A2**2*A1+4*A6*A2*A1**2-5*A6*A2*A1-2*A6*A1**3+
     $A6*
     XA1**2+4*A5**2*A4*A1+4*A5**2*A4+4*A5**2*A2**2-4*A5**2*A2*A1+2
     X*A5*A4**2*A2+4*A5*A4**2*A1+6*A5*A4**2-4*A5*A4*A3*A2-8*A5*A4*
     XA3*A1-8*A5*A4*A3-12*A5*A4*A2*A1-4*A5*A4*A2-4*A5*A4*A1**2-3*
     XA5*A4*A1
      S22=S22+3*A5*A4-4*A5*A3*A2**2+12*A5*A3*A2*A1-2*A5*A2**3
     $+4*
     XA5*A2**2*A1+A5*A2**2+6*A5*A2*A1**2-5*A5*A2*A1-4*A4**2*A3*A2-
     X4*A4**2*A3*A1-6*A4**2*A3+4*A4*A3**2*A2+4*A4*A3**2*A1+4*A4*A3
     X**2+4*A4*A3*A2**2+16*A4*A3*A2*A1+3*A4*A3*A2+4*A4*A3*A1**2+3*
     XA4*A3*A1
      S22=S22-3*A4*A3-8*A3**2*A2*A1-8*A3*A2**2*A1-8*A3*A2*A1*
     $*2+6
     X*A3*A2*A1
      S22=64*S22
      S1221=20*ME**6*A3-7*ME**6*A2-7*ME**6*A1+4*ME**6+19*ME**4*
     XA6*A3-4*ME**4*A6*A2-12*ME**4*A6*A1+5*ME**4*A6+19*ME**4*A5*A3
     X-12*ME**4*A5*A2-4*ME**4*A5*A1+5*ME**4*A5+46*ME**4*A4*A3-11*
     XME**4*A4*A2-11*ME**4*A4*A1+4*ME**4*A4-30*ME**4*A3**2-17*ME**
     X4*A3*A2-17*ME**4*A3*A1
      S1221=S1221+12*ME**4*A3+4*ME**4*A2*A1-ME*
     $*4*A2-ME
     X**4*A1+4*ME**2*A6**2*A3-11*ME**2*A6**2*A1+8*ME**2*A6*A5*A3+3
     X*ME**2*A6*A5*A2+3*ME**2*A6*A5*A1+4*ME**2*A6*A5+31*ME**2*A6*
     XA4*A3-4*ME**2*A6*A4*A2-16*ME**2*A6*A4*A1+9*ME**2*A6*A4-12*ME
     X**2*A6*A3**2-4*ME**2*A6*A3*A2
      S1221=S1221+10*ME**2*A6*A3*A1+ME**
     $2*A6*A3+
     X3*ME**2*A6*A2*A1-4*ME**2*A6*A2+13*ME**2*A6*A1**2-12*ME**2*A6
     X*A1+3*ME**2*A6+4*ME**2*A5**2*A3-11*ME**2*A5**2*A2+31*ME**2*
     XA5*A4*A3-16*ME**2*A5*A4*A2-4*ME**2*A5*A4*A1+9*ME**2*A5*A4-12
     X*ME**2*A5*A3**2
      S1221=S1221+10*ME**2*A5*A3*A2-4*ME**2*A5*A3*A1+M
     $E**2*A5*
     XA3+13*ME**2*A5*A2**2+3*ME**2*A5*A2*A1-12*ME**2*A5*A2-4*ME**2
     X*A5*A1+3*ME**2*A5+34*ME**2*A4**2*A3-4*ME**2*A4**2*A2-4*ME**2
     X*A4**2*A1-46*ME**2*A4*A3**2-29*ME**2*A4*A3*A2-29*ME**2*A4*A3
     X*A1
      S1221=S1221+18*ME**2*A4*A3+2*ME**2*A4*A2**2+8*ME**2*A4*A2*A1
     $-ME**2*
     XA4*A2+2*ME**2*A4*A1**2-ME**2*A4*A1+8*ME**2*A3**3+12*ME**2*A3
     X**2*A2+12*ME**2*A3**2*A1-6*ME**2*A3**2+4*ME**2*A3*A2**2+8*ME
     X**2*A3*A2*A1
      S1221=S1221-3*ME**2*A3*A2
      S1221=S1221+4*ME**2*A3*A1**2-3*ME**2*A
     $3*A1-4
     X*A6**3*A1+4*A6**2*A5*A2+4*A6**2*A4*A3-8*A6**2*A4*A1+2*A6**2*
     XA4+12*A6**2*A3*A1+4*A6**2*A2*A1+12*A6**2*A1**2-5*A6**2*A1+4*
     XA6*A5**2*A1+8*A6*A5*A4*A3+8*A6*A5*A4+4*A6*A5*A3*A2+4*A6*A5*
     XA3*A1
      S1221=S1221+4*A6*A5*A2**2-8*A6*A5*A2*A1-3*A6*A5*A2+4*A6*A5
     $*A1**2-3
     X*A6*A5*A1+12*A6*A4**2*A3-4*A6*A4**2*A1+4*A6*A4**2-12*A6*A4*
     XA3**2-8*A6*A4*A3*A2+A6*A4*A3-4*A6*A4*A2+8*A6*A4*A1**2-8*A6*
     XA4*A1+3*A6*A4-8*A6*A3**2*A1-4*A6*A3*A2*A1-12*A6*A3*A1**2+6*
     XA6*A3*A1
      S1221=S1221+4*A6*A2**2*A1-3*A6*A2*A1-4*A6*A1**3+3*A6*A1
     $**2-4*A5
     X**3*A2+4*A5**2*A4*A3-8*A5**2*A4*A2+2*A5**2*A4+12*A5**2*A3*A2
     X+12*A5**2*A2**2+4*A5**2*A2*A1-5*A5**2*A2+12*A5*A4**2*A3-4*A5
     X*A4**2*A2+4*A5*A4**2-12*A5*A4*A3**2-8*A5*A4*A3*A1+A5*A4*A3+8
     X*A5*A4*A2**2-8*A5*A4*A2-4*A5*A4*A1
      S1221=S1221+3*A5*A4-8*A5*A3**
     $2*A2-12*
     XA5*A3*A2**2-4*A5*A3*A2*A1+6*A5*A3*A2-4*A5*A2**3+3*A5*A2**2+4
     X*A5*A2*A1**2-3*A5*A2*A1+8*A4**3*A3-16*A4**2*A3**2-12*A4**2*
     XA3*A2-12*A4**2*A3*A1+6*A4**2*A3+8*A4*A3**3+12*A4*A3**2*A2+12
     X*A4*A3**2*A1-6*A4*A3**2
      S1221=S1221+4*A4*A3*A2**2+8*A4*A3*A2*A1-
     $3*A4*A3*
     XA2+4*A4*A3*A1**2-3*A4*A3*A1
      S1221=64*S1221
      ARG1=DB**2*S11+DA*DB*S1221+DA**2*S22
      CPIZ1=CPIZ1+PS*ARG1/D12**2/DA**2/DB**2
C
C	EXCHANGE P1 AND P2; REPEAT CALCULATION
C	
      IF(TEST.GT..1) GO TO 59
      TEST=1.D0
      GO TO 32
C
C	INTERFERENCE TERM
C
   59 A1=R1
      A3=E3
      A4=R1*R2-Z1*P1*P2
      A6=R2*E3-P2*P3*Z3
      D12=2.*ME**2+2.*A4
      DB=2.*(ME**2+A4-A1-A2)
      DA=2.*(ME**2+A4+A5+A6)
      DC=2.*(ME**2+A6-A2-A3)
      D23=2.*(ME**2+A6)
      G11=7*ME**6*A3+4*ME**6*A2+7*ME**6*A1-4*ME**6+11*ME**4*
     XA6*A3+6*ME**4*A6*A2+11*ME**4*A6*A1-6*ME**4*A6-12*ME**4*A5*A3
     X-14*ME**4*A5*A2-12*ME**4*A5*A1+8*ME**4*A5+11*ME**4*A4*A3+6*
     XME**4*A4*A2+11*ME**4*A4*A1-6*ME**4*A4-4*ME**4*A3**2-4*ME**4*
     XA3*A2-8*ME**4*A3*A1
      G11=G11+3*ME**4*A3-4*ME**4*A2*A1-4*ME**4*A1*
     $*2+3
     X*ME**4*A1+4*ME**2*A6**2*A3+2*ME**2*A6**2*A2+4*ME**2*A6**2*A1
     X-2*ME**2*A6**2-13*ME**2*A6*A5*A3-12*ME**2*A6*A5*A2-13*ME**2*
     XA6*A5*A1+8*ME**2*A6*A5+8*ME**2*A6*A4*A3+4*ME**2*A6*A4*A2+8*
     XME**2*A6*A4*A1-4*ME**2*A6*A4-4*ME**2*A6*A3**2-4*ME**2*A6*A3*
     XA2-8*ME**2*A6*A3*A1
      G11=G11+3*ME**2*A6*A3-4*ME**2*A6*A2*A1-4*ME*
     $*2*
     XA6*A1**2+3*ME**2*A6*A1-10*ME**2*A5**2*A3-7*ME**2*A5**2*A2-10
     X*ME**2*A5**2*A1+6*ME**2*A5**2-13*ME**2*A5*A4*A3-12*ME**2*A5*
     XA4*A2-13*ME**2*A5*A4*A1+8*ME**2*A5*A4+8*ME**2*A5*A3**2+16*ME
     X**2*A5*A3*A2
      G11=G11+16*ME**2*A5*A3*A1-6*ME**2*A5*A3+8*ME**2*A5*
     $A2**
     X2+16*ME**2*A5*A2*A1-6*ME**2*A5*A2+8*ME**2*A5*A1**2-6*ME**2*
     XA5*A1+4*ME**2*A4**2*A3+2*ME**2*A4**2*A2+4*ME**2*A4**2*A1-2*
     XME**2*A4**2-4*ME**2*A4*A3**2-4*ME**2*A4*A3*A2-8*ME**2*A4*A3*
     XA1
      G11=G11+3*ME**2*A4*A3-4*ME**2*A4*A2*A1-4*ME**2*A4*A1**2+3*ME*
     $*2*
     XA4*A1-4*A6**2*A5*A3-2*A6**2*A5*A2-4*A6**2*A5*A1+2*A6**2*A5-4
     X*A6*A5**2*A3
      G11=G11-4*A6*A5**2*A1+2*A6*A5**2-8*A6*A5*A4*A3-4*A6*A5
     X*A4*A2-8*A6*A5*A4*A1+4*A6*A5*A4+4*A6*A5*A3**2+4*A6*A5*A3*A2+
     X8*A6*A5*A3*A1-3*A6*A5*A3+4*A6*A5*A2*A1+4*A6*A5*A1**2-3*A6*A5
     X*A1+2*A5**3*A2-4*A5**2*A4*A3-4*A5**2*A4*A1+2*A5**2*A4-4*A5**
     X2*A3*A2-4*A5**2*A2**2-4*A5**2*A2*A1
      G11=G11+3*A5**2*A2-4*A5*A4**
     $2*A3
     X-2*A5*A4**2*A2-4*A5*A4**2*A1+2*A5*A4**2+4*A5*A4*A3**2+4*A5*
     XA4*A3*A2+8*A5*A4*A3*A1-3*A5*A4*A3+4*A5*A4*A2*A1+4*A5*A4*A1**
     X2-3*A5*A4*A1
      G11=512*G11
      G12=15*ME**6*A3-8*ME**6*A2-10*ME**6*A1-2*ME**6+23*ME**4
     X*A6*A3-12*ME**4*A6*A2-23*ME**4*A6*A1-2*ME**4*A6+10*ME**4*A5*
     XA3-19*ME**4*A5*A2-7*ME**4*A5*A1-4*ME**4*A5+31*ME**4*A4*A3-6*
     XME**4*A4*A2-12*ME**4*A4*A1-ME**4*A4-16*ME**4*A3**2-2*ME**4*
     XA3*A2-10*ME**4*A3*A1
      G12=G12+10*ME**4*A3+16*ME**4*A2**2+27*ME**4
     $*A2*
     XA1-9*ME**4*A2+15*ME**4*A1**2-6*ME**4*A1+8*ME**2*A6**2*A3-4*
     XME**2*A6**2*A2-17*ME**2*A6**2*A1+10*ME**2*A6*A5*A3-13*ME**2*
     XA6*A5*A2-11*ME**2*A6*A5*A1-8*ME**2*A6*A5+29*ME**2*A6*A4*A3-6
     X*ME**2*A6*A4*A2
      G12=G12-20*ME**2*A6*A4*A1-ME**2*A6*A4-12*ME**2*A
     $6*A3
     X**2-4*ME**2*A6*A3*A2+4*ME**2*A6*A3*A1+6*ME**2*A6*A3+10*ME**2
     X*A6*A2**2+25*ME**2*A6*A2*A1-5*ME**2*A6*A2+23*ME**2*A6*A1**2-
     X9*ME**2*A6*A1-9*ME**2*A5**2*A2-ME**2*A5**2+13*ME**2*A5*A4*A3
     X
      G12=G12-16*ME**2*A5*A4*A2-4*ME**2*A5*A4*A1-2*ME**2*A5*A4-8*ME**
     $2*A5
     X*A3**2+8*ME**2*A5*A3*A2-8*ME**2*A5*A3*A1+10*ME**2*A5*A3+11*
     XME**2*A5*A2**2+13*ME**2*A5*A2*A1-ME**2*A5*A2+4*ME**2*A5*A1**
     X2+2*ME**2*A5*A1-3*ME**2*A5+20*ME**2*A4**2*A3-4*ME**2*A4**2*
     XA1
      G12=G12+ME**2*A4**2-24*ME**2*A4*A3**2-11*ME**2*A4*A3*A2-23*ME
     $**2*
     XA4*A3*A1+13*ME**2*A4*A3+8*ME**2*A4*A2**2+12*ME**2*A4*A2*A1-6
     X*ME**2*A4*A2+8*ME**2*A4*A1**2-3*ME**2*A4*A1+4*ME**2*A3**3+4*
     XME**2*A3**2*A2
      G12=G12+8*ME**2*A3**2*A1-3*ME**2*A3**2-4*ME**2*A3*A2**
     X2-4*ME**2*A3*A2*A1-3*ME**2*A3*A1-4*ME**2*A2**3-12*ME**2*A2**
     X2*A1+3*ME**2*A2**2-12*ME**2*A2*A1**2+6*ME**2*A2*A1-4*ME**2*
     XA1**3+3*ME**2*A1**2-4*A6**3*A1-4*A6**2*A5*A1-4*A6**2*A5+4*A6
     X**2*A4*A3-8*A6**2*A4*A1
      G12=G12+8*A6**2*A3*A1+4*A6**2*A2*A1+8*A6
     $**2*
     XA1**2-3*A6**2*A1-2*A6*A5**2+4*A6*A5*A4*A3-4*A6*A5*A4*A2-4*A6
     X*A5*A4*A1-4*A6*A5*A4+4*A6*A5*A3*A2+4*A6*A5*A3*A1+4*A6*A5*A3+
     X5*A6*A5*A2+4*A6*A5*A1**2+2*A6*A5*A1-3*A6*A5+8*A6*A4**2*A3-4*
     XA6*A4**2*A1-8*A6*A4*A3**2-4*A6*A4*A3*A2
      G12=G12+3*A6*A4*A3+4*A6*
     $A4*
     XA2*A1+8*A6*A4*A1**2-3*A6*A4*A1-4*A6*A3**2*A1-4*A6*A3*A2*A1-8
     X*A6*A3*A1**2+3*A6*A3*A1-4*A6*A2*A1**2-4*A6*A1**3+3*A6*A1**2-
     X4*A5**2*A4*A2-4*A5**2*A2**2-4*A5**2*A2*A1+2*A5**2*A2+4*A5*A4
     X**2*A3-4*A5*A4**2*A2-4*A5*A4*A3**2
      G12=G12+4*A5*A4*A3*A2-4*A5*A4
     $*A3*
     XA1+2*A5*A4*A3+A5*A4*A2-4*A5*A3**2*A2-4*A5*A3*A2**2+3*A5*A3*
     XA2+4*A5*A2**2*A1+4*A5*A2*A1**2-3*A5*A2*A1+4*A4**3*A3-8*A4**2
     X*A3**2-4*A4**2*A3*A2-8*A4**2*A3*A1+3*A4**2*A3+4*A4*A3**3+4*
     XA4*A3**2*A2
      G12=G12+8*A4*A3**2*A1-3*A4*A3**2+4*A4*A3*A2*A1+4*A4*
     $A3*
     XA1**2-3*A4*A3*A1
      G12=256*G12
      G21=-10*ME**6*A3-8*ME**6*A2+15*ME**6*A1-2*ME**6-12*ME**
     X4*A6*A3-6*ME**4*A6*A2+31*ME**4*A6*A1-ME**4*A6-7*ME**4*A5*A3-
     X19*ME**4*A5*A2+10*ME**4*A5*A1-4*ME**4*A5-23*ME**4*A4*A3-12*
     XME**4*A4*A2+23*ME**4*A4*A1-2*ME**4*A4+15*ME**4*A3**2+27*ME**
     X4*A3*A2-10*ME**4*A3*A1-6*ME**4*A3
      G21=G21+16*ME**4*A2**2-2*ME**4
     $*A2*
     XA1-9*ME**4*A2-16*ME**4*A1**2+10*ME**4*A1-4*ME**2*A6**2*A3+20
     X*ME**2*A6**2*A1+ME**2*A6**2-4*ME**2*A6*A5*A3-16*ME**2*A6*A5*
     XA2+13*ME**2*A6*A5*A1-2*ME**2*A6*A5-20*ME**2*A6*A4*A3-6*ME**2
     X*A6*A4*A2
      G21=G21+29*ME**2*A6*A4*A1-ME**2*A6*A4+8*ME**2*A6*A3**2
     $+12*
     XME**2*A6*A3*A2-23*ME**2*A6*A3*A1-3*ME**2*A6*A3+8*ME**2*A6*A2
     X**2-11*ME**2*A6*A2*A1-6*ME**2*A6*A2-24*ME**2*A6*A1**2+13*ME
     X**2*A6*A1-9*ME**2*A5**2*A2-ME**2*A5**2-11*ME**2*A5*A4*A3-13*
     XME**2*A5*A4*A2
      G21=G21+10*ME**2*A5*A4*A1-8*ME**2*A5*A4+4*ME**2*A
     $5*A3
     X**2+13*ME**2*A5*A3*A2-8*ME**2*A5*A3*A1+2*ME**2*A5*A3+11*ME**
     X2*A5*A2**2+8*ME**2*A5*A2*A1-ME**2*A5*A2-8*ME**2*A5*A1**2+10*
     XME**2*A5*A1-3*ME**2*A5-17*ME**2*A4**2*A3-4*ME**2*A4**2*A2+8*
     XME**2*A4**2*A1
      G21=G21+23*ME**2*A4*A3**2+25*ME**2*A4*A3*A2+4*ME*
     $*2*
     XA4*A3*A1-9*ME**2*A4*A3+10*ME**2*A4*A2**2-4*ME**2*A4*A2*A1-5*
     XME**2*A4*A2-12*ME**2*A4*A1**2+6*ME**2*A4*A1-4*ME**2*A3**3-12
     X*ME**2*A3**2*A2
      G21=G21+3*ME**2*A3**2-12*ME**2*A3*A2**2-4*ME**2*A3*A2*
     XA1+6*ME**2*A3*A2+8*ME**2*A3*A1**2-3*ME**2*A3*A1-4*ME**2*A2**
     X3-4*ME**2*A2**2*A1+3*ME**2*A2**2+4*ME**2*A2*A1**2+4*ME**2*A1
     X**3-3*ME**2*A1**2+4*A6**3*A1-4*A6**2*A5*A2+4*A6**2*A5*A1-4*
     XA6**2*A4*A3
      G21=G21+8*A6**2*A4*A1-8*A6**2*A3*A1-4*A6**2*A2*A1-8*
     $A6**
     X2*A1**2+3*A6**2*A1-4*A6*A5**2*A2-4*A6*A5*A4*A3-4*A6*A5*A4*A2
     X+4*A6*A5*A4*A1-4*A6*A5*A4-4*A6*A5*A3*A1+4*A6*A5*A2*A1+A6*A5*
     XA2-4*A6*A5*A1**2+2*A6*A5*A1-8*A6*A4**2*A3+4*A6*A4**2*A1+8*A6
     X*A4*A3**2
      G21=G21+4*A6*A4*A3*A2-3*A6*A4*A3-4*A6*A4*A2*A1-8*A6*A4
     $*A1
     X**2+3*A6*A4*A1+4*A6*A3**2*A1+4*A6*A3*A2*A1+8*A6*A3*A1**2-3*
     XA6*A3*A1+4*A6*A2*A1**2+4*A6*A1**3-3*A6*A1**2-2*A5**2*A4-4*A5
     X**2*A3*A2-4*A5**2*A2**2+2*A5**2*A2-4*A5*A4**2*A3-4*A5*A4**2+
     X4*A5*A4*A3**2
      G21=G21+4*A5*A4*A3*A1+2*A5*A4*A3+4*A5*A4*A2*A1+5*A
     $5*A4
     X*A2+4*A5*A4*A1-3*A5*A4+4*A5*A3**2*A2+4*A5*A3*A2**2-3*A5*A3*
     XA2-4*A5*A2**2*A1-4*A5*A2*A1**2+3*A5*A2*A1-4*A4**3*A3+8*A4**2
     X*A3**2+4*A4**2*A3*A2+8*A4**2*A3*A1-3*A4**2*A3-4*A4*A3**3-4*
     XA4*A3**2*A2-8*A4*A3**2*A1
      G21=G21+3*A4*A3**2-4*A4*A3*A2*A1-4*A4*
     $A3*
     XA1**2+3*A4*A3*A1
      G21=256*G21
      G22=13*ME**6*A3+45*ME**6*A2+13*ME**6*A1+24*ME**6+8*ME**
     X4*A6*A3+64*ME**4*A6*A2+21*ME**4*A6*A1+46*ME**4*A6+10*ME**4*
     XA5*A3+25*ME**4*A5*A2+10*ME**4*A5*A1+24*ME**4*A5+21*ME**4*A4*
     XA3+64*ME**4*A4*A2+8*ME**4*A4*A1+46*ME**4*A4-6*ME**4*A3**2-68
     X*ME**4*A3*A2-32*ME**4*A3*A1-20*ME**4*A3-28*ME**4*A2**2-68*ME
     X**4*A2*A1-6*ME**4*A1**2-20*ME**4*A1
      G22=G22+12*ME**4+24*ME**2*A6
     $**2*
     XA2+8*ME**2*A6**2*A1+22*ME**2*A6**2+16*ME**2*A6*A5*A2+10*ME**
     X2*A6*A5*A1+22*ME**2*A6*A5+8*ME**2*A6*A4*A3+68*ME**2*A6*A4*A2
     X+8*ME**2*A6*A4*A1+60*ME**2*A6*A4-48*ME**2*A6*A3*A2-18*ME**2*
     XA6*A3*A1-24*ME**2*A6*A3-24*ME**2*A6*A2**2-72*ME**2*A6*A2*A1-
     X6*ME**2*A6*A2-6*ME**2*A6*A1**2-26*ME**2*A6*A1
      G22=G22+12*ME**2*A
     $6-2*
     XME**2*A5**2*A2+8*ME**2*A5**2+10*ME**2*A5*A4*A3+16*ME**2*A5*
     XA4*A2+22*ME**2*A5*A4-18*ME**2*A5*A3*A2-16*ME**2*A5*A3*A1-8*
     XME**2*A5*A3+12*ME**2*A5*A2**2-18*ME**2*A5*A2*A1-6*ME**2*A5*
     XA2-8*ME**2*A5*A1
      G22=G22+4*ME**2*A5+8*ME**2*A4**2*A3+24*ME**2*A4
     $**2*
     XA2+22*ME**2*A4**2-6*ME**2*A4*A3**2-72*ME**2*A4*A3*A2-18*ME**
     X2*A4*A3*A1-26*ME**2*A4*A3-24*ME**2*A4*A2**2-48*ME**2*A4*A2*
     XA1-6*ME**2*A4*A2-24*ME**2*A4*A1+12*ME**2*A4+24*ME**2*A3**2*
     XA2
      G22=G22+8*ME**2*A3**2*A1+4*ME**2*A3**2+24*ME**2*A3*A2**2+72*M
     $E**2
     X*A3*A2*A1
      G22=G22-14*ME**2*A3*A2+8*ME**2*A3*A1**2+4*ME**2*A3*A1-
     X3*ME**2*A3+4*ME**2*A2**3+24*ME**2*A2**2*A1-8*ME**2*A2**2+24*
     XME**2*A2*A1**2-14*ME**2*A2*A1
      G22=G22+3*ME**2*A2+4*ME**2*A1**2-3
     $*ME
     X**2*A1+16*A6**2*A4*A2+16*A6**2*A4-16*A6**2*A2*A1-6*A6**2*A1+
     X8*A6*A5*A4*A2+8*A6*A5*A4+8*A6*A5*A2**2-8*A6*A5*A2*A1-2*A6*A5
     X*A2-2*A6*A5*A1+16*A6*A4**2*A2+16*A6*A4**2-32*A6*A4*A3*A2-18*
     XA6*A4*A3-16*A6*A4*A2**2-32*A6*A4*A2*A1-8*A6*A4*A2-18*A6*A4*
     XA1
      G22=G22+8*A6*A4+32*A6*A3*A2*A1+4*A6*A3*A1+16*A6*A2**2*A1+16*A
     $6*A2
     X*A1**2-4*A6*A2*A1+4*A6*A1**2-3*A6*A1-2*A5**2*A2-8*A5*A4*A3*
     XA2-2*A5*A4*A3+8*A5*A4*A2**2-2*A5*A4*A2-8*A5*A3*A2**2+8*A5*A3
     X*A2*A1+4*A5*A3*A2-8*A5*A2**3-8*A5*A2**2*A1+8*A5*A2**2+4*A5*
     XA2*A1-3*A5*A2-16*A4**2*A3*A2-6*A4**2*A3
      G22=G22+16*A4*A3**2*A2+4
     $*A4*
     XA3**2+16*A4*A3*A2**2+32*A4*A3*A2*A1-4*A4*A3*A2+4*A4*A3*A1-3*
     XA4*A3-16*A3**2*A2*A1-16*A3*A2**2*A1-16*A3*A2*A1**2+12*A3*A2*
     XA1
      G22=128*G22
      ARG2=DB*DC*G11+DA*DB*G12+DA*DC*G21+DA**2*G22
      GO TO 25
   27 CPIZ=0.
      GO TO 26
   25 CPIZ2=PS*ARG2/D12/D23/DA**2/DB/DC
      MATRIX_MU_ENUNUEE=AL**2*(.5*CPIZ1-.125*CPIZ2)
   26  zdum = 1.
c       print *,matrix_mu_enunuee
	RETURN
      END
