************************************************************************    
*
*       geom.f
*
*       Definition of the pi-beta detector geometry
*
*       History
*       -------
*       16DEC91 KAA created
*       4AUG95  SR  Implemented variable geometry (via data cards
*                   GDEGR, GTGT, GMWPC, GCALO, GCOSM)
*       7AUG95  SR  corrected misplaced plastic vetos
*       8AUG95  SR  updated MWPC, corrected misplaced wires
*       17OCT95 EF  added CsI crystal directions CSITHT, CSIPHI
*
************************************************************************    
*
      SUBROUTINE GEPIBETA
*   
      IMPLICIT NONE
      INCLUDE 'common.inc'
*WL
      INCLUDE 'dtor.inc'

      CHARACTER*2 CDE(99)
      REAL*4 THT1(3),PHY1(3)
      REAL*4 SINTH,COSTH,SINPH,COSPH

      DATA CDE/'01','02','03','04','05','06','07','08','09',
     +    '10','11','12','13','14','15','16','17','18','19',
     +    '20','21','22','23','24','25','26','27','28','29',
     +    '30','31','32','33','34','35','36','37','38','39',
     +    '40','41','42','43','44','45','46','47','48','49',
     +    '50','51','52','53','54','55','56','57','58','59',
     +    '60','61','62','63','64','65','66','67','68','69',
     +    '70','71','72','73','74','75','76','77','78','79',
     +    '80','81','82','83','84','85','86','87','88','89',
     +    '90','91','92','93','94','95','96','97','98','99'/
      INTEGER IHDH1(10),IHDH2(10) 
c      DATA IHDH1/206,208,210,202,204,216,218,220,212,214/
c      DATA IHDH2/207,209,201,203,205,217,219,211,213,215/
c      DATA IHDH1/201,203,205,207,209,211,213,215,217,219/
c      DATA IHDH2/202,204,206,208,210,212,214,216,218,220/

*
*-----------------------------------------------------------------------
*
*     Tracking target_9 segment parameters: TUBU + 4 TUBS + 4 TUBS
*
      REAL TUBEI(3),TUBI1(5),TUBI2(5),TUBI3(5),TUBI4(5),
     +     TUBO1(5),TUBO2(5),TUBO3(5),TUBO4(5)
*
*     Tracking target_1 segment parameters: TARG + DEGR + TARG VETO
*
      REAL TUBET(3),TUBED(3),TUBEV(3)
      REAL TUBETAR(3),TUBEVAC(3)

      REAL PMT1(27)          ! THORN/EMI PMT geometry
      REAL PKUGE(6),PKUGO(3) ! Kugelgehoize
      REAL PFLOOR(3)         ! Floor
*
*     Declarations for NaI array (1997)
*
      REAL X,Y,Z,NAIB1(3),NAIB2(3),NAIC(3),NAIFE(3),NAIAL(3),NAIVE(3)
      INTEGER N
*
*-----------------------------------------------------------------------
*
      INTEGER I,J,JJ,K,L,ISTATUS,IVOLU,ID,IV
      REAL    XFIB,R0,Z0,PSI,XW1,YW1,XW2,YW2
      REAL    THX,THY,THZ,PHX,PHY,PHZ,XPV,YPV,ZPV
*
*-----------------------------------------------------------------------
*
*       Parameter for materials
*
      REAL APYR(4),ZPYR(4),WPYR(4)    ! Pyrex glass
C--   Standard shilding blocks from Phys .Rev.D, 50 (1994) 1241-1242
      REAL ACON(6),ZCON(6),WCON(6)  
      REAL Z1(2),Z2(2),Z3(3)
      REAL A1(2),A2(2),A3(3)
      REAL WMAT1(2),WMAT2(2),WMAT3(3)
      REAL DENS1,DENS2,DENS3
      INTEGER NLMAT1,NLMAT2,NLMAT3
*
      REAL AMYL(3),ZMYL(3),WMYL(3),DMYL
      REAL AGAS(2),ZGAS(2),WGAS(2),DGAS
      INTEGER NMYL,NGAS
*
      REAL WCH2(2)
*
*       Parameter for geometry
*
      REAL MAMA(3),CALO(6)
      REAL PIPE(5),VAC(5)
      REAL STAVE(11),STAVE97(11),PVETO(3)
      REAL CFC(3)
*
      REAL TARGET(3),TGTLG(3),ACTTGT(3),ACTDEG(3),FIBER(3),CLAD(3)
      REAL B0Z,B0COUNT(3)
      REAL X0(9),Y0(9)
      INTEGER numcol(9)
*
      REAL MWPC(3),WALL1(3),WALL2(3),GAS1(3),GAS2(3)
      REAL ENC1(3),ENC2(3),RING1(3),RING2(3),RING3(3)
      REAL AWIRE1(3),AWIRE2(3)
*
      REAL COSM(3),CVT(3),CVF(3),CVB(3),CVS(3)
      REAL LEAT(3),LEAF(3),LEAB(3),LEAS(3)
      REAL WLST(3),WLSF(3),WLSB(3),WLSS(3)
*
      CHARACTER*4 TAG(69)
      CHARACTER*4 ACR(69)
*
      REAL PE1(11),PE2(11)
      REAL xp01,yp01,zp01,xp1,yp1,zp1,
     1     xp02,yp02,zp02,xp2,yp2,zp2,
     1     TP11,PP11,TP12,PP12,TP13,PP13,
     1     TP21,PP21,TP22,PP22,TP23,PP23
*
      REAL HA1(11),HA2(11)
      REAL TA11,PA11,TA21,PA21,TA31,PA31,
     1     TA12,PA12,TA22,PA22,TA32,PA32
      REAL xa1,ya1,za1,xa2,ya2,za2
      REAL xa01,ya01,za01,xa02,ya02,za02
*
      REAL HB1(11),HB2(11)
      REAL TB11,PB11,TB21,PB21,TB31,PB31,
     1     TB12,PB12,TB22,PB22,TB32,PB32
      REAL xb1,yb1,zb1,xb2,yb2,zb2
      REAL xb01,yb01,zb01,xb02,yb02,zb02
*
      REAL HC1(11),HC2(11)
      REAL TC11,PC11,TC21,PC21,TC31,PC31,
     1     TC12,PC12,TC22,PC22,TC32,PC32
      REAL xc1,yc1,zc1,xc2,yc2,zc2
      REAL xc01,yc01,zc01,xc02,yc02,zc02
*
      REAL HD1(11),HD2(11)
      REAL TD11,PD11,TD21,PD21,TD31,PD31,
     1     TD12,PD12,TD22,PD22,TD32,PD32
      REAL xd1,yd1,zd1,xd2,yd2,zd2
      REAL xd01,yd01,zd01,xd02,yd02,zd02
*
      REAL HH1(11),HH2(11)
*
      REAL VT1(11),VT2(11),VT3(11),VT4(11)
      REAL TV11,PV11,TV21,PV21,TV31,PV31,
     1     TV12,PV12,TV22,PV22,TV32,PV32
      REAL xv1,yv1,zv1,xv2,yv2,zv2
      REAL xv01,yv01,zv01,xv02,yv02,zv02
*
      REAL xv3,yv3,zv3,xv4,yv4,zv4
      REAL xv03,yv03,zv03,xv04,yv04,zv04
*
      DATA APYR,ZPYR,WPYR/28.09,10.82,23.00,16.00,
     +                    14.00,5.00,11.00,8.00,
     +                    0.385,0.039,0.038,0.538/
      DATA ACON,ZCON,WCON/16.00,28.09,40.08,22.99,55.85,26.98,
     +                    8.,14.,20.,11.,26.,13.,
     +                    0.52,0.325,0.06,0.015,0.04,0.04/
      DATA Z1,Z2,A1,A2/6.0,1.0,55.0,53.0,12.01115,1.00797,
     1                 132.905,126.9044/ 
      DATA WMAT1,WMAT2/0.91549,0.08451,0.511548,0.488452/
*
      DATA FIBER,CLAD/0.138,0.138,2.5,0.150,0.150,2.5/
      DATA DENS1,DENS3,NLMAT1,NLMAT3/1.049,1.181,2,3/
      DATA DENS2,NLMAT2/4.526,2/
      DATA WMAT3/0.59985,0.08054,0.31961/
      DATA Z3/6.0,1.0,8.0/
      DATA A3/12.01115,1.00797,15.9994/
      DATA AMYL,ZMYL,WMYL,DMYL/12.01,1.01,16.,6.,1.,8.,5.,4.,2.,1.39/
      DATA NMYL/-3/
      DATA WCH2/1.0,2.0/
      DATA AGAS,ZGAS,WGAS/40.0,58.0,18.0,34.0,0.6765,0.3235/
      DATA DGAS,NGAS/1.85E-03,2/
*
      DATA numcol/9,9,9,7,5,9,9,7,5/
      DATA X0/-1.264,-1.264,-1.264,-0.948,-0.632,
     1        -1.264,-1.264,-0.948,-0.632/ 
      DATA Y0/0.0,0.316,0.632,0.948,1.264,
     1        -0.316,-0.632,-0.948,-1.264/ 
*
      DATA PE1/11.0,4.0,270.0,1.0469,0.0,2.8820,0.0,1.9364,
     1         0.0,5.3305,0.0/
      DATA PE2/11.0,2.0,270.0,1.6939,1.7812,2.8820,0.0,
     1         3.1332,3.2945,5.3305,0.0/  
      DATA xp01,yp01,zp01,xp02,yp02,zp02/0.0,-2.8259,37.0,
     1                                   0.0,-1.0793,37.0/
*
      DATA HA1/11.0,3.240276,270.19166,1.4667,
     1         1.934324,3.712564,0.022746,2.712198,
     1         3.576776,6.864157,0.011140/
      DATA HA2/11.0,2.98973,269.812134,1.353115,
     1         1.784971,3.712564,0.021878,2.502126,
     1         3.299731,6.864157,0.011798/
      DATA xa01,ya01,za01,xa02,ya02,za02/0.0,-2.089452,37.0,
     1                                   0.0,-1.927617,37.0/
*
      DATA HB1/11.0,3.49,266.0,1.576722,1.845073,3.556092,
     1         354.34,2.915130,3.411386,6.574772,354.34/
      DATA HB2/11.0,3.49,274.0,1.576722,1.845073,3.556092,
     1         5.46,2.915130,3.411386,6.574772,5.46/
*
      DATA xb01,yb01,zb01,xb02,yb02,zb02/0.2226,-2.245926,37.0,
     1                                   -0.2226,-2.245926,37.0/
*
c      DATA HC2/11.0,3.43,270.0,1.554285,1.936481,3.930567,0.0,
c     1         2.873644,3.579709,7.266481,0.0/
c      DATA HC1/11.0,3.54,270.0,1.6017715,1.995645,3.930567,0.0,
c     1         2.961446,3.689086,7.266481,0.0/
cnew---------------------------------------------------------------
      DATA HC2/11.0,3.43,270.0,1.704285,2.086481,4.180567,0.0,
     1         3.023644,3.729709,7.416481,0.0/
      DATA HC1/11.0,3.54,270.0,1.7517715,2.145645,4.180567,0.0,
     1         3.211446,3.839086,7.416481,0.0/
c-------------------------------------------------------------------
      DATA xc02,yc02,zc02,xc01,yc01,zc01/0.0,-2.213965,37.0,
     1                                   0.0,-2.281609,37.0/
*
c      DATA HD2/11.0,3.45,273.0,1.561733,1.882653,3.766625,
c     1         359.40,2.8860385,3.480486,6.967328,359.40/
c      DATA HD1/11.0,3.45,267.0,1.561733,1.882335,3.766625,
c     1         0.60,2.8860385,3.480486,6.967238,0.60/
cnew---------------------------------------------------------------- 
      DATA HD2/11.0,3.45,273.0,1.711733,2.032653,3.916625,
     1         359.40,3.0360385,3.630486,7.117328,359.40/
      DATA HD1/11.0,3.45,267.0,1.711733,2.032335,3.916625,
     1         0.60,3.0360385,3.630486,7.117238,0.60/
c-------------------------------------------------------------------
      DATA xd02,yd02,zd02,xd01,yd01,zd01/-0.01377,-2.224521,37.0,
     1                                   0.01377,-2.224521,37.0/
*
      DATA HH2/11.0,3.3426,273.398,1.55815,1.8827,3.7606,358.8018,
     1         2.88245,3.4805,6.9577,358.8028/
      DATA HH1/11.0,3.4522,266.602,1.55815,1.8827,3.7606,1.1982,
     1         2.88245,3.48045,6.9577,1.982/
*
      DATA VT3/3.0075,17.6164,263.0,0.1482,4.70,4.7876,343.544,
     1         1.9383,4.8536,5.9988,343.5416/ 
      DATA VT4/7.9925,3.0,279.7793,1.9383,4.8536,5.9988,343.5416,
     1         2.9169,7.1621,8.8500,343.8961/
      DATA xv03,yv03,zv03,xv04,yv04,zv04/-0.6883,-1.10615,29.0075,
     1                                   -0.6485,-2.49404,40.0075/
*
      DATA VT1/3.0075,18.0,269.9588,0.1482,4.70,4.7876,16.456,
     1         1.9383,4.8536,5.9988,16.4584/
      DATA VT2/7.9925,3.197,260.2207,1.9383,4.8536,5.9988,16.4584,
     1         2.9169,7.1621,8.8500,16.1039/
      DATA xv01,yv01,zv01,xv02,yv02,zv02/0.6883,-1.10615,29.0075,
     1                                   0.6485,-2.49404,40.0075/
*
      CHARACTER*4 NAMESH(2)
      INTEGER NBITSH(2)
      REAL ORIG(2),FACT(2)
      DATA NAMESH,NBITSH,ORIG,FACT/'EDEP','TDEP',32,32,0.,0.,1.,1./
      DATA NUMBV /1,19*0/

*
*=======================================================================
*
*     Define materials
*
      CALL GSMATE( 1,'AIR$',14.610,7.300,1.205e-03,3.04e+04,1.e+16,0,0)
      CALL GSMIXT( 2,'PLAST SC$',A1,Z1,DENS1,NLMAT1,WMAT1)
      CALL GSMIXT( 3,'CsI$',A2,Z2,DENS2,NLMAT2,WMAT2)
      CALL GSMIXT( 4,'ACRYLIC$',A3,Z3,DENS3,NLMAT3,WMAT3) 
      CALL GSMATE( 5,'CARBON$',12.010,6.0,2.265,18.8,0.0,0,0)
      CALL GSMIXT( 6,'MYLAR$',AMYL,ZMYL,DMYL,NMYL,WMYL)
      CALL GSMIXT( 7,'MAGIC GAS$',AGAS,ZGAS,DGAS,NGAS,WGAS)
      CALL GSMATE( 8,'TUNGSTEN$',183.850,74.0,19.3,0.35,0.0,0,0)
      CALL GSMATE( 9,'LEAD$',207.190,82.0,11.35,0.59,0.0,0,0)
      CALL GSMIXT(10,'CH2$',A1,Z1,0.935,-2,WCH2)
      CALL GSMATE(11,'VACUUM$',1E-16,1E-16,1E-16,1E16,0.0,0,0)
      CALL GSMATE(12,'IRON$',55.850,26.0,7.870,1.760,0.0,0,0)
      CALL GSMIXT(13,'PYREX$',APYR,ZPYR,2.23,4,WPYR)
      CALL GSMIXT(14,'SHIELD$',ACON,ZCON,2.50,6,WCON)
      CALL GSMATE(15,'NaI(Tl)$',74.94,32.0,3.67,2.60,41.3,0,0)
      CALL GSMATE(16,'ALUMINIUM$',26.98,13.0,2.700,8.9,0.0,0,0)
      CALL GSMATE(17,'LIQUID HYDROGEN$',1.01,1.0,0.071,865.0,790.0,0,0)

*
C--   PSI Dummies Density 774 g/1773 cm^3= 0.437 g/cm^3 (PLS 02/06/97)
*
*=======================================================================
*
*     Define media
*
      EPSIL=1.0e-04
*
      CALL GSTMED( 1,'VACUUM$',11,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 2,'AIR$',1,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 3,'PLASTIC SCINT$',2,1,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 4,'ACRYLIC$',4,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 5,'WAVE L. SHI$',2,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 6,'MYLAR$',6,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 7,'CARBON FIBER$',5,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 8,'MAGIC GAS$',7,1,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 9,'CH2$',10,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
        CALL GSTMED( 10,'CsI$',3,1,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
* 
      CALL GSTMED( 11,'TUNGSTEN$',8,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 12,'IRON$',12,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 13,'LEAD$',9,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    

      CALL GSTMED( 14,'PYREX$',13,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    

      CALL GSTMED( 15,'SHIELD$',14,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    

      CALL GSTMED( 16,'NaI(Tl)$',15,1,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    

      CALL GSTMED( 17,'ALUMINIUM$',16,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    

      CALL GSTMED( 18,'LIQUID HYDROGEN$',17,0,0,
     1     0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )
            
*
*=======================================================================

      DO  K=1,69
         TAG(K) = 'FB'//CDE(K)
         ACR(K) = 'AC'//CDE(K)
      enddo  
*
*=======================================================================
*
*       Defines experiment volume ('MAMA')
*   
      DATA MAMA/168.,130.,136./
c
c includes BC counter
c      DATA MAMA/168.,130.,395./ 
*
      CALL GSVOLU ('MAMA','BOX ',2,MAMA,3,ISTATUS)    ! Experimental Area, air
*
*-----------------------------------------------------------------------
*
*       Cosmic veto house
*
      DATA COSM/150.0,150.0,170.0/
*
      DATA CVT/129.50,1.27,147.25/
      DATA CVF/131.59,123.70,1.27/
      DATA CVB/131.59,108.65,1.27/
      DATA CVS/1.27,112.4,142.25/
*
      DATA LEAT/132.04,2.5,138.44/
      DATA LEAF/132.04,121.2,2.5/
      DATA LEAB/132.04,103.70,2.5/
      DATA LEAS/2.5,103.70,132.17/
*
      DATA WLST/1.27,1.27,150.0/
      DATA WLSF/132.04,1.27,1.27/
      DATA WLSB/132.04,1.27,1.27/
      DATA WLSS/1.27,1.27,145.0/
*
      CALL GSVOLU ('COSM','BOX ',2,COSM,3,ISTATUS)   ! Cosmic Veto mama, air
*
*       Position the lead walls
*
      CALL GSVOLU('LEAT','BOX ',13,LEAT,3,ISTATUS)   ! Lead Top, lead
      CALL GSVOLU('LEAF','BOX ',13,LEAF,3,ISTATUS)   ! Lead Front, lead
      CALL GSVOLU('LEAB','BOX ',13,LEAB,3,ISTATUS)   ! Lead Back, lead
      CALL GSVOLU('LEAS','BOX ',13,LEAS,3,ISTATUS)   ! Lead Sides, lead
      CALL GSPOS ('LEAT',1,'COSM',0.0,121.2,25.48,0,'ONLY')
      CALL GSPOS ('LEAF',1,'COSM',0.0,-2.5,-110.46,0,'ONLY')
      CALL GSPOS ('LEAB',1,'COSM',0.0,15.05,161.42,0,'ONLY')
      CALL GSPOS ('LEAS',1,'COSM',129.54,15.05,25.48,0,'ONLY')
      CALL GSPOS ('LEAS',2,'COSM',-129.54,15.05,25.48,0,'ONLY')
*
*       Position the cosmic vetoes
*
      CALL GSVOLU('CVTO','BOX ', 3,CVT,3,ISTATUS)    ! Top Cosmic Veto, scin
      CALL GSVOLU('CVFR','BOX ', 3,CVF,3,ISTATUS)    ! Front Cosmic Veto, scin
      CALL GSVOLU('CVBA','BOX ', 3,CVB,3,ISTATUS)    ! Back Cosmic Veto, scin
      CALL GSVOLU('CVSL','BOX ', 3,CVS,3,ISTATUS)    ! RSide Cosmic Veto, scin
      CALL GSVOLU('CVSR','BOX ', 3,CVS,3,ISTATUS)    ! LSide Cosmic Veto, scin

      CALL GSPOS ('CVTO',1,'COSM',0.0,127.51,25.48,0,'ONLY')
      CALL GSDETV('CVET','CVTO',331,100,100,ISET,IDET)  ! 331
      CALL GSDETH('CVET','CVTO',2,NAMESH,NBITSH,ORIG,FACT) 

      CALL GSPOS ('CVFR',1,'COSM',0.0,0.0,-114.23,0,'ONLY')
      CALL GSDETV('CVET','CVFR',332,100,100,ISET,IDET)  ! 332
      CALL GSDETH('CVET','CVFR',2,NAMESH,NBITSH,ORIG,FACT) 

      CALL GSPOS ('CVBA',1,'COSM',0.0,15.05,165.19,0,'ONLY')
      CALL GSDETV('CVET','CVBA',333,100,100,ISET,IDET)  ! 333
      CALL GSDETH('CVET','CVBA',2,NAMESH,NBITSH,ORIG,FACT) 

      CALL GSPOS ('CVSL',1,'COSM',133.31,18.8,25.48,0,'ONLY')
      CALL GSDETV('CVET','CVSL',334,100,100,ISET,IDET)  ! 334
      CALL GSDETH('CVET','CVSL',2,NAMESH,NBITSH,ORIG,FACT) 

      CALL GSPOS ('CVSR',1,'COSM',-133.31,18.8,25.48,0,'ONLY')
      CALL GSDETV('CVET','CVSR',335,100,100,ISET,IDET)  ! 335
      CALL GSDETH('CVET','CVSR',2,NAMESH,NBITSH,ORIG,FACT) 
*
*       Position the Wave Length Shifters
*
      CALL GSVOLU('WLST','BOX ', 5,WLST,3,ISTATUS)   ! Wave Length Shifter Top, waveshift
      CALL GSVOLU('WLSF','BOX ', 5,WLSF,3,ISTATUS)   ! Wave length Shifter Front, waveshift
      CALL GSVOLU('WLSB','BOX ', 5,WLSB,3,ISTATUS)   ! Wave Length Shifter Back, waveshift
      CALL GSVOLU('WLSS','BOX ', 5,WLSS,3,ISTATUS)   ! Wave Length Shifter Sides, waveshift
      CALL GSPOS ('WLST',1,'COSM',130.77,127.51,25.48,0,'ONLY')
      CALL GSPOS ('WLST',2,'COSM',-130.77,127.51,25.48,0,'ONLY')
      CALL GSPOS ('WLSF',1,'COSM',0.0,124.97,-114.23,0,'ONLY')
      CALL GSPOS ('WLSF',2,'COSM',0.0,-124.97,-114.23,0,'ONLY')
      CALL GSPOS ('WLSB',1,'COSM',0.0,124.97,165.19,0,'ONLY')
      CALL GSPOS ('WLSB',2,'COSM',0.0,-94.87,165.19,0,'ONLY')
      CALL GSPOS ('WLSS',1,'COSM',133.31,132.47,25.48,0,'ONLY')
      CALL GSPOS ('WLSS',2,'COSM',133.31,-94.87,25.48,0,'ONLY')
      CALL GSPOS ('WLSS',3,'COSM',-133.31,132.47,25.48,0,'ONLY')
      CALL GSPOS ('WLSS',4,'COSM',-133.31,-94.87,25.48,0,'ONLY')
*
*-----------------------------------------------------------------------
*
*       Vacuum pipe
*
      DATA PIPE/60.0,0.0,12.5,0.0,2.5/
      DATA VAC/60.0,0.0,12.3,0.0,2.3/
*
      CALL GSVOLU ('PIPE','CONE',12,PIPE,5,ISTATUS) ! iron
      CALL GSVOLU ('VAC', 'CONE', 1,VAC,5,ISTATUS)  ! vacuum
*
*       Now let's drill a hole in our vaccum pipe
*
C      CALL GSPOS ('VAC',1,'PIPE',0.0,0.0,-0.01,0,'ONLY')
*
*-----------------------------------------------------------------------
*
*       Active Degrader
*
      DATA ACTDEG/0.0,2.0,1.783/
*
      IF (IGTGT.EQ.9.OR.IGTGT.EQ.69) 
     +   CALL GSVOLU ('DEGR','TUBE',3,ACTDEG,3,ISTATUS) ! scint
*
*        B0 Counter

      DATA B0COUNT/1.25,1.25,0.1/
cc      IF(IGTGT.EQ.99) THEN
c        B0Z=ZBEAM+1.0
c        CALL GSVOLU ('B0CO','BOX ',3,B0COUNT,3,ISTATUS) ! scint
c        CALL GSPOS ('B0CO',1,'MAMA',0.0,0.0,B0Z,0,'ONLY')
c        CALL GSDETV('TARB','B0CO',500,100,100,ISET,IDET)  ! sensitive 500 
c        CALL GSDETH('TARB','B0CO',2,NAMESH,NBITSH,ORIG,FACT)
cc      ENDIF

*-----------------------------------------------------------------------
*
*       Active Target
*
      DATA TARGET/0.0,2.0,20.0/
      DATA ACTTGT/0.0,2.0,2.5/
      DATA TGTLG/0.0,2.0,15.0/
*
*       Position the target
*
      IF (IGTGT.EQ.69) THEN
        include 'geometry/target_69.f'   ! 69-segment target
      ELSEIF (IGTGT.EQ.9) THEN  
        include 'geometry/target_9.f'    ! 9-piece target
      ELSEIF (IGTGT.EQ.1) THEN           ! 1996 target package
        include 'geometry/target_1.f'
      ENDIF
*
      include 'geometry/pmt.f'
      include 'geometry/kugel.f'
*
*       Wire chambers
*
      DATA MWPC/5.0,12.75,32.0/
      DATA WALL1/5.7405,6.2895,17.5/
      DATA WALL2/11.733,12.287,27.0/
      DATA GAS1/5.760,6.270,17.5/
      DATA GAS2/11.76,12.26,27.0/
      DATA ENC1/5.0,7.25,2.5/
      DATA RING1/7.25,7.35,2.5/
      DATA RING2/7.35,10.2,1.0/
      DATA RING3/10.2,10.3,2.5/
      DATA ENC2/10.3,12.75,2.5/
      DATA AWIRE1,AWIRE2/0.0,10.0E-04,17.5,0.0,10.0E-04,27.0/
*
      CALL GSVOLU ('MWPC','TUBE',2,MWPC,3,ISTATUS)    ! Wire chamber mama ,air
*
      CALL GSVOLU ('WAL1','TUBE',6,WALL1,3,ISTATUS)  ! MWPC1 Wall, mylar
      CALL GSVOLU ('GAS1','TUBE',8,GAS1,3,ISTATUS)   ! MWPC1 GAS, magic

      CALL GSVOLU ('WAL2','TUBE',6,WALL2,3,ISTATUS)  ! MWPC2 Wall, mylar
      CALL GSVOLU ('GAS2','TUBE',8,GAS2,3,ISTATUS)   ! MWPC2 GAS, magic

      CALL GSVOLU ('ENC1','TUBE',9,ENC1,3,ISTATUS)   ! End Cap 1, ch2
      CALL GSVOLU ('RIN1','TUBE',9,RING1,3,ISTATUS)  ! Ring 1, ch2
      CALL GSVOLU ('RIN2','TUBE',9,RING2,3,ISTATUS)  ! Ring 2, ch2
      CALL GSVOLU ('RIN3','TUBE',9,RING3,3,ISTATUS)  ! Ring 3, ch2
      CALL GSVOLU ('ENC2','TUBE',9,ENC2,3,ISTATUS)   ! End Cap 2, ch2

      CALL GSVOLU ('WIR1','TUBE',11,AWIRE1,3,ISTATUS) ! Anode wire MWPC1, tungsten
      CALL GSVOLU ('WIR2','TUBE',11,AWIRE2,3,ISTATUS) ! Anode wire MWPC2, tungsten

*       Position the wire chambers
*
      IF (IGMWPC.GT.0) THEN

*       Carbon Fiber Cylinder
*
        DATA CFC/12.8,12.9,53.0/
*
        CALL GSVOLU ('CFCY','TUBE',7,CFC,3,ISTATUS) ! carbon fibers
*
        CALL GSPOS ('MWPC',1,'MAMA',0.0,0.0,0.0,0,'ONLY')
*
*       Position the carbon fiber cylinder
*
        CALL GSPOS ('CFCY',1,'MAMA',0.0,0.0,0.0,0,'ONLY')
*
*       Position the anode wires of MWPC 1
*
      R0 = 6.0
      DO K=1,192
        PSI = 360.0*(K-1)/192
*WL degree to radian, COSD to COS, SIND to SIN
        XW1 = R0*COS(PSI*dtor)
        YW1 = R0*SIN(PSI*dtor)
        CALL GSPOS('WIR1',K,'GAS1',XW1,YW1,0.0,0,'ONLY')
      END DO
*
*       Position the anode wires of MWPC 2
*
      R0 = 12.0
      DO K=1,385
        PSI = 360.0*(K-1)/385
*WL degree to radian, COSD to COS, SIND to SIN
        XW2 = R0*COS(PSI*dtor)
        YW2 = R0*SIN(PSI*dtor)
        CALL GSPOS('WIR2',K,'GAS2',XW2,YW2,0.0,0,'ONLY')
      ENDDO
*
*       Position MWPC1 gas and MWPC2 gas
*
      CALL GSPOS('GAS1',1,'WAL1',0.,0.,0.,0,'ONLY')
      CALL GSPOS('GAS2',1,'WAL2',0.,0.,0.,0,'ONLY')
*
*       Position the MWPC walls
*
      CALL GSPOS('WAL1',1,'MWPC',0.,0.,0.,0,'MANY')
      CALL GSPOS('WAL2',1,'MWPC',0.,0.,0.,0,'MANY')
*
*       Position the end caps and support rings
*
      CALL GSPOS ('ENC1',1,'MWPC',0.,0.,20.0,0,'ONLY')
      CALL GSPOS ('ENC1',2,'MWPC',0.,0.,-20.0,0,'ONLY')
      CALL GSPOS ('RIN1',1,'MWPC',0.,0.,23.0,0,'ONLY')
      CALL GSPOS ('RIN1',2,'MWPC',0.,0.,-23.0,0,'ONLY')
      CALL GSPOS ('RIN2',1,'MWPC',0.,0.,24.5,0,'ONLY')
      CALL GSPOS ('RIN2',2,'MWPC',0.,0.,-24.5,0,'ONLY')
      CALL GSPOS ('RIN3',1,'MWPC',0.,0.,26.0,0,'ONLY')
      CALL GSPOS ('RIN3',2,'MWPC',0.,0.,-26.0,0,'ONLY')

      CALL GSPOS ('ENC2',1,'MWPC',0.,0.,29.5,0,'ONLY')
      CALL GSPOS ('ENC2',2,'MWPC',0.,0.,-29.5,0,'ONLY')
*
      ENDIF ! end positioning MWPCs !
*
*-----------------------------------------------------------------------
*
*       Plastic Veto
*
      DATA PVETO/12.9,13.5,30.0/
      DATA STAVE/30.0,0.0,262,0.15875,2.04315,2.09475,9.0,0.15875,
     1          2.04315,2.09475,9.0/
      DATA STAVE97/15.0,0.0,262,0.15875,2.04315,2.09475,9.0,0.15875,
     1     2.04315,2.09475,9.0/
*
      CALL GSVOLU ('PVET','TUBE',2,PVETO,3,ISTATUS) ! air
*
*       Position the plastic veto
*
      IF (IGPV.GT.0) THEN
        IF (ISWIT(1).NE.1997) THEN
          CALL GSPOS('PVET',1,'MAMA',0.0,0.0,0.0,0,'ONLY')
        ELSE
          CALL GSROTM(1003,116.6,0.,90.,90.,26.6,0.)
          CALL GSPOS('PVET',1,'MAMA',-49.998,0.0,24.999,1003,'ONLY')
        ENDIF
      ENDIF
*
*       Position the 20 plastic veto staves
*
      R0 = 12.9+0.318/2.0
      Z0 = 0.0
      ID=500
      IF (ISWIT(1).NE.1997) THEN
      DO I =1,20
        PSI = 18.0*(I-1)
        THY = 90.0
        PHY = PSI 
        THX = 90.0
        PHX = 90 + PSI
        IF (PHX.GT.360) PHX = PHX-360
        THZ = 0.0
        PHZ = 0.0
        CALL GSROTM(ID,THX,PHX,THY,PHY,THZ,PHZ)

* WL convert to radian, change COSD and SIND to COS & SIN
        XPV = R0*COS(PSI*dtor)
        YPV = R0*SIN(PSI*dtor)
        ZPV = Z0
        CALL GSVOLU ('PV'//CDE(I),'TRAP',3,STAVE,11,ISTATUS) ! scint
        CALL GSPOS('PV'//CDE(I),1,'PVET',XPV,YPV,ZPV,ID,'ONLY') 
        CALL GSDETV('PVET','PV'//CDE(I),I+240,100,100,ISET,IDET)  ! 241->260
        CALL GSDETH('PVET','PV'//CDE(I),2,NAMESH,NBITSH,ORIG,FACT)
        ID = ID + 1
      ENDDO
      ELSE
      DO I =7,14
        PSI = 18.0*(I-1)
        THY = 90.0
        PHY = PSI
        THX = 90.0
        PHX = 90 + PSI
        IF (PHX.GT.360) PHX = PHX-360
        THZ = 0.0
        PHZ = 0.0
        CALL GSROTM(ID,THX,PHX,THY,PHY,THZ,PHZ)
*WL COSD & SIND to COS & SIN
        XPV = R0*COS(PSI*dtor)
        YPV = R0*SIN(PSI*dtor)
        ZPV = Z0
        CALL GSVOLU ('PV'//CDE(I),'TRAP',3,STAVE97,11,ISTATUS) ! scint
        CALL GSPOS('PV'//CDE(I),1,'PVET',XPV,YPV,ZPV,ID,'ONLY')
        CALL GSDETV('PVET','PV'//CDE(I),I+240,100,100,ISET,IDET)  ! 241->260
        CALL GSDETH('PVET','PV'//CDE(I),2,NAMESH,NBITSH,ORIG,FACT)
        call gsatt('PV'//CDE(I),'SEEN',1)
        ID = ID + 1
      ENDDO
      ENDIF
*
*       Position subdetectors
*
*       Position the vacuum pipe
*
c      IF (IGDEGR.GT.0) THEN
c        CALL GSPOS ('PIPE',1,'MAMA',0.0,0.0,-67.0,0,'ONLY')
c      ENDIF
*
*       Position the degrader
*
      IF (IGDEGR.GT.0) THEN
        CALL GSPOS ('DEGR',1,'MAMA',0.0,0.0,-4.6,0,'ONLY')
        CALL GSDETV('TARG','DEGR',330,100,100,ISET,IDET)  ! 330
        CALL GSDETH('TARG','DEGR',2,NAMESH,NBITSH,ORIG,FACT)
      ENDIF
*
*       Position the PIBETA CsI calorimeter
*
      IF     (IGCALO.EQ.1) THEN
        include 'geometry/calo1.f' ! Ketevi's CALO geometry
        CALL GSPOS ('CALO',1,'MAMA',0.0,0.0,0.0,0,'ONLY')
      ELSEIF (IGCALO.EQ.2) THEN            
        CALL CRYS_SHAPES           ! Jason's  CALO geometry
        CALL CRYS_POSITIONS
        CALL CRYS_DRAW
      ENDIF
*
C-- If Calibration in 1997, include NaI calorimeter
*
      IF (ISWIT(1).EQ.1997) THEN
        INCLUDE 'geometry/NaI.f'
        INCLUDE 'geometry/lh2_target.f'
      ENDIF
*
*       Position the cosmic veto house
*
      IF (IGCOSM.GT.0) THEN
        CALL GSPOS ('COSM',1,'MAMA',0.0,0.0,0.0,0,'MANY')
      ENDIF
*
*       Close the geometry package
*
      CALL GGCLOS   
*
*       Hide containers
*
      call gsatt('MAMA','SEEN',0)
      call gsatt('CALO','SEEN',0)
      call gsatt('COSM','SEEN',0)
      call gsatt('MWPC','SEEN',0)
      call gsatt('PVET','SEEN',0)
      call gsatt('NAI2','SEEN',0)

      call gsatt('WAL1','SEEN',0)
      call gsatt('GAS1','SEEN',0)
      call gsatt('ENC1','SEEN',0)
      call gsatt('RIN1','SEEN',0)
      call gsatt('RIN2','SEEN',0)
      call gsatt('RIN3','SEEN',0)
      call gsatt('WAL2','SEEN',0)
      call gsatt('GAS2','SEEN',0)
      call gsatt('ENC2','SEEN',0)
*
*      Print information of geometry 
*
*      CALL GPVOLU(0)
*      CALL GPMATE(0)
*      CALL GPTMED(0)
*   
      END   

      SUBROUTINE SCALE_RAD(RCALO,X,Y,Z)      

      IMPLICIT NONE

      REAL RCALO,X,Y,Z

      X=RCALO*X
      Y=RCALO*Y
      Z=RCALO*Z

      RETURN
      END

      INCLUDE 'geometry/cryscalc.f'
      INCLUDE 'geometry/crysposi.f'
      INCLUDE 'geometry/crysdraw.f'



