**********************************************************************
*  This program calculates the input parameters necesary for 
*  defining the crystal geometry for GEANT.
*
*  The basic idea for generating the CsI crystals and their wrapping
*  involves using the Buckminster Fuller geodesic breakdown of an 
*  icosohedron.  From this, the verticies of the crystal moduals 
*  can be calculated.  Any value of crystal shaving can be supplied,
*  thus the verticies for any thickness of crystal wrapping can also 
*  be calculated.
*
*  In order to create these shapes in GEANT, the GEANT shape TRAP, 
*  a general trapezoid, was used to make wedges.  One wedge is used 
*  for each crystal surface.   When rotated and positioned properly,
*  the wedges form a whole crystal (or crystal wrapping).
*  
**********************************************************************
*
      SUBROUTINE CRYS_SHAPES
*
      IMPLICIT NONE
*
      include 'cryscommon.inc'
*WL 
      include '../dtor.inc'
*
      INTEGER ACOMMENTS,BCOMMENTS
      INTEGER CWEDGEWRITE(0:NC)
      INTEGER NX,NY,NZ,I,J,K,L,M,N
      INTEGER IV(0:NC,0:NW),JV(0:NC,0:NW),KV(0:NC,0:NW)
      INTEGER LV(0:NC,0:NW),MV(0:NC,0:NW),NV(0:NC,0:NW)
      INTEGER IC(0:NC,0:NW),JC(0:NC,0:NW),KC(0:NC,0:NW)
      REAL*8  ZDIST(NM,2)
      REAL*8  SPACE(NM,2)
      REAL*8  RAY(0:5,0:5,5:10,4)
      REAL*8  PNORM(0:NC,0:NW,4)
      REAL*8  PX,PY,PZ
      REAL*8  CRYSTHETA(0:NC,0:NW),CRYSPHI(0:NC,0:NW)
      REAL*8  CTH,CPH
      REAL*8  RN(0:NC,0:NW,4)
      REAL*8  RNX,RNY,RNZ
      REAL*8  DPHI(0:NC)
      REAL*8  PENTPHI
      REAL*8  DCENT(2,0:NC)
      REAL*8  PDIST(NM,2,2,0:NC,0:NW)
      REAL*8  PTHETA(0:NC,0:NW),PPHI(0:NC,0:NW)
      REAL*8  CVERT(NM,2,2,0:NC,0:NW,3)
      REAL*8  MID(NM,2,2,0:NC,0:NW,3)
      REAL*8  FCENT(NM,2,0:NC,0:NW,3)
      REAL*8  FPHI(NM,2,0:NC,0:NW)
      REAL*8  WCENT(NM,0:NC,0:NW,3)
      REAL*8  BASE(NM,2,2,0:NC,0:NW)
      REAL*8  HEIGHT(NM,2,0:NC,0:NW)
      REAL*8  FC(3),FCRYSPHI
      REAL*8  THETA(NM,0:NC,0:NW)
      REAL*8  PHI(NM,0:NC,0:NW)
      REAL*8  ALP(NM,2,0:NC,0:NW)
      REAL*8  RMAX(2)
*
*WL remove CARRIAGECONTROL='LIST'
*      OPEN(UNIT=3,NAME='crystals.dat',CARRIAGECONTROL='LIST',
*     +    TYPE='UNKNOWN')
*      OPEN(UNIT=4,NAME='cryscalc.dat',CARRIAGECONTROL='LIST',
*     +    TYPE='UNKNOWN')
      OPEN(UNIT=3,NAME='crystals.dat',TYPE='UNKNOWN')
      OPEN(UNIT=4,NAME='cryscalc.dat',TYPE='UNKNOWN')

*
*  Axial (z) distance to the face (2nd index) of a material (first 
*  index) 
*
      ZDIST(1,1) = DBLE(CRYSTAL_CENTER-CRYSTAL_LENGTH/2)
      ZDIST(1,2) = DBLE(CRYSTAL_CENTER+CRYSTAL_LENGTH/2)
      ZDIST(2,1) = DBLE(CRYSTAL_CENTER-CRYSTAL_LENGTH/2)
      ZDIST(2,2) = DBLE(CRYSTAL_CENTER+CRYSTAL_LENGTH/2)
      ZDIST(3,1) = DBLE(CRYSTAL_CENTER-CRYSTAL_LENGTH/2)
      ZDIST(3,2) = DBLE(CRYSTAL_CENTER+CRYSTAL_LENGTH/2)
      ZDIST(4,1) = DBLE(CRYSTAL_CENTER-CRYSTAL_LENGTH/2
     +             -BKPAPER_THICKNESS)
      ZDIST(4,2) = DBLE(CRYSTAL_CENTER-CRYSTAL_LENGTH/2)
      ZDIST(5,1) = DBLE(CRYSTAL_CENTER-CRYSTAL_LENGTH/2)
      ZDIST(5,2) = DBLE(CRYSTAL_CENTER+CRYSTAL_LENGTH/2)
*
*  SPACE is the perpendicular distance from the natural geodesic 
*  surface boundary for which the surface (2nd index) of a material 
*  (1st index) is to be created.
*  
*  For example:  there is a gap of distance CRYSTAL_GAP
*  between the second (outer) surface of the first (CsI crystal) 
*  material and the natural surface boundary.  Also note:  in the 
*  cases of the CsI crystal, dummy crystal, and black paper nosecover 
*  the inner surface has a negative SPACE value which means that 
*  there is no inner surface and all TRAPs converge at the origin.
*
      SPACE(1,1) = -99.0D00
      SPACE(1,2) = DBLE(CRYSTAL_GAP)
      SPACE(2,1) = DBLE(CRYSTAL_GAP-TEFLON_AIRGAP)
      SPACE(2,2) = DBLE(CRYSTAL_GAP-TEFLON_AIRGAP-TEFLON_THICKNESS)
      SPACE(3,1) = DBLE(CRYSTAL_GAP-TEFLON_AIRGAP-TEFLON_THICKNESS
     +             -MYLAR_AIRGAP)
      SPACE(3,2) = DBLE(CRYSTAL_GAP-TEFLON_AIRGAP-TEFLON_THICKNESS
     +             -MYLAR_AIRGAP-MYLAR_THICKNESS)
      SPACE(4,1) = -99.0D00
      SPACE(4,2) = DBLE(CRYSTAL_GAP)
      SPACE(5,1) = -99.0D00
      SPACE(5,2) = DBLE(DUMMY_GAP)
*
      IF (SPACE(3,2).LT.0) THEN
        WRITE (6,*) '**************OVERLAPPING MATERIALS**************'
      ENDIF
*              
*  Geodesic vertex coordinate data:  this gives the information
*  necessary to calculate the positions of the natural geodesic
*  boundary verticies for each crystal, and each crystal axis
*  relative to the PENT axis.
*
      DATA (IV(0,I), I = 1,NW)  /0,0,0,0,0,0/
      DATA (IV(1,I), I = 1,NW)  /0,1,2,2,1,0/
      DATA (IV(2,I), I = 1,NW)  /1,1,0,3,2,2/
      DATA (IV(3,I), I = 1,NW)  /1,2,3,3,2,1/
      DATA (IV(4,I), I = 1,NW)  /3,4,5,3,3,3/
      DATA (IV(5,I), I = 1,NW)  /0,1,2,0,0,0/
      DATA (IV(6,I), I = 1,NW)  /3,4,5,3,3,3/
      DATA (IV(7,I), I = 1,NW)  /1,4,5,3,3,3/
      DATA (IV(8,I), I = 1,NW)  /0,2,2,0,0,0/
*
      DATA (JV(0,I), I = 1,NW)  /1,1,1,1,1,1/
      DATA (JV(1,I), I = 1,NW)  /1,0,0,1,2,2/
      DATA (JV(2,I), I = 1,NW)  /2,3,4,1,1,0/
      DATA (JV(3,I), I = 1,NW)  /2,1,1,2,3,3/
      DATA (JV(4,I), I = 1,NW)  /1,0,0,2,2,2/
      DATA (JV(5,I), I = 1,NW)  /4,3,3,5,5,5/
      DATA (JV(6,I), I = 1,NW)  /1,0,0,2,2,2/
      DATA (JV(7,I), I = 1,NW)  /1,0,0,2,2,2/
      DATA (JV(8,I), I = 1,NW)  /4,2,2,5,5,5/
*
      DATA (LV(0,I), I = 1,NW)  /1,1,1,1,1,1/
      DATA (LV(1,I), I = 1,NW)  /0,0,1,2,2,1/
      DATA (LV(2,I), I = 1,NW)  /0,1,1,4,3,2/
      DATA (LV(3,I), I = 1,NW)  /1,1,2,3,3,2/
      DATA (LV(4,I), I = 1,NW)  /3,3,4,5,5,5/
      DATA (LV(5,I), I = 1,NW)  /0,0,1,2,2,2/
      DATA (LV(6,I), I = 1,NW)  /3,3,4,5,5,5/
      DATA (LV(7,I), I = 1,NW)  /2,2,4,5,5,5/
      DATA (LV(8,I), I = 1,NW)  /0,0,1,2,2,2/
*
      DATA (MV(0,I), I = 1,NW)  /0,0,0,0,0,0/
      DATA (MV(1,I), I = 1,NW)  /2,1,0,0,1,2/
      DATA (MV(2,I), I = 1,NW)  /2,2,3,0,1,1/
      DATA (MV(3,I), I = 1,NW)  /3,2,1,1,2,3/
      DATA (MV(4,I), I = 1,NW)  /2,1,0,0,0,0/
      DATA (MV(5,I), I = 1,NW)  /5,4,3,3,3,3/
      DATA (MV(6,I), I = 1,NW)  /2,1,0,0,0,0/
      DATA (MV(7,I), I = 1,NW)  /2,2,0,0,0,0/
      DATA (MV(8,I), I = 1,NW)  /5,4,1,3,3,3/
*
      DATA (IC(0,I), I = 1,NW)  /0,0,0,0,0,0/
      DATA (IC(1,I), I = 1,NW)  /1,1,1,1,1,1/
      DATA (IC(2,I), I = 1,NW)  /0,0,0,3,3,3/
      DATA (IC(3,I), I = 1,NW)  /2,2,2,2,2,2/
      DATA (IC(4,I), I = 1,NW)  /4,4,4,4,4,4/
      DATA (IC(5,I), I = 1,NW)  /1,1,1,1,1,1/
      DATA (IC(6,I), I = 1,NW)  /4,4,4,4,4,4/
      DATA (IC(7,I), I = 1,NW)  /4,4,4,4,4,4/
      DATA (IC(8,I), I = 1,NW)  /1,1,1,1,1,1/
*
      DATA (JC(0,I), I = 1,NW)  /0,0,0,0,0,0/
      DATA (JC(1,I), I = 1,NW)  /1,1,1,1,1,1/
      DATA (JC(2,I), I = 1,NW)  /3,3,3,0,0,0/
      DATA (JC(3,I), I = 1,NW)  /2,2,2,2,2,2/
      DATA (JC(4,I), I = 1,NW)  /1,1,1,1,1,1/
      DATA (JC(5,I), I = 1,NW)  /4,4,4,4,4,4/
      DATA (JC(6,I), I = 1,NW)  /1,1,1,1,1,1/
      DATA (JC(7,I), I = 1,NW)  /1,1,1,1,1,1/
      DATA (JC(8,I), I = 1,NW)  /4,4,4,4,4,4/
*
      DO CTYPE = 0,NC
       DO CWEDGE = 1,CWEDGEMAX(CTYPE)
        KV(CTYPE,CWEDGE) = FREQUENCY-IV(CTYPE,CWEDGE)-JV(CTYPE,CWEDGE)
        NV(CTYPE,CWEDGE) = FREQUENCY-LV(CTYPE,CWEDGE)-MV(CTYPE,CWEDGE)
        KC(CTYPE,CWEDGE) = FREQUENCY-IC(CTYPE,CWEDGE)-JC(CTYPE,CWEDGE)
       END DO
      END DO
*
**********************************************************************
*                        GEODESIC BREAKDOWN
*
*  The design for the PiBeta calorimeter is based on a Class II 
*  geodesic breakdown of an icosahedron.  This geometry contains 60 
*  triangles arranged such that 5 triangles are clustered around each 
*  of the 12 icosohedron verticies.  Then a n-frequency division is 
*  performed on each triangle.  For a Class II breakdown, this means 
*  f/2 subdivisions are performed on the triangles.  Each vertex of 
*  this divided triangle are given three digits.  The first digit, 
*  NX, is assigned as shown.  
*
*              0       NX digits
*              /\
*            0/__\1
*            /\  /\
*          0/__\1__\2
*          /\  /\  /\
*        0/__\1__\2__\3
*        /\  /\  /\  /\
*      0/__\1__\2__\3__\4
*      /\  /\  /\  /\  /\
*    0/__\/__\/__\/__\/__\5
*        1   2   3   4   
*
*  The second index, NY, is assigned by the same pattern after a 60
*  deg rotation.  
*
*              0       NY digits
*              /\
*            1/__\0
*            /\  /\
*          2/__\1__\0
*          /\  /\  /\
*        3/__\2__\1__\0
*        /\  /\  /\  /\
*      4/__\3__\2__\1__\0
*      /\  /\  /\  /\  /\
*    5/__\/__\/__\/__\/__\0
*        4   3   2   1   
*
*  The third index, NZ, must satisfy the relation:  f = NX+NY+NZ.  
*  (Note:  The digitization pattern of NZ for Class II breakdowns is 
*  offset by f/2 with respect to the NX and NY digitizations in 
*  order to perserve this relation.)
*
*              10      NZ digits
*              /\
*            9/__\9
*            /\  /\
*          8/__\8__\8
*          /\  /\  /\
*        7/__\7__\7__\7
*        /\  /\  /\  /\
*      6/__\6__\6__\6__\6
*      /\  /\  /\  /\  /\
*    5/__\/__\/__\/__\/__\5
*        5   5   5   5   
*
*  The following calculates the unnormalized rays through the 
*  verticies in this divided triangle.
*  
***********************************************************************
*
      DO NX = 0,5
       DO NY = 0,5
        DO NZ = 5,10
         IF ((NX+NY+NZ).EQ.10) THEN
*WL changed DSIND to DSIN and variable from deg to ran
          RAY(NX,NY,NZ,1) = NX*DSIN(72.D00*dtor)
          RAY(NX,NY,NZ,2) = NY+NX*DCOS(72.D00*dtor)
          RAY(NX,NY,NZ,3) = (FREQUENCY/2.+(NZ)/TAO)*DCOS(36.D00*dtor)
         ENDIF
        END DO
       END DO
      END DO
*
**********************************************************************
*                        Vertex Calculations
*
*  By removing some of the lines from the basic this broken down 
*  triangle, the general PiBeta moduals are formed.  The NX and NY 
*  indicies for sets of adjacent rays which make up a modual surface 
*  are specified in the arrays IV,JV,KV and LV,MV,NV. The indicies 
*  of the central ray of the modual are specified in the arrays
*  IC,JC,KC.   
*
*              P
*              /\                     /\
*             /__\                   /  \
*            /    \                 /    \
*           /  A   \               /      \
*          /\      /\             /        \
*         /  \____/  \           /          \
*        / B /    \ B \         /            \
*       /___/  C   \___\       /______________\
*      / D  \      / D  \     /   VT  |   VT   \
*     /______\____/______\   /________|_________\
*
**********************************************************************
*
*  Cross product of two adjacent rays gives the normal
*  to the plane, PNORM, in which these two rays reside.
*  These planes, when appropriatly adjusted for the desired
*  material (i.e. the crystals or the wrapping), form
*  the boundaries of the material.
*
      DO CTYPE = 0,NC
       DO CWEDGE = 1,CWEDGEMAX(CTYPE)
*
        I = IV(CTYPE,CWEDGE)
        J = JV(CTYPE,CWEDGE)
        K = KV(CTYPE,CWEDGE)
        L = LV(CTYPE,CWEDGE)
        M = MV(CTYPE,CWEDGE)
        N = NV(CTYPE,CWEDGE)
*
        PNORM(CTYPE,CWEDGE,1) = RAY(L,M,N,2)*RAY(I,J,K,3)
     +                        - RAY(L,M,N,3)*RAY(I,J,K,2)
        PNORM(CTYPE,CWEDGE,2) = RAY(L,M,N,3)*RAY(I,J,K,1)
     +                        - RAY(L,M,N,1)*RAY(I,J,K,3)
        PNORM(CTYPE,CWEDGE,3) = RAY(L,M,N,1)*RAY(I,J,K,2)
     +                        - RAY(L,M,N,2)*RAY(I,J,K,1)
        PNORM(CTYPE,CWEDGE,4) = DSQRT(PNORM(CTYPE,CWEDGE,1)**2
     +                               +PNORM(CTYPE,CWEDGE,2)**2
     +                               +PNORM(CTYPE,CWEDGE,3)**2)
       END DO
      END DO
*
*  CRYSTHETA and CRYSPHI are the theta and phi angles for the crystal 
*  centers.  The angles for the vetos must be adjusted.
*
      DO CTYPE = 0,NC
       DO CWEDGE = 1,CWEDGEMAX(CTYPE)
*
        I = IC(CTYPE,CWEDGE)
        J = JC(CTYPE,CWEDGE)
        K = KC(CTYPE,CWEDGE)
*
	IF (CTYPE.EQ.0) THEN
	 CRYSTHETA(CTYPE,CWEDGE) = 0.D0
	 CRYSPHI(CTYPE,CWEDGE) = 90.D0
	ELSEIF (CTYPE.LE.6) THEN
*WL changed DACOSD to DACOS and return value from ran to deg
         CRYSTHETA(CTYPE,CWEDGE) = 1/dtor*DACOS(RAY(I,J,K,3)
     +      /DSQRT(RAY(I,J,K,1)**2+RAY(I,J,K,2)**2+RAY(I,J,K,3)**2))
         CRYSPHI(CTYPE,CWEDGE) = 1/dtor*DASIN(RAY(I,J,K,2)
     +                      /DSQRT(RAY(I,J,K,1)**2+RAY(I,J,K,2)**2))
        ELSEIF (CTYPE.EQ.7) THEN
         CRYSTHETA(CTYPE,CWEDGE) = DBLE(VETO1_THETA)
         CRYSPHI(CTYPE,CWEDGE) = 90.D0-DBLE(VETO1_PHI)
        ELSEIF (CTYPE.EQ.8) THEN
         CRYSTHETA(CTYPE,CWEDGE) = DBLE(VETO2_THETA)
         CRYSPHI(CTYPE,CWEDGE) = 90.D0-DBLE(VETO2_PHI)
        ENDIF
*
       END DO
      END DO
*
*  Rotated normal vectors such that the crystal axis is the z axis.
*
      DO CTYPE = 0,NC
       DO CWEDGE = 1,CWEDGEMAX(CTYPE)
*
        PX = PNORM(CTYPE,CWEDGE,1)
        PY = PNORM(CTYPE,CWEDGE,2)
        PZ = PNORM(CTYPE,CWEDGE,3)
        CTH = CRYSTHETA(CTYPE,CWEDGE)
        CPH = CRYSPHI(CTYPE,CWEDGE)
*
*WL changed DCOSD & DSIND to DCOS &DSIN, change variables from DEG to RAD
        RN(CTYPE,CWEDGE,1) =  (PX*DCOS(CTH*dtor)*DCOS(CPH*dtor)
     +                        +PY*DCOS(CTH*dtor)*DSIN(CPH*dtor)
     +                        -PZ*DSIN(CTH*dtor))/PNORM(CTYPE,CWEDGE,4)
        RN(CTYPE,CWEDGE,2) =  (-PX*DSIN(CPH*dtor)
     +                        +PY*DCOS(CPH*dtor))/PNORM(CTYPE,CWEDGE,4)
        RN(CTYPE,CWEDGE,3) =  (PX*DSIN(CTH*dtor)*DCOS(CPH*dtor)
     +                        +PY*DSIN(CTH*dtor)*DSIN(CPH*dtor)
     +                        +PZ*DCOS(CTH*dtor))/PNORM(CTYPE,CWEDGE,4)
        RN(CTYPE,CWEDGE,4) = DSQRT(RN(CTYPE,CWEDGE,1)**2
     +                            +RN(CTYPE,CWEDGE,2)**2
     +                            +RN(CTYPE,CWEDGE,3)**2)
*
       END DO
      END DO
*
*  PENT wedge positioning
*
      CTYPE = 0
      RNX = RN(0,1,1)
      RNY = RN(0,1,2)
      DO CWEDGE = 1,5
       PENTPHI = -72.D00*(CWEDGE-1)

*WL changed DCOSD & DSIND to DCOS &DSIN, change variables from DEG to RAD
       RN(CTYPE,CWEDGE,1) = RNX*DCOS(PENTPHI*dtor)
     1                      +RNY*DSIN(PENTPHI*dtor)
       RN(CTYPE,CWEDGE,2) = RNY*DCOS(PENTPHI*dtor)
     1                      -RNX*DSIN(PENTPHI*dtor)
      END DO
*
*  Rotate HEXD's and VETO's so that the y-axis is the axis
*  of symmetry for the crystal.  This is done by rotating with
*  respect to the 4th face which is the axis of symmetry for 
*  the crystal.
*
      DO CTYPE = 4,8
*
*WL changed DACOSD & DASIND to DACOS &DASIN, change return values from RAD to DEG
       DPHI(CTYPE) = (1/dtor)*DASIN(RN(CTYPE,4,2)
     +               /DSQRT(RN(CTYPE,4,1)**2+RN(CTYPE,4,2)**2))
*
       DO CWEDGE = 1,4
        RNX = RN(CTYPE,CWEDGE,1)
        RNY = RN(CTYPE,CWEDGE,2)
*WL changed DCOSD & DSIND to DCOS &DSIN, change variables from DEG to RAD
        RN(CTYPE,CWEDGE,1) = RNX*DCOS(-DPHI(CTYPE)*dtor)
     +                      +RNY*DSIN(-DPHI(CTYPE)*dtor)

        RN(CTYPE,CWEDGE,2) = RNY*DCOS(-DPHI(CTYPE)*dtor)
     +                      -RNX*DSIN(-DPHI(CTYPE)*dtor)
       END DO
*
      END DO
*
*  Create second half of the full HEXD wedges 
*
      CTYPE = 4
      DO CWEDGE = 1,3
       RN(CTYPE,7-CWEDGE,1) = -RN(CTYPE,CWEDGE,1)
       RN(CTYPE,7-CWEDGE,2) =  RN(CTYPE,CWEDGE,2)
       RN(CTYPE,7-CWEDGE,3) =  RN(CTYPE,CWEDGE,3)
      END DO
*
*  PTHETA is the polar angle of the rotated normal of a surface
*  PPHI is the azimuthal angel of the rotated normal of a surface
*
      DO CTYPE = 0,NC
       DO CWEDGE = 1,CWEDGEMAX(CTYPE)
*
*WL changed DACOSD & DASIND to DACOS &DASIN, change return values from RAD to DEG
        PTHETA(CTYPE,CWEDGE) = (1/dtor)*DASIN(RN(CTYPE,CWEDGE,3))
        PPHI(CTYPE,CWEDGE) = (1/dtor)*DASIN(RN(CTYPE,CWEDGE,2)
     +                       /DSQRT(RN(CTYPE,CWEDGE,1)**2
     +                       +RN(CTYPE,CWEDGE,2)**2))
*
        IF (RN(CTYPE,CWEDGE,1).LT.0.D00) THEN
         IF (RN(CTYPE,CWEDGE,2).GE.0.D00) THEN
          PPHI(CTYPE,CWEDGE) =  180.D00-PPHI(CTYPE,CWEDGE)
         ELSE
          PPHI(CTYPE,CWEDGE) = -180.D00-PPHI(CTYPE,CWEDGE)
         ENDIF
        ENDIF
*
*  I'm not sure why I need this extra 90 deg here, but it works!!!
*
        PPHI(CTYPE,CWEDGE) = PPHI(CTYPE,CWEDGE)+90.D00
*
       END DO
      END DO
*     
*  PDIST gives the perpendicular distance from the
*  z axis to the plane defining the side of the material
*  at each face (FACE=1 is for the inside face and FACE=2
*  is for the outside face).
*  Note:  the center of each half D and veto are moved
*  by a distance DCENT along the x-axis to accomodate
*  the shaving of the base. 
*
*       _______________  ___
*       \\            /|  |
*        \\         /  |  |
*         \\    PDIST  |  |
*          \\   /      |  |
*           \\/        |  |
*           /\\        |  |
*      RN /\  \\       |  |
*           \  \\______|  ZDIST
*            \  \\     |  |
*             \  \\    |  |
*              \  \\   |  |
*              Xo  \\  |  |
*                \  \\ |  |
*                 \  \\|  |
*                  \  \| _|_
*                   \ /
*                   /   \\ SPACE
*
*  PDIST is found from the dot product of RN (a unit vector) 
*  and the vector describing ZDIST in the z-direction with the 
*  spacing and the shifting of the center (for half Ds and 
*  VETOs) subtracted.
*
      DO MAT = 1,NM
       DO SIDE = 1,2
        DO FACE = 1,2
         DO CTYPE = 0,NC
*
          IF (CTYPE.GE.5) THEN
           DCENT(FACE,CTYPE) =  1.D00
          ELSE
           DCENT(FACE,CTYPE) =  0.D00
          END IF
*
          DO CWEDGE = 1,CWEDGEMAX(CTYPE)
           IF (SPACE(MAT,SIDE).GE.0.) THEN
            PDIST(MAT,SIDE,FACE,CTYPE,CWEDGE) = RN(CTYPE,CWEDGE,3)
     +                          *ZDIST(MAT,FACE)-SPACE(MAT,SIDE)
     +                          -DCENT(FACE,CTYPE)*RN(CTYPE,CWEDGE,1)
           ELSE
            PDIST(MAT,SIDE,FACE,CTYPE,CWEDGE) = 0.D00
           ENDIF
          END DO
*
         END DO
        END DO
       END DO
      END DO
*
*  The intersection of adjacent sides with the each face
*  determines the verticies, VERT, of the material.
*
*  A modual surface plane is given by the vector equation
*                 RN dot (X - Xo) = 0
*  where n is the normal defined by RN, and Xo is as shown
*  in the diagram above.
*
*  To find the verticies one must solve for the equations.
*            RNx(i)*X + RNy(i)*Y = PDIST(i)
*            RNx(j)*X + RNy(j)*Y = PDIST(j)
*  also,     Z = ZDIST(i) = ZDIST(j)
*  where i and j are for adjacent normals.
*
      DO MAT = 1,NM
       DO SIDE = 1,2
        DO FACE = 1,2
         DO CTYPE = 0,NC
          DO CWEDGE = 1,CWEDGEMAX(CTYPE)
*
           L = CWEDGE
           IF (L.EQ.1) THEN
             M = CWEDGEMAX(CTYPE)
           ELSE
             M = L-1
           ENDIF
*
           DO I = 1,2
            CVERT(MAT,SIDE,FACE,CTYPE,L,I) = 
     +             (RN(CTYPE,M,I)*PDIST(MAT,SIDE,FACE,CTYPE,L)
     +             -PDIST(MAT,SIDE,FACE,CTYPE,M)*RN(CTYPE,L,I))
     +             /(RN(CTYPE,L,1)*RN(CTYPE,M,2)
     +             -RN(CTYPE,L,2)*RN(CTYPE,M,1))
           END DO
*
           CVERT(MAT,SIDE,FACE,CTYPE,L,3) = ZDIST(MAT,FACE)
*
          END DO
         END DO
        END DO
       END DO
      END DO
*
**********************************************************************
*  Calculations to make the crystals and wrapping out of GEANT TRAPs
**********************************************************************
*
*  HEIGHT gives the perpendicular distance between the top and bottom 
*  edges of each trapizia face. (I'm using trapezia according to 
*  the international definition meaning a 4 sided object which has two 
*  perpendicular faces)
*
      DO MAT = 1,NM
       DO FACE = 1,2
        DO CTYPE = 0,NC
         DO CWEDGE = 1,CWEDGEMAX(CTYPE)
          IF (SPACE(MAT,1).LT.0) THEN
           HEIGHT(MAT,FACE,CTYPE,CWEDGE) =
     +                            (PDIST(MAT,2,FACE,CTYPE,CWEDGE)
     +                            -PDIST(MAT,1,FACE,CTYPE,CWEDGE))
*WL change DCOSD to DCOS and convert variable from degree to radian
     +                            /DCOS(PTHETA(CTYPE,CWEDGE)*dtor)
          ELSE
           HEIGHT(MAT,FACE,CTYPE,CWEDGE) = SPACE(MAT,1)-SPACE(MAT,2)
          ENDIF
         END DO
        END DO
       END DO
      END DO
*
*  BASE is the length of the trapezia side
*  MID is the position of the bisected side
*
      DO MAT = 1,NM
       DO SIDE = 1,2
        DO FACE = 1,2
         DO CTYPE = 0,NC
          DO CWEDGE = 1,CWEDGEMAX(CTYPE)
*
           L = CWEDGE
           IF (L.EQ.CWEDGEMAX(CTYPE)) THEN
            M = 1
           ELSE
            M = L+1
           ENDIF
*
           BASE(MAT,SIDE,FACE,CTYPE,L)  = DSQRT
     +                          ((CVERT(MAT,SIDE,FACE,CTYPE,L,1)
     +                           -CVERT(MAT,SIDE,FACE,CTYPE,M,1))**2
     +                          +(CVERT(MAT,SIDE,FACE,CTYPE,L,2)
     +                           -CVERT(MAT,SIDE,FACE,CTYPE,M,2))**2)
*
           DO I = 1,3
            MID(MAT,SIDE,FACE,CTYPE,L,I) = 
     +                           (CVERT(MAT,SIDE,FACE,CTYPE,L,I)
     +                           +CVERT(MAT,SIDE,FACE,CTYPE,M,I))/2
           END DO
*
          END DO
         END DO
        END DO
       END DO
      END DO
*
*  FCENT is the position of the center of the trapezia face
*  FPHI is the azimuthal angle to the center of the trapezia face
*  WCENT is the position of the center of the TRAP
*
      DO MAT = 1,NM
       DO CTYPE = 0,NC
        DO CWEDGE = 1,CWEDGEMAX(CTYPE)
         DO FACE = 1,2
*
          DO I = 1,3
           FCENT(MAT,FACE,CTYPE,CWEDGE,I) = 
     +                           (MID(MAT,1,FACE,CTYPE,CWEDGE,I)
     +                           +MID(MAT,2,FACE,CTYPE,CWEDGE,I))/2
          END DO
*WL changed DACOSD & DASIND to DACOS &DASIN, change return values from RAD to DEG
          FPHI(MAT,FACE,CTYPE,CWEDGE) = (1/dtor)*DASIN
     +                  (FCENT(MAT,FACE,CTYPE,CWEDGE,2)
     +                  /DSQRT(FCENT(MAT,FACE,CTYPE,CWEDGE,1)**2
     +                  +FCENT(MAT,FACE,CTYPE,CWEDGE,2)**2))
          IF (FCENT(MAT,FACE,CTYPE,CWEDGE,1).LT.0.D00) THEN
           IF (FCENT(MAT,FACE,CTYPE,CWEDGE,2).GE.0.D00) THEN
            FPHI(MAT,FACE,CTYPE,CWEDGE) =  180.D00
     +                   -FPHI(MAT,FACE,CTYPE,CWEDGE)
           ELSE
            FPHI(MAT,FACE,CTYPE,CWEDGE) = -180.D00
     +                    -FPHI(MAT,FACE,CTYPE,CWEDGE)
           ENDIF
          ENDIF
         END DO
*
         DO I = 1,3
          WCENT(MAT,CTYPE,CWEDGE,I) = (FCENT(MAT,1,CTYPE,CWEDGE,I)
     +                                +FCENT(MAT,2,CTYPE,CWEDGE,I))/2
         END DO
        END DO
       END DO
      END DO
*
*  FC is the vector defining the relative position of the faces
*    of the TRAP.
*  THETA is the polar angle joining the faces of the TRAP
*  PHI is the azimuthal angle joining the faces of the TRAP
*    relative to the perpendicular of the parallel sides of
*    the trapezia at each face.
*  ALP is the angle of the line connecting the midpoints of the
*    parallel sides of the trapezia with respect to their
*    perpendicular.
*   
      DO MAT = 1,NM
       DO CTYPE = 0,NC
        DO CWEDGE = 1,CWEDGEMAX(CTYPE)
*
         DO I = 1,3
          FC(I) = FCENT(MAT,2,CTYPE,CWEDGE,I)
     +           -FCENT(MAT,1,CTYPE,CWEDGE,I)
         END DO
*
*WL changed DATAND to DATAN and convert return value from radian to degree
         THETA(MAT,CTYPE,CWEDGE) = (1/dtor)
     +               *DATAN(DSQRT(FC(1)**2+FC(2)**2)/FC(3))
*
*WL changed DACOSD & DASIND to DACOS &DASIN, change return values from RAD to DEG
         FCRYSPHI= (1/dtor)*DASIN(FC(2)/DSQRT(FC(1)**2+FC(2)**2))
         IF (FC(1).LT.0.D00) THEN
          IF (FC(2).GE.0.D00) THEN
           FCRYSPHI =  180.D00-FCRYSPHI
          ELSE
           FCRYSPHI = -180.D00-FCRYSPHI
          ENDIF
         ENDIF
*
         PHI(MAT,CTYPE,CWEDGE) = FCRYSPHI-PPHI(CTYPE,CWEDGE)+90.D00
         IF (PHI(MAT,CTYPE,CWEDGE).GT.180.D00) THEN
          PHI(MAT,CTYPE,CWEDGE) = PHI(MAT,CTYPE,CWEDGE)-360.D00
         ELSEIF (PHI(MAT,CTYPE,CWEDGE).LE.-180.D00) THEN
          PHI(MAT,CTYPE,CWEDGE) = PHI(MAT,CTYPE,CWEDGE)+360.D00
         ENDIF
*
         DO FACE = 1,2
          ALP(MAT,FACE,CTYPE,CWEDGE) = PPHI(CTYPE,CWEDGE)
     +                       -FPHI(MAT,FACE,CTYPE,CWEDGE)
          IF (ALP(MAT,FACE,CTYPE,CWEDGE).GT.180.D00) THEN
           ALP(MAT,FACE,CTYPE,CWEDGE) = ALP(MAT,FACE,CTYPE,CWEDGE)
     +                                  -360.D00
          ELSEIF (ALP(MAT,FACE,CTYPE,CWEDGE).LE.-180.D00) THEN
           ALP(MAT,FACE,CTYPE,CWEDGE) = ALP(MAT,FACE,CTYPE,CWEDGE)
     +                                  +360.D00
          ENDIF
         END DO
*
        END DO
       END DO
      END DO
*
**********************************************************************
*                           GEANT parameters
**********************************************************************
*
      DO MAT = 1,NM
       DO CTYPE = 0,NC
        DO CWEDGE = 1,CWEDGEMAX(CTYPE)
*
*  Definition for TRAP wedges that form crystals and wrapping
*    1. DZ half-length along the z axis;
*    2. THET polar angel of the line joining the centre of the face at
*       -DZ to the centre of the one at +DZ;
*    3. PHI azimuthal angel of the line joining the centre of the face
*       at -DZ to the centre of the one at +DZ;
*    4. H1 half-length along y of the face at -DZ;
*    5. BL1 half-length along x of the side at -H1 in y of the face at
*       -DZ in z;
*    6. TL1 half length along x of the side at +H1 in y of the face at
*       -DZ in z;
*    7. ALP1 angle with respect to the y axis from the centre of the
*       FACE at -H1 in y to the centre of the FACE at +H1 in the y of
*       the face at -DZ 
*    8. H2 half-length along y of the face at +DZ;
*    9. BL2 half-length along x of the side at -H1 in y of the face at
*       +DZ in z;
*   10. TL2 half length along x of the side at +H1 in y of the face at
*       +DZ in z;
*   11. ALP2 angle with respect to the y axis from the centre of the
*       FACE at -H1 in y to the centre of the FACE at +H1 in the y of
*       the face at +DZ 
*
         WTRAP(MAT,CTYPE,CWEDGE,1)  = REAL(ZDIST(MAT,2)-ZDIST(MAT,1))
     +                                /2
         WTRAP(MAT,CTYPE,CWEDGE,2)  = REAL(THETA(MAT,CTYPE,CWEDGE))
         WTRAP(MAT,CTYPE,CWEDGE,3)  = REAL(PHI(MAT,CTYPE,CWEDGE))
         WTRAP(MAT,CTYPE,CWEDGE,4)  = REAL(HEIGHT(MAT,1,CTYPE,CWEDGE))
     +                                /2
         WTRAP(MAT,CTYPE,CWEDGE,5)  = REAL(BASE(MAT,1,1,CTYPE,CWEDGE))
     +                                /2
         WTRAP(MAT,CTYPE,CWEDGE,6)  = REAL(BASE(MAT,2,1,CTYPE,CWEDGE))
     +                                /2
         WTRAP(MAT,CTYPE,CWEDGE,7)  = REAL(ALP(MAT,1,CTYPE,CWEDGE))
         WTRAP(MAT,CTYPE,CWEDGE,8)  = REAL(HEIGHT(MAT,2,CTYPE,CWEDGE))
     +                                /2
         WTRAP(MAT,CTYPE,CWEDGE,9)  = REAL(BASE(MAT,1,2,CTYPE,CWEDGE))
     +                                /2
         WTRAP(MAT,CTYPE,CWEDGE,10) = REAL(BASE(MAT,2,2,CTYPE,CWEDGE))
     +                                /2
         WTRAP(MAT,CTYPE,CWEDGE,11) = REAL(ALP(MAT,2,CTYPE,CWEDGE))
*
*  Positioning of wedges and wrapping
*    1. x position of the volume in the MRS
*    2. y position of the volume in the MRS
*    3. z position of the volume in the MRS
*
         WPOS(MAT,CTYPE,CWEDGE,1) = REAL(WCENT(MAT,CTYPE,CWEDGE,1))
         WPOS(MAT,CTYPE,CWEDGE,2) = REAL(WCENT(MAT,CTYPE,CWEDGE,2))
         WPOS(MAT,CTYPE,CWEDGE,3) = REAL(WCENT(MAT,CTYPE,CWEDGE,3))
     +                              -CRYSTAL_CENTER
*
*  Modify positioning for half HEXDs and VETOs 
*
         IF (CTYPE.GE.5) THEN
          WPOS(MAT,CTYPE,CWEDGE,2) = WPOS(MAT,CTYPE,CWEDGE,2)
     +                       +REAL(DCENT(1,CTYPE)+DCENT(2,CTYPE))/2
         ENDIF
*
*  Rotation of wedges and wrapping:  this gives the rotational matrix
*  of the Daughter Reference System (DRS) in the Mother Reference
*  System (MRS)
*    1.  THET1 polar angle for axis x';
*    2.  PHI1 azimuthal angle for axis x';
*    3.  THET2 polar angle for axis y';
*    4.  PHI2 azimuthal angle for axis y';
*    5.  THET3 polar angle for axis z';
*    6.  PHI3 azimuthal angle for axis z';
* 
         WROT(MAT,CTYPE,CWEDGE,1) = 90.
         WROT(MAT,CTYPE,CWEDGE,2) = REAL(PPHI(CTYPE,CWEDGE))-90.
         WROT(MAT,CTYPE,CWEDGE,3) = 90.
         WROT(MAT,CTYPE,CWEDGE,4) = REAL(PPHI(CTYPE,CWEDGE))
         WROT(MAT,CTYPE,CWEDGE,5) = 0.
         WROT(MAT,CTYPE,CWEDGE,6) = 0.
*
        END DO
       END DO
      END DO
*
**********************************************************************
*                              VETO CUT
*
*    The VETOs must be cut for beam entry. The inersection
*    of the uncut VETO and this VETO CUT body will form the cut VETO. 
**********************************************************************
*
      WTRAP(1,7,5,1)  = REAL(ZDIST(1,2)-ZDIST(1,1))/2
      WTRAP(1,7,5,4)  = VETOCUT_HEIGHT/2
     +                  +REAL(SPACE(1,2)-SPACE(3,2))/2
      WTRAP(1,7,5,5)  = WTRAP(3,8,4,6)
*WL changed DTAND to DTAN
      WTRAP(1,7,5,6)  = WTRAP(3,8,4,6)-REAL(DTAN(PPHI(8,1)*dtor))
     +                  *WTRAP(1,7,5,4)
*WL ATAND to ATAN
      WTRAP(1,7,5,7)  = -(1/dtor)*ATAN((WTRAP(1,7,5,6)-WTRAP(1,7,5,5))
     +                  /(WTRAP(1,7,5,4)*2))
*WL TAND to TAN
      WTRAP(1,7,5,8)  = WTRAP(1,7,5,4)+TAN(dtor*VETOCUT_BETA)
     +                  *REAL(ZDIST(1,2)-ZDIST(1,1))/2
      WTRAP(1,7,5,9)  = WTRAP(3,8,4,10)
*WL DTAND to DTAN
      WTRAP(1,7,5,10) = WTRAP(3,8,4,10)-REAL(DTAN(dtor*PPHI(8,1)))
     +                  *WTRAP(1,7,5,8)
      WTRAP(1,7,5,11) = WTRAP(1,7,5,7)
*
      WTRAP(1,8,5,1)  =  WTRAP(1,7,5,1)
      WTRAP(1,8,5,4)  =  WTRAP(1,7,5,4)
      WTRAP(1,8,5,5)  =  WTRAP(1,7,5,5)
      WTRAP(1,8,5,6)  =  WTRAP(1,7,5,6)
      WTRAP(1,8,5,7)  = -WTRAP(1,7,5,7)
      WTRAP(1,8,5,8)  =  WTRAP(1,7,5,8)
      WTRAP(1,8,5,9)  =  WTRAP(1,7,5,9)
      WTRAP(1,8,5,10) =  WTRAP(1,7,5,10)
      WTRAP(1,8,5,11) = -WTRAP(1,7,5,11)
*
      DO CTYPE = 7,8
*
       FCENT(1,1,CTYPE,5,1) = FCENT(3,1,CTYPE,4,1)+DBLE(
*WL change (4)TAND to TAN
     +                  TAN(dtor*WTRAP(1,CTYPE,5,7))*WTRAP(1,CTYPE,5,4)
     +                -TAN(dtor*WTRAP(3,CTYPE,4,7))*WTRAP(3,CTYPE,4,4))
       FCENT(1,1,CTYPE,5,2) = DBLE(WTRAP(1,CTYPE,5,4)+SPACE(3,2))
       FCENT(1,1,CTYPE,5,3) = ZDIST(1,1)
       FCENT(1,2,CTYPE,5,1) = FCENT(3,2,CTYPE,4,1)+DBLE(
     +                  TAN(dtor*WTRAP(1,CTYPE,5,11))*WTRAP(1,CTYPE,5,8)
     +                -TAN(dtor*WTRAP(3,CTYPE,4,11))*WTRAP(3,CTYPE,4,8))
       FCENT(1,2,CTYPE,5,2) = DBLE(WTRAP(1,CTYPE,5,8)+SPACE(3,2))
       FCENT(1,2,CTYPE,5,3) = ZDIST(1,2)

       DO I = 1,3
        FC(I) = FCENT(1,2,CTYPE,5,I)
     +         -FCENT(1,1,CTYPE,5,I)
        WCENT(1,CTYPE,5,I) = (FCENT(1,1,CTYPE,5,I)
     +                       +FCENT(1,2,CTYPE,5,I))/2
       END DO
*
*WL replace DATAND with DATAN
       WTRAP(1,CTYPE,5,2) = REAL((1/dtor)*DATAN
     +                        (DSQRT(FC(1)**2+FC(2)**2)/FC(3)))
*WL changed DACOSD & DASIND to DACOS &DASIN, change return values from RAD to DEG
       WTRAP(1,CTYPE,5,3) = REAL((1/dtor)*DASIN(FC(2)
     +                        /DSQRT(FC(1)**2+FC(2)**2)))
       IF (FC(1).LT.0.D00) THEN
        IF (FC(2).GE.0.D00) THEN
         WTRAP(1,CTYPE,5,3) =  180.D00-WTRAP(1,CTYPE,5,3)
        ELSE
         WTRAP(1,CTYPE,5,3) = -180.D00-WTRAP(1,CTYPE,5,3)
        ENDIF
       ENDIF
*
       WPOS(1,CTYPE,5,1) = REAL(WCENT(1,CTYPE,5,1))
       WPOS(1,CTYPE,5,2) = REAL(WCENT(1,CTYPE,5,2))
       WPOS(1,CTYPE,5,3) = 0.
*
      END DO
*
*  DUMMY
*
      WTRAP(5,7,5,1)  = REAL(ZDIST(5,2)-ZDIST(5,1))/2
      WTRAP(5,7,5,4)  = VETOCUT_HEIGHT/2
     +                  +REAL(SPACE(5,2))/2
      WTRAP(5,7,5,5)  = WTRAP(5,8,4,6)
*WL DTAND to DTAN
      WTRAP(5,7,5,6)  = WTRAP(5,8,4,6)-REAL(DTAN(dtor*PPHI(8,1)))
     +                  *WTRAP(5,7,5,4)
*WL ATAND to ATAN
      WTRAP(5,7,5,7)  = -(1/dtor)*ATAN((WTRAP(5,7,5,6)-WTRAP(5,7,5,5))
     +                  /(WTRAP(5,7,5,4)*2))
*TAND to TAN
      WTRAP(5,7,5,8)  = WTRAP(5,7,5,4)+TAN(dtor*VETOCUT_BETA)
     +                  *REAL(ZDIST(5,2)-ZDIST(5,1))/2
      WTRAP(5,7,5,9)  = WTRAP(5,8,4,10)
*WL DTAND to DTAN
      WTRAP(5,7,5,10) = WTRAP(5,8,4,10)-REAL(DTAN(dtor*PPHI(8,1)))
     +                  *WTRAP(5,7,5,8)
      WTRAP(5,7,5,11) = WTRAP(5,7,5,7)
*
      WTRAP(5,8,5,1)  =  WTRAP(5,7,5,1)
      WTRAP(5,8,5,4)  =  WTRAP(5,7,5,4)
      WTRAP(5,8,5,5)  =  WTRAP(5,7,5,5)
      WTRAP(5,8,5,6)  =  WTRAP(5,7,5,6)
      WTRAP(5,8,5,7)  = -WTRAP(5,7,5,7)
      WTRAP(5,8,5,8)  =  WTRAP(5,7,5,8)
      WTRAP(5,8,5,9)  =  WTRAP(5,7,5,9)
      WTRAP(5,8,5,10) =  WTRAP(5,7,5,10)
      WTRAP(5,8,5,11) = -WTRAP(5,7,5,11)
*
      DO CTYPE = 7,8
*
*WL (4)TAND to TAN
       FCENT(5,1,CTYPE,5,1) = FCENT(5,1,CTYPE,4,1)+DBLE(
     +               TAN(dtor*WTRAP(5,CTYPE,5,7))*WTRAP(5,CTYPE,5,4)
     +             -TAN(dtor*WTRAP(5,CTYPE,4,7))*WTRAP(5,CTYPE,4,4))
       FCENT(5,1,CTYPE,5,2) = DBLE(WTRAP(5,CTYPE,5,4))
       FCENT(5,1,CTYPE,5,3) = ZDIST(5,1)
       FCENT(5,2,CTYPE,5,1) = FCENT(5,2,CTYPE,4,1)+DBLE(
     +              TAN(dtor*WTRAP(5,CTYPE,5,11))*WTRAP(5,CTYPE,5,8)
     +            -TAN(dtor*WTRAP(5,CTYPE,4,11))*WTRAP(5,CTYPE,4,8))
       FCENT(5,2,CTYPE,5,2) = DBLE(WTRAP(5,CTYPE,5,8))
       FCENT(5,2,CTYPE,5,3) = ZDIST(5,2)

       DO I = 1,3
        FC(I) = FCENT(5,2,CTYPE,5,I)
     +         -FCENT(5,1,CTYPE,5,I)
        WCENT(5,CTYPE,5,I) = (FCENT(5,1,CTYPE,5,I)
     +                       +FCENT(5,2,CTYPE,5,I))/2
       END DO
*
*WL DATAND to DATAN
       WTRAP(5,CTYPE,5,2) = REAL((1/dtor)*DATAN
     +                        (DSQRT(FC(1)**2+FC(2)**2)/FC(3)))
*WL changed DACOSD & DASIND to DACOS &DASIN, change return values from RAD to DEG
       WTRAP(5,CTYPE,5,3) = REAL((1/dtor)*DASIN(FC(2)
     +                        /DSQRT(FC(1)**2+FC(2)**2)))
       IF (FC(1).LT.0.D00) THEN
        IF (FC(2).GE.0.D00) THEN
         WTRAP(5,CTYPE,5,3) =  180.D00-WTRAP(5,CTYPE,5,3)
        ELSE
         WTRAP(5,CTYPE,5,3) = -180.D00-WTRAP(5,CTYPE,5,3)
        ENDIF
       ENDIF
*
       WPOS(5,CTYPE,5,1) = REAL(WCENT(5,CTYPE,5,1))
       WPOS(5,CTYPE,5,2) = REAL(WCENT(5,CTYPE,5,2))
       WPOS(5,CTYPE,5,3) = 0.
*
      END DO
*
*  Modify position of VETO wedges to fit inside of the VETO CUT body
*
      DO CTYPE = 7,8
       DO MAT = 1,NM
        DO CWEDGE = 1,4
         DO I = 1,3
          WPOS(MAT,CTYPE,CWEDGE,I) = WPOS(MAT,CTYPE,CWEDGE,I)
     +                               -WPOS(1,CTYPE,5,I)
         END DO
        END DO
       END DO
      END DO
*
**********************************************************************
*                       Other Drawing Parameters
**********************************************************************
*
      DO CTYPE = 0,NC
       HXTHETA_O(CTYPE) = REAL(CRYSTHETA(CTYPE,1))
       HXPHI_O(CTYPE) = 90.-REAL(CRYSPHI(CTYPE,1))
       HDPHI_O(CTYPE) = REAL(DPHI(CTYPE))
      END DO
*
      DO CTYPE = 0,NC
*
       CRYS(CTYPE,1) = CRYSTAL_LENGTH/2+BKPAPER_THICKNESS
       CRYS(CTYPE,2) = 0.
       CRYS(CTYPE,3) = 0.
       CRYS(CTYPE,4) = 0.
       CRYS(CTYPE,5) = 0.
*
       DO CWEDGE = 1,CWEDGEMAX(CTYPE)
        DO MAT = 3,5,2
*
         RMAX(1) = DSQRT(CVERT(MAT,2,1,CTYPE,CWEDGE,1)**2
     +              +CVERT(MAT,2,1,CTYPE,CWEDGE,2)**2)
     +              *ZDIST(4,1)/ZDIST(MAT,1)
         RMAX(2) = DSQRT(CVERT(MAT,2,2,CTYPE,CWEDGE,1)**2
     +              +CVERT(MAT,2,2,CTYPE,CWEDGE,2)**2)
     +              *(ZDIST(MAT,2)+(ZDIST(4,2)-ZDIST(4,1)))
     +              /ZDIST(MAT,2)
*
         IF (REAL(RMAX(1)).GT.CRYS(CTYPE,3)) THEN
          CRYS(CTYPE,3) = REAL(RMAX(1))
         ENDIF
*
         IF (REAL(RMAX(2)).GT.CRYS(CTYPE,5)) THEN
          CRYS(CTYPE,5) = REAL(RMAX(2))
         ENDIF
*
        END DO
       END DO
*
      END DO
*
      DO CTYPE = 7,8
       CRYS(CTYPE,5) = SQRT(WTRAP(1,CTYPE,5,8)**2
     +                 +(WTRAP(1,CTYPE,5,9)*2)**2)
      END DO
*
*
**********************************************************************
*  Print out data to 'crystals.dat'
**********************************************************************
*
      DO CTYPE = 0,6
       CWEDGEWRITE(CTYPE) = CWEDGEMAX(CTYPE)
      END DO
      CWEDGEWRITE(7) = 5
      CWEDGEWRITE(8) = 5
*
      ACOMMENTS = 1
      IF (ACOMMENTS.EQ.1) THEN
*
        DO CTYPE = 0,NC
         WRITE (4,100) CTYPE
         WRITE (4,300)
         DO CWEDGE = 1,NW
          WRITE (4,310) CWEDGE,
     +                  PNORM(CTYPE,CWEDGE,1),PNORM(CTYPE,CWEDGE,2),
     +                  PNORM(CTYPE,CWEDGE,3),PNORM(CTYPE,CWEDGE,4)
         END DO
        END DO
*
        DO CTYPE = 0,NC
         WRITE (4,100) CTYPE
         WRITE (4,350)
         DO CWEDGE = 1,NW
          WRITE (4,360) CWEDGE,
     +                  RN(CTYPE,CWEDGE,1),RN(CTYPE,CWEDGE,2),
     +                  RN(CTYPE,CWEDGE,3),RN(CTYPE,CWEDGE,4)
         END DO
        END DO
*
        DO CTYPE = 0,NC
         WRITE (4,100) CTYPE
         WRITE (4,400)
         DO CWEDGE = 1,CWEDGEWRITE(CTYPE)
          WRITE (4,410) CWEDGE,
     +                  CRYSTHETA(CTYPE,CWEDGE),
     +                  CRYSPHI(CTYPE,CWEDGE)
         END DO
        END DO
*
       MAT = 1
       SIDE = 2
*       DO MAT = 1,NW
*        DO SIDE = 1,2
*
         DO CTYPE = 0,NC
          WRITE (4,110) MAT,SIDE,CTYPE
          WRITE (4,450)
          DO CWEDGE = 1,CWEDGEWRITE(CTYPE)
           WRITE (4,460) CWEDGE,
     +                   PDIST(MAT,SIDE,1,CTYPE,CWEDGE),
     +                   PDIST(MAT,SIDE,2,CTYPE,CWEDGE),
     +                   PPHI(CTYPE,CWEDGE)
          END DO
         END DO
*
         DO CTYPE = 0,NC
          WRITE (4,110) MAT,SIDE,CTYPE
          WRITE (4,500)
          DO CWEDGE = 1,CWEDGEWRITE(CTYPE)
           WRITE (4,510) CWEDGE,
     +                   CVERT(MAT,SIDE,1,CTYPE,CWEDGE,1),
     +                   CVERT(MAT,SIDE,1,CTYPE,CWEDGE,2),
     +                   CVERT(MAT,SIDE,2,CTYPE,CWEDGE,1),
     +                   CVERT(MAT,SIDE,2,CTYPE,CWEDGE,2)
          END DO
         END DO
*
         DO CTYPE = 0,NC
          WRITE (4,110) MAT,SIDE,CTYPE
          WRITE (4,700)
          DO CWEDGE = 1,CWEDGEWRITE(CTYPE)
           WRITE (4,710) CWEDGE,
     +                   MID(MAT,SIDE,1,CTYPE,CWEDGE,1),
     +                   MID(MAT,SIDE,1,CTYPE,CWEDGE,2),
     +                   MID(MAT,SIDE,2,CTYPE,CWEDGE,1),
     +                   MID(MAT,SIDE,2,CTYPE,CWEDGE,2)
          END DO
         END DO
*
         DO CTYPE = 0,NC
          WRITE (4,110) MAT,SIDE,CTYPE
          WRITE (4,800)
          DO CWEDGE = 1,CWEDGEWRITE(CTYPE)
           WRITE (4,810) CWEDGE,
     +                   FCENT(MAT,1,CTYPE,CWEDGE,1),
     +                   FCENT(MAT,1,CTYPE,CWEDGE,2),
     +                   FPHI(MAT,1,CTYPE,CWEDGE),
     +                   FCENT(MAT,2,CTYPE,CWEDGE,1),
     +                   FCENT(MAT,2,CTYPE,CWEDGE,2),
     +                   FPHI(MAT,2,CTYPE,CWEDGE)
          END DO
         END DO
*
*        END DO
*       END DO
*
      ENDIF
*
      BCOMMENTS = 1
      IF (BCOMMENTS.EQ.1) THEN
*
*       MAT = 1
       DO MAT = 1,NW
*
        DO CTYPE = 0,NC
         WRITE (3,120) MAT,CTYPE
         WRITE (3,1100)
         DO CWEDGE = 1,CWEDGEWRITE(CTYPE)
          WRITE (3,1110) CWEDGE,
     +                   WTRAP(MAT,CTYPE,CWEDGE,1),
     +                   WTRAP(MAT,CTYPE,CWEDGE,2),
     +                   WTRAP(MAT,CTYPE,CWEDGE,3)
         END DO
        END DO
*
        DO CTYPE = 0,NC
         WRITE (3,120) MAT,CTYPE
         WRITE (3,1200)
        DO CWEDGE = 1,CWEDGEWRITE(CTYPE)
          WRITE (3,1210) CWEDGE,
     +                   WTRAP(MAT,CTYPE,CWEDGE,4),
     +                   WTRAP(MAT,CTYPE,CWEDGE,5),
     +                   WTRAP(MAT,CTYPE,CWEDGE,6),
     +                   WTRAP(MAT,CTYPE,CWEDGE,7)
         END DO
        END DO
*
        DO CTYPE = 0,NC
         WRITE (3,120) MAT,CTYPE
         WRITE (3,1300)
        DO CWEDGE = 1,CWEDGEWRITE(CTYPE)
          WRITE (3,1310) CWEDGE,
     +                   WTRAP(MAT,CTYPE,CWEDGE,8),
     +                   WTRAP(MAT,CTYPE,CWEDGE,9),
     +                   WTRAP(MAT,CTYPE,CWEDGE,10),
     +                   WTRAP(MAT,CTYPE,CWEDGE,11)
         END DO
        END DO
*
        DO CTYPE = 0,NC
         WRITE (3,120) MAT,CTYPE
         WRITE (3,1400)
         DO CWEDGE = 1,CWEDGEWRITE(CTYPE)
          WRITE (3,1410) CWEDGE,
     +                   WPOS(MAT,CTYPE,CWEDGE,1),
     +                   WPOS(MAT,CTYPE,CWEDGE,2),
     +                   WPOS(MAT,CTYPE,CWEDGE,3)
         END DO
        END DO
*
       END DO
*
        DO CTYPE = 0,NC
	  WRITE (3,1500)
          WRITE (3,1510) CTYPE,
     +                   CRYS(CTYPE,1),
     +                   CRYS(CTYPE,2),
     +                   CRYS(CTYPE,3),
     +                   CRYS(CTYPE,4),
     +                   CRYS(CTYPE,5)
        END DO
*
        DO CTYPE = 0,NC
	  WRITE (3,1600)
          WRITE (3,1610) CTYPE,
     +                   HXTHETA_O(CTYPE),
     +                   HXPHI_O(CTYPE),
     +                   HDPHI_O(CTYPE)
        END DO
*
      ENDIF
*
**********************************************************************
 100  FORMAT (/T10,'CTYPE = ',I3)
 110  FORMAT (/T10,'MATERIAL = ',I3,T35,'SIDE = ',I3,T60,
     +        'CTYPE = ',I3)
 120  FORMAT (/T10,'MATERIAL = ',I3,T60,'CTYPE = ',I3)
 300  FORMAT ('CW',T10,'PNORMX',T25,'PNORMY',T40,'PNORMZ',T55,'PNORM')
 310  FORMAT (I3,4F15.7)
 350  FORMAT ('CW',T10,'RNX',T25,'RNY',T40,'RNZ',T55,'RN')
 360  FORMAT (I3,4F15.7)
 400  FORMAT ('CW',T10,'CTHETA',T25,'CPHI')
 410  FORMAT (I3,2F15.7)
 450  FORMAT ('CW',T10,'PDIST_IN',T25,'PDIST_OUT',T40,'PPHI')
 460  FORMAT (I3,3F15.7)
 500  FORMAT ('CW',T10,'VERTXBOT',T25,'VERTYBOT',
     +             T40,'VERTXTOP',T55,'VERTYTOP')
 510  FORMAT (I3,4F15.7)
 700  FORMAT ('CW',T10,'MIDXBOT',T25,'MIDYBOT',
     +             T40,'MIDXTOP',T55,'MIDYTOP')
 710  FORMAT (I3,4F15.7)
 800  FORMAT ('CW',T10,'FCENTXBOT',T22,'FCENTYBOT',T34,'FPHIBOT',
     +             T46,'FCENTXTOP',T58,'FCENTYTOP',T70,'FPHITOP')
 810  FORMAT (I3,6F12.5)
 1100 FORMAT ('CW',T10,'DZ',T25,'THET',T40,'PHI')
 1110 FORMAT (I3,3F15.7)
 1200 FORMAT ('CW',T10,'H1',T25,'BL1',T40,'TL1',T55,'ALP1')
 1210 FORMAT (I3,4F15.7)
 1300 FORMAT ('CW',T10,'H2',T25,'BL2',T40,'TL2',T55,'ALP2')
 1310 FORMAT (I3,4F15.7)
 1400 FORMAT ('CW',T10,'POSX',T25,'POSY',T40,'POSZ')
 1410 FORMAT (I3,3F15.7)
 1500 FORMAT (/'CTYPE',T10,'CRYS1',T25,'CRYS2',T40,'CRYS3',
     +        T55,'CRYS4',T70,'CRYS5')
 1510 FORMAT (I3,5F15.7)
 1600 FORMAT (/'CTYPE',T10,'HXTHETA_O',T25,'HXPHI_O',T40,'HDPHI_O')
 1610 FORMAT (I3,3F15.7)
**********************************************************************
*
      END
