**********************************************************************
*
*              COMMON BLOCKS FOR CSI CRYSTAL GEOMETRY
*
*********************************************************************
*
      COMMON /CRYSTALPOSITION/  CRYS,ROT,POS
      COMMON /CRYSTALWEDGES/  WTRAP,WROT,WPOS
      COMMON /CRYSTALGENERATION/  HXTHETA_O,HXPHI_O,HDPHI_O
*
**********************************************************************
*
*                      ARRAY INDEX PARAMETERS
*
**********************************************************************
*
      INTEGER II
      INTEGER NM                !# of materials
      INTEGER NC                !# of crystals
      INTEGER NW                !max # of wedges
      PARAMETER (NM=5)
      PARAMETER (NC=8)
      PARAMETER (NW=6)
*
**********************************************************************
*
*              DEFINITIONS FOR VARIABLES IN COMMON BLOCKS
*
**********************************************************************
*
      REAL*4  WTRAP(NM,0:NC,0:NW,11)	!wedge shape  parameters
      REAL*4  WPOS(NM,0:NC,0:NW,3)	!wedge position parameters 
      REAL*4  WROT(NM,0:NC,0:NW,6)	!wedge rotation matrix 
      REAL*4  CRYS(0:NC,5)	!crystal mama shape parameters
      REAL*4  POS(0:NC,0:49,3)	!crystal position parameters
      REAL*4  ROT(0:NC,0:49,6)	!crystal rotation matrix
      REAL*4  HXTHETA_O(0:NC)	!crystal polar angle wrt PENT
      REAL*4  HXPHI_O(0:NC)	!crystal azimuthal angle wrt PENT
      REAL*4  HDPHI_O(0:NC)	!extra rotation for Ds and VETOs
*
**********************************************************************
*
*                             INDEX NAMES
*
*    MAT: material 
*      1. CsI crystal
*      2. teflon wrapping
*      3. mylar wrapping
*      4. black paper nosecover
*      5. dummy crystal
*
*    SIDE: the side of a wedge face or surface of a wedge
*      1. inside surface
*      2. outside surface 
*
*    FACE: wedge face along the z axis
*      1. bottom
*      2. top
*
*    CTYPE: type of cyrstal
*      0. PENT--pentagon
*      1. HEXA--hexagon A
*      2. HEXB--hexagon B
*      3. HEXC--hexagon C
*      4. HEXD--hexagon D
*      5. HH1D--half hexagon D type 1
*      6. HH2D--half hexagon D type 2
*      7. VT1V--veto type 1
*      8. VT2V--veto type 2
*
*    CWEDGE: wedge/vertex number.
*      The first vertex is positioned along either the x or y axis 
*      and subsequent vertices are positioned in a counter clockwise 
*      manner relative to this initial vertex.
*      The wedges are labled such that of the two vertices used to
*      form the wedge, the lower one is used to name the wedge.
*      The fifth wedge (VCUT) of the VETOs is used to cut the VETOs
*      in order to make room for beam opening.
*
*    PENTNUM: pentagon number
*      This number is used for positioning crystals.
*      Each pentagon serves as the center for a group of crystals. 
*
*    CNUM: crystal number for a given crystal type
*      Crystal numbers start with zero. 
*      Crystals with the same last digit belong to a group of crystals
*      associated with the pentagon they surround.
*      The crystals dirrectly opposing one another differ by this
*      last digit by 5.
*      
**********************************************************************
*
      INTEGER MAT,SIDE,FACE,CTYPE,CWEDGE,PENTNUM,CNUM
*
**********************************************************************
*
*                           MAXIMUM VALUES
*
**********************************************************************
*
      INTEGER NUMGROUP(0:NC)    !# of CTYPE crystals in a PENT group
      INTEGER CNUMMAX(0:NC)     !# of CTYPE crystals 
      INTEGER CWEDGEMAX(0:NC)   !# of wedges in CTYPE crystal
*
      DATA NUMGROUP/1,5,5,5,4,1,1,1,1/
      DATA CNUMMAX/10,50,50,50,40,10,10,10,10/
      DATA CWEDGEMAX/5,6,6,6,6,4,4,4,4/
*
**********************************************************************
*
*                       CALCULATION PARAMETERS
*
**********************************************************************
*
      INTEGER FREQUENCY		!frequency of geodesic breakdown
      REAL*4  TAO		!golden proportion
      REAL*4  CRYSTAL_CENTER	!radial distance to crystal center
      REAL*4  CRYSTAL_LENGTH	!length of crystal
      REAL*4  CRYSTAL_GAP	!gap between crystal faces
      REAL*4  TEFLON_AIRGAP	!air space between crystal and teflon
      REAL*4  TEFLON_THICKNESS  !thickness of teflon wrapping
      REAL*4  MYLAR_AIRGAP	!air space between teflon and mylar
      REAL*4  MYLAR_THICKNESS   !thickness of mylar wrapping
      REAL*4  BKPAPER_THICKNESS	!thickness of black papar nosecover
      REAL*4  DUMMY_GAP		!gap for dummy crytals
      REAL*4  VETO1_THETA       !polar angle of veto1 central axis
      REAL*4  VETO1_PHI         !azimuthal angle of veto1 central axis
      REAL*4  VETO2_THETA       !polar angle of veto2 central axis
      REAL*4  VETO2_PHI         !azimuthal angle of veto2 central axis
      REAL*4  VETOCUT_BETA      !angle of cut face with veto base
      REAL*4  VETOCUT_HEIGHT    !height of cut front veto face
*
      PARAMETER(FREQUENCY = 10)
*WL no function call allowed inside PARAMETER definition
*      PARAMETER(TAO = (1.+SQRT(5.))/2.)
      PARAMETER(TAO = 1.618033989)
      PARAMETER(CRYSTAL_GAP = .0100)
      PARAMETER(TEFLON_AIRGAP = .0000)
      PARAMETER(TEFLON_THICKNESS = .0050)
      PARAMETER(MYLAR_AIRGAP = .0000)
      PARAMETER(MYLAR_THICKNESS = .0050)
      PARAMETER(BKPAPER_THICKNESS = .0050)
      PARAMETER(DUMMY_GAP = .0000)
      PARAMETER(CRYSTAL_CENTER = 37.000)
      PARAMETER(CRYSTAL_LENGTH = 22.000)
      PARAMETER(VETO1_THETA = 32.75401)
      PARAMETER(VETO1_PHI = 52.11765)
      PARAMETER(VETO2_THETA = 32.75401)
      PARAMETER(VETO2_PHI = 19.88235)
      PARAMETER(VETOCUT_BETA = 31.5)
      PARAMETER(VETOCUT_HEIGHT = 0.2964)
*
**********************************************************************
*
*                       DRAWING MEDIUM PARAMETERS
*
**********************************************************************
*
      INTEGER MED_VACUUM
      INTEGER MED_AIR		!medium # for air
      INTEGER MED_PLASTIC
      INTEGER MED_ACRYLIC
      INTEGER MED_WAVESHIFT
      INTEGER MED_MYLAR		!medium # for mylar wrapping
      INTEGER MED_CARBON
      INTEGER MED_MAGICGAS
      INTEGER MED_CH2
      INTEGER MED_CSI		!medium # for CsI crystals 
      INTEGER MED_TUNGSTEN
      INTEGER MED_IRON
      INTEGER MED_LEAD
      INTEGER MED_PYREX
      INTEGER MED_SHIELD
      INTEGER MED_TEFLON	!medium # for teflon wrapping
      INTEGER MED_BKPAPER	!medium # for black paper nosecover
      INTEGER MED_DUMMY		!medium # for dummy crystals
*
      PARAMETER(MED_VACUUM = 1)
      PARAMETER(MED_AIR = 2)
      PARAMETER(MED_PLASTIC = 3)
      PARAMETER(MED_ACRYLIC = 4)
      PARAMETER(MED_WAVESHIFT = 5)
      PARAMETER(MED_MYLAR = 6)
      PARAMETER(MED_CARBON = 7)
      PARAMETER(MED_MAGICGAS = 8)
      PARAMETER(MED_CH2 = 9)
      PARAMETER(MED_CSI = 10)
      PARAMETER(MED_TUNGSTEN = 11)
      PARAMETER(MED_IRON = 12)
      PARAMETER(MED_LEAD = 13)
      PARAMETER(MED_PYREX = 14)
      PARAMETER(MED_SHIELD = 15)
      PARAMETER(MED_TEFLON = 2)
      PARAMETER(MED_BKPAPER = 2)
      PARAMETER(MED_DUMMY = 3)
*
**********************************************************************
*
*                     CRYSTAL IDENTIFICATION NUMBER
*
**********************************************************************
*
      INTEGER CRYSTALID(0:NC,0:49)
*
      DATA (CRYSTALID(0,II), II=0,9)   
     +                      /  1,  2,  3,  4,  5,  9, 10,  6,  7,  8/ 
      DATA (CRYSTALID(1,II), II=0,49)  
     +                      / 13, 18, 23, 28, 33, 53, 58, 38, 43, 48,
     +                        14, 19, 24, 29, 34, 54, 59, 39, 44, 49,
     +                        15, 20, 25, 30, 35, 55, 60, 40, 45, 50,
     +                        11, 16, 21, 26, 31, 51, 56, 36, 41, 46,
     +                        12, 17, 22, 27, 32, 52, 57, 37, 42, 47/
      DATA (CRYSTALID(2,II), II=0,49)  
     +                      / 63, 68, 73, 78, 83,103,108, 88, 93, 98,
     +                        64, 69, 74, 79, 84,104,109, 89, 94, 99,
     +                        65, 70, 75, 80, 85,105,110, 90, 95,100,
     +                        61, 66, 71, 76, 81,101,106, 86, 91, 96,
     +                        62, 67, 72, 77, 82,102,107, 87, 92, 97/
      DATA (CRYSTALID(3,II), II=0,49)  
     +                      /113,118,123,128,133,153,158,138,143,148,
     +                       114,119,124,129,134,154,159,139,144,149,
     +                       115,120,125,130,135,155,160,140,145,150,
     +                       111,116,121,126,131,151,156,136,141,146,
     +                       112,117,122,127,132,152,157,137,142,147/
      DATA (CRYSTALID(4,II), II=0,39)  
     +                      /178,162,166,170,174,190,194,198,182,186,
     +                       163,167,171,175,179,195,199,183,187,191,
     +                       184,188,192,196,200,172,176,180,164,168,
     +                       161,165,169,173,177,193,197,181,185,189/
      DATA (CRYSTALID(5,II), II=0,9)   
     +                      /201,203,205,207,209,217,219,211,213,215/
      DATA (CRYSTALID(6,II), II=0,9)   
     +                      /202,204,206,208,210,216,218,220,212,214/
      DATA (CRYSTALID(7,II), II=0,9)   
     +                      /221,223,225,227,229,237,239,231,233,235/
      DATA (CRYSTALID(8,II), II=0,9)   
     +                      /222,224,226,228,230,236,238,240,232,234/
*
**********************************************************************
*
*                           CRYSTAL NAMES
*
**********************************************************************
*
      CHARACTER*4  CNAME(0:NC)		!crystal name
      CHARACTER*4  CNAMEDUM(0:NC)	!dummy crystal name
*
      DATA CNAME/'PENT','HEXA','HEXB','HEXC','HEXD','HH1D','HH2D',
     +           'VT1V','VT2V'/
      DATA CNAMEDUM/'DPEN','DHXA','DHXB','DHXC','DHXD','DH1D','DH2D',
     +              'DV1V','DV2V'/
*
**********************************************************************
*
*                             WEDGE NAMES
*
**********************************************************************
*
      CHARACTER*4  WEDGENAME(NM,0:NC,1:NW)
*
      DATA (WEDGENAME(1,0,II), II = 1,NW)
     +                    /'PEN1','PEN2','PEN3','PEN4','PEN5','    '/
      DATA (WEDGENAME(1,1,II), II = 1,NW)  
     +                    /'HXA1','HXA2','HXA3','HXA4','HXA5','HXA6'/
      DATA (WEDGENAME(1,2,II), II = 1,NW)  
     +                    /'HXB1','HXB2','HXB3','HXB4','HXB5','HXB6'/
      DATA (WEDGENAME(1,3,II), II = 1,NW)  
     +                    /'HXC1','HXC2','HXC3','HXC4','HXC5','HXC6'/
      DATA (WEDGENAME(1,4,II), II = 1,NW)  
     +                    /'HXD1','HXD2','HXD3','HXD4','HXD5','HXD6'/
      DATA (WEDGENAME(1,5,II), II = 1,NW)  
     +                    /'H1D1','H1D2','H1D3','H1D4','    ','    '/
      DATA (WEDGENAME(1,6,II), II = 1,NW)  
     +                    /'H2D1','H2D2','H2D3','H2D4','    ','    '/
      DATA (WEDGENAME(1,7,II), II = 1,NW)  
     +                    /'V1V1','V1V2','V1V3','V1V4','V1CT','    '/
      DATA (WEDGENAME(1,8,II), II = 1,NW)  
     +                    /'V2V1','V2V2','V2V3','V2V4','V2CT','    '/
      DATA (WEDGENAME(2,0,II), II = 1,NW)
     +                    /'TFP1','TFP2','TFP3','TFP4','TFP5','    '/
      DATA (WEDGENAME(2,1,II), II = 1,NW)
     +                    /'TFA1','TFA2','TFA3','TFA4','TFA5','TFA6'/
      DATA (WEDGENAME(2,2,II), II = 1,NW)  
     +                    /'TFB1','TFB2','TFB3','TFB4','TFB5','TFB6'/
      DATA (WEDGENAME(2,3,II), II = 1,NW)  
     +                    /'TFC1','TFC2','TFC3','TFC4','TFC5','TFC6'/
      DATA (WEDGENAME(2,4,II), II = 1,NW)  
     +                    /'TFD1','TFD2','TFD3','TFD4','TFD5','TFD6'/
      DATA (WEDGENAME(2,5,II), II = 1,NW)  
     +                    /'T1D1','T1D2','T1D3','T1D4','    ','    '/
      DATA (WEDGENAME(2,6,II), II = 1,NW)  
     +                    /'T2D1','T2D2','T2D3','T2D4','    ','    '/
      DATA (WEDGENAME(2,7,II), II = 1,NW)  
     +                    /'T1V1','T1V2','T1V3','T1V4','    ','    '/
      DATA (WEDGENAME(2,8,II), II = 1,NW)  
     +                    /'T2V1','T2V2','T2V3','T2V4','    ','    '/
      DATA (WEDGENAME(3,0,II), II = 1,NW)
     +                    /'MYP1','MYP2','MYP3','MYP4','MYP5','    '/
      DATA (WEDGENAME(3,1,II), II = 1,NW)
     +                    /'MYA1','MYA2','MYA3','MYA4','MYA5','MYA6'/
      DATA (WEDGENAME(3,2,II), II = 1,NW)  
     +                    /'MYB1','MYB2','MYB3','MYB4','MYB5','MYB6'/
      DATA (WEDGENAME(3,3,II), II = 1,NW)  
     +                    /'MYC1','MYC2','MYC3','MYC4','MYC5','MYC6'/
      DATA (WEDGENAME(3,4,II), II = 1,NW)  
     +                    /'MYD1','MYD2','MYD3','MYD4','MYD5','MYD6'/
      DATA (WEDGENAME(3,5,II), II = 1,NW)  
     +                    /'M1D1','M1D2','M1D3','M1D4','    ','    '/
      DATA (WEDGENAME(3,6,II), II = 1,NW)  
     +                    /'M2D1','M2D2','M2D3','M2D4','    ','    '/
      DATA (WEDGENAME(3,7,II), II = 1,NW)  
     +                    /'M1V1','M1V2','M1V3','M1V4','    ','    '/
      DATA (WEDGENAME(3,8,II), II = 1,NW)  
     +                    /'M2V1','M2V2','M2V3','M2V4','    ','    '/
      DATA (WEDGENAME(4,0,II), II = 1,NW)
     +                    /'BPP1','BPP2','BPP3','BPP4','BPP5','    '/
      DATA (WEDGENAME(4,1,II), II = 1,NW)
     +                    /'BPA1','BPA2','BPA3','BPA4','BPA5','BPA6'/
      DATA (WEDGENAME(4,2,II), II = 1,NW)  
     +                    /'BPB1','BPB2','BPB3','BPB4','BPB5','BPB6'/
      DATA (WEDGENAME(4,3,II), II = 1,NW)  
     +                    /'BPC1','BPC2','BPC3','BPC4','BPC5','BPC6'/
      DATA (WEDGENAME(4,4,II), II = 1,NW)  
     +                    /'BPD1','BPD2','BPD3','BPD4','BPD5','BPD6'/
      DATA (WEDGENAME(4,5,II), II = 1,NW)  
     +                    /'B1D1','B1D2','B1D3','B1D4','    ','    '/
      DATA (WEDGENAME(4,6,II), II = 1,NW)  
     +                    /'B2D1','B2D2','B2D3','B2D4','    ','    '/
      DATA (WEDGENAME(4,7,II), II = 1,NW)  
     +                    /'    ','    ','    ','    ','    ','    '/
      DATA (WEDGENAME(4,8,II), II = 1,NW)  
     +                    /'    ','    ','    ','    ','    ','    '/
      DATA (WEDGENAME(5,0,II), II = 1,NW)
     +                    /'DMP1','DMP2','DMP3','DMP4','DMP5','    '/
      DATA (WEDGENAME(5,1,II), II = 1,NW)
     +                    /'DMA1','DMA2','DMA3','DMA4','DMA5','DMA6'/
      DATA (WEDGENAME(5,2,II), II = 1,NW)  
     +                    /'DMB1','DMB2','DMB3','DMB4','DMB5','DMB6'/
      DATA (WEDGENAME(5,3,II), II = 1,NW)  
     +                    /'DMC1','DMC2','DMC3','DMC4','DMC5','DMC6'/
      DATA (WEDGENAME(5,4,II), II = 1,NW)  
     +                    /'DMD1','DMD2','DMD3','DMD4','DMD5','DMD6'/
      DATA (WEDGENAME(5,5,II), II = 1,NW)  
     +                    /'D1D1','D1D2','D1D3','D1D4','    ','    '/
      DATA (WEDGENAME(5,6,II), II = 1,NW)  
     +                    /'D2D1','D2D2','D2D3','D2D4','    ','    '/
      DATA (WEDGENAME(5,7,II), II = 1,NW)  
     +                    /'D1V1','D1V2','D1V3','D1V4','DV1C','    '/
      DATA (WEDGENAME(5,8,II), II = 1,NW)  
     +                    /'D2V1','D2V2','D2V3','D2V4','DV2C','    '/
*
**********************************************************************







