**********************************************************************
*     Geant drawing commands for crystals
**********************************************************************
*
      SUBROUTINE CRYS_DRAW
*
      IMPLICIT NONE
*
      include '../common.inc'
      include 'cryscommon.inc'
*
      INTEGER I,ISTATUS
      INTEGER WROTNUM
      INTEGER  WMED(NM)
*
      REAL*4  CALO(6)
      REAL*4  CONE_PARAM(5)
      REAL*4  TRAP_PARAM(11)
      REAL*4  THT
*
      WMED(1) = MED_CSI
      WMED(2) = MED_TEFLON
      WMED(3) = MED_MYLAR
      WMED(4) = MED_BKPAPER
      WMED(5) = MED_PLASTIC
*
**********************************************************************
*     DEFINE Sphere into which we position the PIBETA CALORIMETER
**********************************************************************
*
      DATA CALO/0.,50.,0.,180.,0.,360./
      CALL GSVOLU ('CALO','SPHE',MED_AIR,CALO,6,ISTATUS)
*
C--   In 1997 Calibration CsI P03 Face is 81.9cm Away From LH2 Target center
*
      IF (ISWIT(1).EQ.1997) THEN 
        CALL GSPOS ('CALO',1,'MAMA',-49.998,0.0,24.999,0,'MANY')
      ELSE
        CALL GSPOS ('CALO',1,'MAMA',0.,0.,0.,0,'MANY')
      ENDIF

C--   Calorimeter rotation!
C
      IF (ISWIT(1).NE.1997.AND.ISWIT(2).NE.0.) THEN 
C--     Rotation about positive x-axis (P03 at THT=63.43495deg,PHI=180deg)
C       ISWIT(2)=90deg -> P03 looks at zenith!
C       ISWIT(2)=0.deg -> P03 horizontal
C
        THT=ISWIT(2)-63.43495
        CALL GSROTM(1002,0.,0.,THT,90.,THT,270.)
*WL changed #4 & #6variable from 0 to 0.
*        CALL GSPOS ('CALO',1,'MAMA',0,0.0,0,1002,'MANY')
        CALL GSPOS ('CALO',1,'MAMA',0.,0.0,0.,1002,'MANY')
      ENDIF

*
**********************************************************************
*                DEFINE MOTHER VOLUMES FOR CRYSTALS
**********************************************************************
*
       DO CTYPE = 0,8
        DO I = 1,5
         CONE_PARAM(I) = CRYS(CTYPE,I)
        END DO
        write (6,*) 'making ',CNAME(CTYPE)
        CALL GSVOLU (CNAME(CTYPE),'CONE',MED_AIR,CONE_PARAM,
     +               5,ISTATUS)
        write (6,*) 'making ',CNAMEDUM(CTYPE)
        CALL GSVOLU (CNAMEDUM(CTYPE),'CONE',MED_AIR,CONE_PARAM,
     +               5,ISTATUS)
       END DO
*
**********************************************************************
*              POSITION CRYSTAL MOTHER VOLUMES IN CALO
*
*  The rotation #s are the ID # of the crystal which currently
*  run from 1 to 240 according to the old (Ketevi) naming and 
*  positioning convention. 
**********************************************************************
*
      DO CTYPE = 0,NC
       DO CNUM = 0,CNUMMAX(CTYPE)-1
        CALL GSROTM (CRYSTALID(CTYPE,CNUM),
     +               ROT(CTYPE,CNUM,1),ROT(CTYPE,CNUM,2),
     +               ROT(CTYPE,CNUM,3),ROT(CTYPE,CNUM,4),
     +               ROT(CTYPE,CNUM,5),ROT(CTYPE,CNUM,6))
        IF ((ON_CSI_G(CRYSTALID(CTYPE,CNUM)).GE.1).AND.
     +      (ON_CSI_G(CRYSTALID(CTYPE,CNUM)).LE.250)) THEN
         write (6,*) 'positioning ',CNAME(CTYPE)
         CALL GSPOS (CNAME(CTYPE),CNUM,'CALO',POS(CTYPE,CNUM,1),
     +               POS(CTYPE,CNUM,2),POS(CTYPE,CNUM,3),
     +               CRYSTALID(CTYPE,CNUM),'MANY')
        ELSEIF (ON_CSI_G(CRYSTALID(CTYPE,CNUM)).EQ.999) THEN
         write (6,*) 'positioning ',CNAMEDUM(CTYPE)
         CALL GSPOS (CNAMEDUM(CTYPE),CNUM,'CALO',POS(CTYPE,CNUM,1),
     +               POS(CTYPE,CNUM,2),POS(CTYPE,CNUM,3),
     +               CRYSTALID(CTYPE,CNUM),'MANY')
        ENDIF
       END DO
      END DO
*
**********************************************************************
*                        DEFINE VETOCUT
**********************************************************************
*
      DO MAT = 1,5,4
       DO CTYPE = 7,8
        DO I = 1,11
         TRAP_PARAM(I) = WTRAP(MAT,CTYPE,5,I)
        END DO
        write (6,*) 'making ',WEDGENAME(MAT,CTYPE,5)
        CALL GSVOLU (WEDGENAME(MAT,CTYPE,5),'TRAP',MED_AIR,TRAP_PARAM,
     +               11,ISTATUS)
       END DO
      END DO
*
**********************************************************************
*            DEFINE PENT AND HEX CRYSTALS AND WRAPPING 
**********************************************************************
*
      DO MAT = 1,5
       DO CTYPE = 0,8
        DO CWEDGE = 1,CWEDGEMAX(CTYPE)
         IF (WEDGENAME(MAT,CTYPE,CWEDGE).NE.'    ') THEN
          DO I = 1,11
           TRAP_PARAM(I) = WTRAP(MAT,CTYPE,CWEDGE,I)
          END DO
          write (6,*) 'making ',WEDGENAME(MAT,CTYPE,CWEDGE)
          CALL GSVOLU (WEDGENAME(MAT,CTYPE,CWEDGE),'TRAP',WMED(MAT),
     +                 TRAP_PARAM,11,ISTATUS)
         ENDIF
        END DO
       END DO
      END DO
*
**********************************************************************
*         POSITION CRYSTALS AND WRAPPING IN CRYSTAL MOTHERS
*
*  Rotation numbers reserved for wedges go from 1100 to 1499
**********************************************************************
*
      DO MAT = 1,NM
       IF (ON_MAT(MAT).EQ.1) THEN
        DO CTYPE = 0,6
         DO CWEDGE = 1,CWEDGEMAX(CTYPE)
          WROTNUM = 1000+100*MAT+10*CTYPE+CWEDGE
          CALL GSROTM (WROTNUM,WROT(MAT,CTYPE,CWEDGE,1),
     +                         WROT(MAT,CTYPE,CWEDGE,2),
     +                         WROT(MAT,CTYPE,CWEDGE,3),
     +                         WROT(MAT,CTYPE,CWEDGE,4),
     +                         WROT(MAT,CTYPE,CWEDGE,5),
     +                         WROT(MAT,CTYPE,CWEDGE,6))
          write (6,*) 'positioning ',WEDGENAME(MAT,CTYPE,CWEDGE)
          IF (MAT.LE.4) THEN
           CALL GSPOS (WEDGENAME(MAT,CTYPE,CWEDGE),1,
     +                 CNAME(CTYPE),
     +                 WPOS(MAT,CTYPE,CWEDGE,1),
     +                 WPOS(MAT,CTYPE,CWEDGE,2),
     +                 WPOS(MAT,CTYPE,CWEDGE,3),
     +                 WROTNUM,'ONLY')
          ELSEIF (MAT.EQ.5) THEN
           CALL GSPOS (WEDGENAME(MAT,CTYPE,CWEDGE),1,
     +                 CNAMEDUM(CTYPE),
     +                 WPOS(MAT,CTYPE,CWEDGE,1),
     +                 WPOS(MAT,CTYPE,CWEDGE,2),
     +                 WPOS(MAT,CTYPE,CWEDGE,3),
     +                 WROTNUM,'ONLY')
          ENDIF
         END DO
        END DO
       ENDIF
      END DO
*
**********************************************************************
*              POSITION VETO WEDGES INSIDE VETOCUT
**********************************************************************
*
       DO CTYPE = 7,8
*
         write (6,*) 'positioning ',WEDGENAME(1,CTYPE,5)
         CALL GSPOS (WEDGENAME(1,CTYPE,5),1,
     +               CNAME(CTYPE),
     +               WPOS(1,CTYPE,CWEDGE,1),
     +               WPOS(1,CTYPE,CWEDGE,2),
     +               WPOS(1,CTYPE,CWEDGE,3),
     +               0,'MANY')
*
         write (6,*) 'positioning ',WEDGENAME(5,CTYPE,5)
         CALL GSPOS (WEDGENAME(5,CTYPE,5),1,
     +               CNAMEDUM(CTYPE),
     +               WPOS(5,CTYPE,CWEDGE,1),
     +               WPOS(5,CTYPE,CWEDGE,2),
     +               WPOS(5,CTYPE,CWEDGE,3),
     +               0,'MANY')
*
        DO MAT = 1,NM
         IF (ON_MAT(MAT).EQ.1) THEN
          DO CWEDGE = 1,4
           WROTNUM = 1000+100*MAT+10*CTYPE+CWEDGE
           CALL GSROTM (WROTNUM,WROT(MAT,CTYPE,CWEDGE,1),
     +                          WROT(MAT,CTYPE,CWEDGE,2),
     +                          WROT(MAT,CTYPE,CWEDGE,3),
     +                          WROT(MAT,CTYPE,CWEDGE,4),
     +                          WROT(MAT,CTYPE,CWEDGE,5),
     +                          WROT(MAT,CTYPE,CWEDGE,6))
           IF (MAT.LE.3) THEN
            write (6,*) 'positioning ',WEDGENAME(MAT,CTYPE,CWEDGE)
            CALL GSPOS (WEDGENAME(MAT,CTYPE,CWEDGE),1,
     +                  WEDGENAME(1,CTYPE,5),
     +                  WPOS(MAT,CTYPE,CWEDGE,1),
     +                  WPOS(MAT,CTYPE,CWEDGE,2),
     +                  WPOS(MAT,CTYPE,CWEDGE,3),
     +                  WROTNUM,'MANY')
           ELSEIF (MAT.EQ.5) THEN
            write (6,*) 'positioning ',WEDGENAME(MAT,CTYPE,CWEDGE)
            CALL GSPOS (WEDGENAME(MAT,CTYPE,CWEDGE),1,
     +                  WEDGENAME(5,CTYPE,5),
     +                  WPOS(MAT,CTYPE,CWEDGE,1),
     +                  WPOS(MAT,CTYPE,CWEDGE,2),
     +                  WPOS(MAT,CTYPE,CWEDGE,3),
     +                  WROTNUM,'MANY')
           ENDIF
          END DO
         ENDIF
        END DO
*
       END DO
*
**********************************************************************
*
      END
