*
**********************************************************************
*  Position and rotation of Crystals in Calorimeter
**********************************************************************
*
      SUBROUTINE CRYS_POSITIONS
*
      IMPLICIT NONE
*
      include '../common.inc'
      include 'cryscommon.inc'
*WL
      include '../dtor.inc'
*
      INTEGER I,J,M,N
      INTEGER CTYPE_MOD
*
      REAL*4  RP(3,3),RH(3,3),RF(3,3),RD(3,3),RT(3,3)
      REAL*4  PTPHI,PTTHETA
      REAL*4  HXPHI,HXTHETA
      REAL*4  HDPHI
*
*WL remove CARRIAGECONTROL option
*      OPEN(UNIT=5,NAME='positions.dat',CARRIAGECONTROL='LIST',
*     +     TYPE='UNKNOWN')
      OPEN(UNIT=5,NAME='positions.dat',TYPE='UNKNOWN')

*
      DO PENTNUM = 0,9
*
*  RP is the rotation matrix for a PENT.
*  Starting in the calorimeter coordinate system, a rotation of
*  PTPHI about the z-axis is performed followed by a rotation of
*  PTTHETA about the new y-axis.
*
       IF (PENTNUM.LT.5) THEN
*WL ATAND -> ATAN
        PTTHETA = (1/dtor)*ATAN(2.)
        PTPHI = 36.+PENTNUM*72.
       ELSE
        PTTHETA = 180.-(1/dtor)*ATAN(2.)
        PTPHI = 180.+36.+PENTNUM*72.
       ENDIF
*
*WL replace sind cosd with sin cos 
       RP(1,1) =  COS(dtor*PTTHETA)*COS(dtor*PTPHI)
       RP(2,1) =  COS(dtor*PTTHETA)*SIN(dtor*PTPHI)
       RP(3,1) = -SIN(dtor*PTTHETA)
       RP(1,2) = -SIN(dtor*PTPHI)
       RP(2,2) =  COS(dtor*PTPHI)
       RP(3,2) =  0.
       RP(1,3) =  SIN(dtor*PTTHETA)*COS(dtor*PTPHI)
       RP(2,3) =  SIN(dtor*PTTHETA)*SIN(dtor*PTPHI)
       RP(3,3) =  COS(dtor*PTTHETA)
*
       DO CTYPE = 0,NC
*
        DO M = 0,NUMGROUP(CTYPE)-1
*
         CNUM = M*10+PENTNUM
*
*  RH is the rotation matrix to place a crystal relative to the PENT it
*  is associated with. 
*  A rotation of HXPHI about the z-axis (which will be the PENT axis) 
*  is performed followed by a rotation of HXTHETA about the new y-axis.
*  (for the case of the PENT this is the unit matrix)
*
         HXPHI = -HXPHI_O(CTYPE)+(M*72.+36.)
         HXTHETA = -HXTHETA_O(CTYPE)
*
         IF (CTYPE.EQ.4) THEN
          IF (M.EQ.0) THEN
           HXPHI = HXPHI+72.
          ELSEIF (M.EQ.1) THEN
           HXPHI = HXPHI-(HXPHI_O(5)-HXPHI_O(6))
          ELSEIF (M.EQ.2) THEN
           HXPHI = HXPHI
          ELSEIF (M.EQ.3) THEN
           HXPHI = HXPHI-(HXPHI_O(5)-HXPHI_O(6)) 
          ENDIF
         ELSEIF (CTYPE.EQ.7) THEN
           HXPHI = HXPHI+(HXPHI_O(7)-HXPHI_O(8))
         ELSEIF (CTYPE.EQ.8) THEN
           HXPHI = HXPHI+(HXPHI_O(8)-HXPHI_O(7))
         ENDIF
*
	 IF (PENTNUM.GE.5) THEN
          HXPHI = -HXPHI
	  HXTHETA = -HXTHETA
	 ENDIF
*
*WL replace SIND COSD with SIN AND COS
         RH(1,1) =  COS(dtor*HXTHETA)*COS(dtor*HXPHI)
         RH(2,1) =  COS(dtor*HXTHETA)*SIN(dtor*HXPHI)
         RH(3,1) = -SIN(dtor*HXTHETA)
         RH(1,2) = -SIN(dtor*HXPHI)
         RH(2,2) =  COS(dtor*HXPHI)
         RH(3,2) =  0.
         RH(1,3) =  SIN(dtor*HXTHETA)*COS(dtor*HXPHI)
         RH(2,3) =  SIN(dtor*HXTHETA)*SIN(dtor*HXPHI)
         RH(3,3) =  COS(dtor*HXTHETA)
*
*  A 90 deg rotation is performed on all crystals about their 
*  central axis (the final z-axis) so that they fit properly.
*  An additional rotation is performed on the full and half 
*  HEXDs and VETOs.
*
         HDPHI = -90.
*
         IF (PENTNUM.LT.5) THEN
          IF (CTYPE.LT.4) THEN
            HDPHI =  HDPHI
          ELSEIF (CTYPE.EQ.4) THEN
           IF (M.EQ.0) THEN
            HDPHI =  HDPHI-HDPHI_O(4)
           ELSEIF (M.EQ.1) THEN
            HDPHI = -HDPHI-HDPHI_O(5)
           ELSEIF (M.EQ.2) THEN
            HDPHI =  HDPHI-HDPHI_O(4)
           ELSEIF (M.EQ.3) THEN
            HDPHI = -HDPHI-HDPHI_O(5)
           ENDIF
          ELSEIF (CTYPE.EQ.5) THEN
            HDPHI =  HDPHI-HDPHI_O(5)
          ELSEIF (CTYPE.EQ.6) THEN
            HDPHI =  HDPHI-HDPHI_O(6)
          ELSEIF (CTYPE.EQ.7) THEN
            HDPHI = -HDPHI+HDPHI_O(7)
          ELSEIF (CTYPE.EQ.8) THEN
            HDPHI = -HDPHI+HDPHI_O(8)
          ENDIF
         ELSE
          IF (CTYPE.LT.4) THEN
            HDPHI = -HDPHI
          ELSEIF (CTYPE.EQ.4) THEN
           IF (M.EQ.0) THEN
            HDPHI =  HDPHI+HDPHI_O(4)
           ELSEIF (M.EQ.1) THEN
            HDPHI = -HDPHI+HDPHI_O(5)
           ELSEIF (M.EQ.2) THEN
            HDPHI =  HDPHI+HDPHI_O(4)
           ELSEIF (M.EQ.3) THEN
            HDPHI = -HDPHI+HDPHI_O(5)
           ENDIF
          ELSEIF (CTYPE.EQ.5) THEN
            HDPHI = -HDPHI+HDPHI_O(5)
          ELSEIF (CTYPE.EQ.6) THEN
            HDPHI = -HDPHI+HDPHI_O(6)
          ELSEIF (CTYPE.EQ.7) THEN
            HDPHI =  HDPHI-HDPHI_O(7)
          ELSEIF (CTYPE.EQ.8) THEN
            HDPHI =  HDPHI-HDPHI_O(8)
          ENDIF
         ENDIF
*
*WL replace COSD and SIND with COS & SIN
         RD(1,1) =  COS(dtor*HDPHI)
         RD(2,1) =  SIN(dtor*HDPHI)
         RD(3,1) =  0.
         RD(1,2) = -SIN(dtor*HDPHI)
         RD(2,2) =  COS(dtor*HDPHI)
         RD(3,2) =  0.
         RD(1,3) =  0.
         RD(2,3) =  0.
         RD(3,3) =  1.
*
*  The rotational matrix for each crystal formed by:
*    1) rotating the PENT into its proper place -- [RP]
*    2) then rotating the crystal about that PENT -- [RH]
*    3) correcting the HEXD's -- [RD]
*  Thus, the total rotation matrix is  [RT] = [RP] [RH] [RD] 
*
         DO I = 1,3
          DO J = 1,3
           RF(I,J) = RH(I,1)*RD(1,J)+RH(I,2)*RD(2,J)
     +             + RH(I,3)*RD(3,J)
          END DO
         END DO
*
         DO I = 1,3
          DO J = 1,3
           RT(I,J) = RP(I,1)*RF(1,J)+RP(I,2)*RF(2,J)
     +             + RP(I,3)*RF(3,J)
          END DO
         END DO
*
*  For the mirror crystals, the half Ds and VETOs must be exchanged
*  with their mirror symmetry crystal.
*
	 IF (PENTNUM.LT.5) THEN
           CTYPE_MOD = CTYPE
         ELSE
          IF (CTYPE.LT.5) THEN
           CTYPE_MOD = CTYPE
          ELSEIF (CTYPE.EQ.5) THEN
           CTYPE_MOD = 6     
          ELSEIF (CTYPE.EQ.6) THEN
           CTYPE_MOD = 5     
          ELSEIF (CTYPE.EQ.7) THEN
           CTYPE_MOD = 8     
          ELSEIF (CTYPE.EQ.8) THEN
           CTYPE_MOD = 7     
	  ENDIF
         ENDIF
*
         DO I = 1,3 
*
*  Find the rotational paramiters for crystals
*
*WL replace ACOSD & ASIND with ACOS & ASIN
          ROT(CTYPE_MOD,CNUM,2*I-1) = REAL((1/dtor)*ACOS(RT(3,I)))
*
          ROT(CTYPE_MOD,CNUM,2*I) = REAL((1/dtor)*ASIN(RT(2,I)
     +                          /SQRT(RT(1,I)**2+RT(2,I)**2)))
          IF (RT(1,I).LT.0.) THEN
           ROT(CTYPE_MOD,CNUM,2*I) = 180.-ROT(CTYPE_MOD,CNUM,2*I)
          ELSEIF (RT(2,I).LT.0.) THEN
           ROT(CTYPE_MOD,CNUM,2*I) = 360.+ROT(CTYPE_MOD,CNUM,2*I)
          ENDIF
*
*  Find the position of the crystals 
*
          POS(CTYPE_MOD,CNUM,I) = REAL(CRYSTAL_CENTER*RT(I,3))
*
         END DO
*
        END DO
       END DO
*
      END DO
**********************************************************************
*  Write Data to file
**********************************************************************
*
       DO CTYPE = 0,NC
        WRITE (5,2300)
        DO CNUM =0,CNUMMAX(CTYPE)-1
          WRITE (5,2310) CNAME(CTYPE),CNUM,
     +                   ROT(CTYPE,CNUM,1),ROT(CTYPE,CNUM,2),
     +                   ROT(CTYPE,CNUM,3),ROT(CTYPE,CNUM,4),
     +                   ROT(CTYPE,CNUM,5),ROT(CTYPE,CNUM,6)
          CSITHT((CRYSTALID(CTYPE,CNUM)))=ROT(CTYPE,CNUM,5)
          CSIPHI((CRYSTALID(CTYPE,CNUM)))=ROT(CTYPE,CNUM,6)
        END DO
       END DO
*
       DO CTYPE = 0,NC
        WRITE (5,2400)
        DO CNUM =0,CNUMMAX(CTYPE)-1
          WRITE (5,2410) CNAME(CTYPE),CNUM,
     +                   POS(CTYPE,CNUM,1),POS(CTYPE,CNUM,2),
     +                   POS(CTYPE,CNUM,3)
        END DO
       END DO
*
**********************************************************************
*
 2300 FORMAT (/'NAME',T10,'XTH',T22,'XPH',T34,'YTH',T46,'YPH',
     +        T58,'ZTH',T70,'ZPH')
 2310 FORMAT (A4,I2,6F12.5)
 2400 FORMAT (/'CNUM',T10,'POSX',T22,'POSY',T34,'POSZ')
 2410 FORMAT (A4,I2,3F12.5)
 2500 FORMAT (/A4,I2,T15,'PTPHI = ',F8.2,T40,'PTTHETA = ',F8.2,
     +        / '     |',3F8.5,T32,'|'
     +        / 'RP = |',3F8.5,T32,'|'
     +        / '     |',3F8.5,T32,'|')
 2600 FORMAT (/A4,I2,T15,'HXPHI = ',F8.2,T40,'HXTHETA = ',F8.2,
     +        / '     |',3F8.5,T32,'|'
     +        / 'RT = |',3F8.5,T32,'|'
     +        / '     |',3F8.5,T32,'|')
 2700 FORMAT (/'GVERT',/T10,'MATERIAL = ',I3,T35,'SIDE = ',
     +        I3,T60,'CTYPE = ',I3)
 2705 FORMAT (/'CTYPE',T10,'XBOT',T22,'YBOT',T34,'ZBOT',
     +                 T46,'XTOP',T58,'YTOP',T70,'ZBOT')
 2710 FORMAT (I3,6F12.5)
 2800 FORMAT (/'RVERT',/T10,'MATERIAL = ',I3,T35,'SIDE = ',
     +        I3,T60,'CTYPE = ',I3)
 2805 FORMAT (/'CTYPE',T10,'XBOT',T22,'YBOT',T34,'ZBOT',
     +                 T46,'XTOP',T58,'YTOP',T70,'ZBOT')
 2810 FORMAT (I3,6F12.5)
*
**********************************************************************
      END






