**********************************************************************
*     Subroutine to draw one CsI crystal alone at the origin of 'CALO'.
*     This subroutine is called when RAN_VOL flag > 0 in 'geant.inp'.
*     RAN_VOL = (1:240) for crystals, or (888) to draw an arbitrary 
*     user-defined volume, whose parameters and shape are defined in 
*     this subroutine.  RAN_VOL is also consistent with the 'YEAR' 
*     specific set-up.  For example, if RAN_VOL=9 and IYEAR=1996, then 
*     no crystal will be drawn because there was no crystal in GEANT 
*     position #9 in 1996.  Non-uniformities and photo-electron statistics 
*     will also be included in the energy tracking, if the appropriate flag 
*     is on in 'geant.inp'.  Teflon and mylar wrappings will be included if 
*     those flags are on in 'geant.inp'.  Energy tracking output appears 
*     in the usual 'geant.rz' file for the crystals, but is not yet com-
*     pleted for the arbitrary user-defined volume.  
*
*     Created 27FEB97 PLS
**********************************************************************
*
      SUBROUTINE DRAW_ONE_CRYSTAL
*
      IMPLICIT NONE
*
      include 'common.inc'
      include 'geometry/cryscommon.inc'
*
      INTEGER WROTNUM,I,ISTATUS,J,K,L
      INTEGER WMED(NM) 
      REAL*4 RANVOL(3), OUT_MAT(3,3)
      REAL*4  CALO(6)
      REAL*4  CONE_PARAM(5)
      REAL*4  TRAP_PARAM(11)
      REAL*4 THT(3)
      REAL*4 PHY(3)
      REAL*4 AX,AY,AZ,Y_OFF,Z_OFF,PI 
      REAL*4 SINTH,COSTH,SINPH,COSPH
      LOGICAL ROTATE
      PARAMETER(PI=3.1415926) 
*
      WMED(1) = MED_CSI
      WMED(2) = MED_TEFLON
      WMED(3) = MED_MYLAR
      WMED(4) = MED_BKPAPER
      WMED(5) = MED_PLASTIC
*
      DATA RANVOL /10.0,2.0,15.0/
*
* Turn off all CsI crystals.
      DO I=1,240
        ON_CSI_G(I)=0
      ENDDO

      IF (RAN_VOL.NE.888) THEN  ! If not the user-defined vol.	      
*
* Turn on the one crystal specified in geant.inp
*
      IF     (IYEAR.EQ.1993) THEN
         ON_CSI_G(RAN_VOL)=ON_1993CSI_G(RAN_VOL)
      ELSEIF (IYEAR.EQ.1994) THEN
         ON_CSI_G(RAN_VOL)=ON_1994CSI_G(RAN_VOL)
      ELSEIF (IYEAR.EQ.1995) THEN
         ON_CSI_G(RAN_VOL)=ON_1995CSI_G(RAN_VOL)
      ELSEIF (IYEAR.EQ.1996) THEN
         ON_CSI_G(RAN_VOL)=ON_1996CSI_G(RAN_VOL)
      ELSEIF (IYEAR.EQ.1997) THEN
         ON_CSI_G(RAN_VOL)=ON_1997CSI_G(RAN_VOL)
      ELSEIF (IYEAR.EQ.1998) THEN
         ON_CSI_G(RAN_VOL)=RAN_VOL
      ELSE
         PAUSE
      ENDIF
*
***********************************************************************
*                          DEFINE CALO
**********************************************************************
*
      DATA CALO/0.,50.,0.,180.,0.,360./
      CALL GSVOLU ('CALO','SPHE',MED_AIR,CALO,6,ISTATUS)
      CALL GSPOS ('CALO',1,'MAMA',0.,0.,0.,0,'MANY')
*
**********************************************************************
*                DEFINE MOTHER VOLUMES FOR CTYSTALS
**********************************************************************
*
       DO CTYPE = 0,8
        DO I = 1,5
         CONE_PARAM(I) = CRYS(CTYPE,I)
        END DO
        CALL GSVOLU (CNAME(CTYPE),'CONE',MED_AIR,CONE_PARAM,
     +                 5,ISTATUS)
        CALL GSVOLU (CNAMEDUM(CTYPE),'CONE',MED_AIR,CONE_PARAM,
     +               5,ISTATUS)
       END DO
*
**********************************************************************
*
**********************************************************************
*              POSITION CRYSTAL MOTHER VOLUMES IN CALO
*
*  The rotation lables for the crystals go from 1 to 240 since zero
*  is reserved for the identity rotation matrix
**********************************************************************
*
      DO CTYPE = 0,NC
        Z_OFF=0.
        Y_OFF=0.
*
* Define rotation angles to position crystal with side "C" on floor.
*
* First, initialize rotation matrix to "1".
        DO K=1,3
          DO L=1,3
            IF (L.EQ.K) THEN
              OUT_MAT(K,L)=1.
            ELSE
              OUT_MAT(K,L)=0. 
            ENDIF
          ENDDO
        ENDDO
*
        IF (CTYPE.EQ.0) THEN ! finished
          AZ=36.
          CALL RASTA_ROTZ(AZ,OUT_MAT)
          AX=5.408
          CALL RASTA_ROTX(AX,OUT_MAT)
          Y_OFF=3.47276
          Z_OFF=-0.3005
        ELSE IF (CTYPE.EQ.1) THEN ! finished
          AX=6.460
          CALL RASTA_ROTX(AX,OUT_MAT)
          Y_OFF=4.1405
          Z_OFF=-0.4341
        ELSE IF (CTYPE.EQ.2) THEN ! finished
          AZ=-90.0-0.61
          CALL RASTA_ROTZ(AZ,OUT_MAT)
          AX=6.949
          CALL RASTA_ROTX(AX,OUT_MAT)
          Y_OFF=4.4744
          Z_OFF=-0.5008 
        ELSE IF (CTYPE.EQ.3) THEN 
          AX=7.047
          CALL RASTA_ROTX(AX,OUT_MAT)
          Y_OFF=4.5412
          Z_OFF=-0.5342
        ELSE IF (CTYPE.EQ.4) THEN 
          AZ=180.+1.57
          CALL RASTA_ROTZ(AZ,OUT_MAT)
          AX=6.8720
          CALL RASTA_ROTX(AX,OUT_MAT)
          Y_OFF=4.4077
          Z_OFF=-0.5008
        ELSE IF (CTYPE.EQ.5) THEN 
          AZ=180.-1.57
          CALL RASTA_ROTZ(AZ,OUT_MAT)
          AX=6.8720
          CALL RASTA_ROTX(AX,OUT_MAT)
          Y_OFF=4.4077
          Z_OFF=-0.5008
        ELSE IF (CTYPE.EQ.6) THEN  
          AZ=180.+1.57
          CALL RASTA_ROTZ(AZ,OUT_MAT)
          AX=6.8720
          CALL RASTA_ROTX(AX,OUT_MAT)
          Y_OFF=4.4077
          Z_OFF=-0.5008
        ELSE IF (CTYPE.EQ.7) THEN
          AZ=180.+1.1318
          CALL RASTA_ROTZ(AZ,OUT_MAT)
          AX=7.8430
          CALL RASTA_ROTX(AX,OUT_MAT)
          Y_OFF=0.
          Z_OFF=0.
        ELSE IF (CTYPE.EQ.8) THEN
          AZ=180.-1.1318
          CALL RASTA_ROTZ(AZ,OUT_MAT)
          AX=7.8430
          CALL RASTA_ROTX(AX,OUT_MAT)
          Y_OFF=0.
          Z_OFF=0.
        ELSE
          PAUSE
        ENDIF
* Calculate angles for Geant rotation matrix. 
        DO 10 J=1,3
          ROWMAT(1)=OUT_MAT(J,1)
          ROWMAT(2)=OUT_MAT(J,2)
          ROWMAT(3)=OUT_MAT(J,3)
          CALL GFANG(ROWMAT,COSTH,SINTH,COSPH,SINPH,ROTATE)
          THT(J)=ATAN2(SINTH,COSTH)
          PHY(J)=ATAN2(SINPH,COSPH) 
          THT(J)=THT(J)*180./3.1415926
          PHY(J)=PHY(J)*180./3.1415926
 10     CONTINUE 
*
       DO CNUM = 0,CNUMMAX(CTYPE)-1
*
        CALL GSROTM (CRYSTALID(CTYPE,CNUM),
     +                 THT(1),PHY(1),
     +                 THT(2),PHY(2),
     +                 THT(3),PHY(3))
        IF ((ON_CSI_G(CRYSTALID(CTYPE,CNUM)).GE.1).AND.
     +        (ON_CSI_G(CRYSTALID(CTYPE,CNUM)).LE.250)) THEN
         CALL GSPOS (CNAME(CTYPE),CNUM,'CALO',0.,
     +               Y_OFF,11.+Z_OFF,
     +               CRYSTALID(CTYPE,CNUM),'ONLY')
        ELSEIF (ON_CSI_G(CRYSTALID(CTYPE,CNUM)).EQ.999) THEN
         CALL GSPOS (CNAMEDUM(CTYPE),CNUM,'CALO',0.,
     +               Y_OFF,11.+Z_OFF,
     +               CRYSTALID(CTYPE,CNUM),'ONLY')
        ENDIF
       END DO
      END DO
*
**********************************************************************
*                        DEFINE VETOCUT
**********************************************************************
*
      DO MAT = 1,5,4
       DO CTYPE = 7,8
        DO I = 1,11
         TRAP_PARAM(I) = WTRAP(MAT,CTYPE,5,I)
        END DO
        CALL GSVOLU (WEDGENAME(MAT,CTYPE,5),'TRAP',MED_AIR,TRAP_PARAM,
     +               11,ISTATUS)
       END DO
      END DO
*
**********************************************************************
*            DEFINE PENT AND HEX CRYSTALS AND WRAPPING
**********************************************************************
*
      DO MAT = 1,5
       DO CTYPE = 0,8
        DO CWEDGE = 1,CWEDGEMAX(CTYPE)
         IF (WEDGENAME(MAT,CTYPE,CWEDGE).NE.'    ') THEN
          DO I = 1,11
           TRAP_PARAM(I) = WTRAP(MAT,CTYPE,CWEDGE,I)
          END DO
          CALL GSVOLU (WEDGENAME(MAT,CTYPE,CWEDGE),'TRAP',WMED(MAT),
     +                 TRAP_PARAM,11,ISTATUS)
         ENDIF
        END DO
       END DO
      END DO
*
**********************************************************************
*         POSITION CRYSTALS AND WRAPPING IN CRYSTAL MOTHERS
*
*  Rotation numbers reserved for wedges go from 1100 to 1499
**********************************************************************
*
      DO MAT = 1,NM
       IF (ON_MAT(MAT).EQ.1) THEN
        DO CTYPE = 0,6
         DO CWEDGE = 1,CWEDGEMAX(CTYPE)
          WROTNUM = 1000+100*MAT+10*CTYPE+CWEDGE
          CALL GSROTM (WROTNUM,WROT(MAT,CTYPE,CWEDGE,1),
     +                         WROT(MAT,CTYPE,CWEDGE,2),
     +                         WROT(MAT,CTYPE,CWEDGE,3),
     +                         WROT(MAT,CTYPE,CWEDGE,4),
     +                         WROT(MAT,CTYPE,CWEDGE,5),
     +                         WROT(MAT,CTYPE,CWEDGE,6))
          IF (MAT.LE.4) THEN
           CALL GSPOS (WEDGENAME(MAT,CTYPE,CWEDGE),1,
     +                 CNAME(CTYPE),
     +                 WPOS(MAT,CTYPE,CWEDGE,1),
     +                 WPOS(MAT,CTYPE,CWEDGE,2),
     +                 WPOS(MAT,CTYPE,CWEDGE,3),
     +                 WROTNUM,'ONLY')
          ELSEIF (MAT.EQ.5) THEN
           CALL GSPOS (WEDGENAME(MAT,CTYPE,CWEDGE),1,
     +                 CNAMEDUM(CTYPE),
     +                 WPOS(MAT,CTYPE,CWEDGE,1),
     +                 WPOS(MAT,CTYPE,CWEDGE,2),
     +                 WPOS(MAT,CTYPE,CWEDGE,3),
     +                 WROTNUM,'ONLY')
          ENDIF
         END DO
        END DO
       ENDIF
      END DO
*
**********************************************************************
*              POSITION VETO WEDGES INSIDE VETOCUT
**********************************************************************
*
       DO CTYPE = 7,8
*
         CALL GSPOS (WEDGENAME(1,CTYPE,5),1,
     +               CNAME(CTYPE),
     +               WPOS(1,CTYPE,CWEDGE,1),
     +               WPOS(1,CTYPE,CWEDGE,2),
     +               WPOS(1,CTYPE,CWEDGE,3),
     +               0,'MANY')
*
         CALL GSPOS (WEDGENAME(5,CTYPE,5),1,
     +               CNAMEDUM(CTYPE),
     +               WPOS(5,CTYPE,CWEDGE,1),
     +               WPOS(5,CTYPE,CWEDGE,2),
     +               WPOS(5,CTYPE,CWEDGE,3),
     +               0,'MANY')
*
        DO MAT = 1,NM
         IF (ON_MAT(MAT).EQ.1) THEN
          DO CWEDGE = 1,4
           WROTNUM = 1000+100*MAT+10*CTYPE+CWEDGE
           CALL GSROTM (WROTNUM,WROT(MAT,CTYPE,CWEDGE,1),
     +                          WROT(MAT,CTYPE,CWEDGE,2),
     +                          WROT(MAT,CTYPE,CWEDGE,3),
     +                          WROT(MAT,CTYPE,CWEDGE,4),
     +                          WROT(MAT,CTYPE,CWEDGE,5),
     +                          WROT(MAT,CTYPE,CWEDGE,6))
           IF (MAT.LE.3) THEN
            CALL GSPOS (WEDGENAME(MAT,CTYPE,CWEDGE),1,
     +                  WEDGENAME(1,CTYPE,5),
     +                  WPOS(MAT,CTYPE,CWEDGE,1),
     +                  WPOS(MAT,CTYPE,CWEDGE,2),
     +                  WPOS(MAT,CTYPE,CWEDGE,3),
     +                  WROTNUM,'MANY')
           ELSEIF (MAT.EQ.5) THEN
            CALL GSPOS (WEDGENAME(MAT,CTYPE,CWEDGE),1,
     +                  WEDGENAME(5,CTYPE,5),
     +                  WPOS(MAT,CTYPE,CWEDGE,1),
     +                  WPOS(MAT,CTYPE,CWEDGE,2),
     +                  WPOS(MAT,CTYPE,CWEDGE,3),
     +                  WROTNUM,'MANY')
           ENDIF
          END DO
         ENDIF
        END DO
*
       END DO
*
**********************************************************************
       ELSE       ! Abitrary user-defined volume.
*
         CALL GSVOLU('RAND','BOX ',10,RANVOL,3,ISTATUS)  
         CALL GSPOS ('RAND',1,'MAMA',0.,0.,0.,0,'ONLY')
*
       ENDIF 
      END
*
***********************************************************************
*
      SUBROUTINE RASTA_ROTX(AX,OUT_MAT)
*     This subroutine produces a rotation about the X-axis. 
      REAL*4 ROTMAT(3,3),IN_MAT(3,3),OUT_MAT(3,3)
      REAL*4 AX
      INTEGER I,J,K
*
*     Convert to radians        
      AX=3.1415926*AX/180.
*
      ROTMAT(1,1)=1
      ROTMAT(1,2)=0
      ROTMAT(1,3)=0
      ROTMAT(2,1)=0
      ROTMAT(2,2)=COS(AX)
      ROTMAT(2,3)=-SIN(AX)
      ROTMAT(3,1)=0
      ROTMAT(3,2)=SIN(AX)
      ROTMAT(3,3)=COS(AX)
*
* Place OUT_MAT matrix into IN_MAT matrix, and zero OUT_MAT.
            DO I=1,3
              DO J=1,3
                IN_MAT(I,J)=OUT_MAT(I,J)
                OUT_MAT(I,J)=0.
              ENDDO
            ENDDO
*
* Do matrix multiplication.
* 
      DO I=1,3
        DO K=1,3
          DO J=1,3
            OUT_MAT(I,K)=OUT_MAT(I,K)+IN_MAT(I,J)*ROTMAT(J,K)
          ENDDO
        ENDDO 
      ENDDO
*
* Convert back to degrees.
      AX=180.*AX/3.1415926
*
      RETURN      
*
      END
*
******************************************************************
*     
      SUBROUTINE RASTA_ROTY(AY,OUT_MAT)
*     This subroutine produces a rotation about the Y-axis.
      REAL*4 ROTMAT(3,3),IN_MAT(3,3),OUT_MAT(3,3)
      REAL*4 AY
      INTEGER I,J,K
*
*     Convert to radians
      AY=3.1415926*AY/180.
*
      ROTMAT(1,1)=COS(AY)
      ROTMAT(1,2)=0
      ROTMAT(1,3)=SIN(AY)
      ROTMAT(2,1)=0
      ROTMAT(2,2)=1
      ROTMAT(2,3)=0
      ROTMAT(3,1)=-SIN(AY)
      ROTMAT(3,2)=0
      ROTMAT(3,3)=COS(AY)
*
* Place OUT_MAT matrix into IN_MAT matrix, and zero OUT_MAT
*
            DO I=1,3
              DO J=1,3
                IN_MAT(I,J)=OUT_MAT(I,J)
                OUT_MAT(I,J)=0.
              ENDDO
            ENDDO
*
* Do matrix multiplication.
*
      DO I=1,3
        DO K=1,3
          DO J=1,3
            OUT_MAT(I,K)=OUT_MAT(I,K)+IN_MAT(I,J)*ROTMAT(J,K)
          ENDDO
        ENDDO
      ENDDO
*
* Convert back to degrees.
      AY=180.*AY/3.1415926
*
      RETURN
*
      END
*
*****************************************************************     
*
      SUBROUTINE RASTA_ROTZ(AZ,OUT_MAT)
*     This subroutine produces a rotation about the Z-axis.
      REAL*4 ROTMAT(3,3),IN_MAT(3,3),OUT_MAT(3,3)
      REAL*4 AZ
      INTEGER I,J,K
*
*     Convert to radians
      AZ=3.1415926*AZ/180.
*
      ROTMAT(1,1)=COS(AZ)
      ROTMAT(1,2)=-SIN(AZ)
      ROTMAT(1,3)=0
      ROTMAT(2,1)=SIN(AZ)
      ROTMAT(2,2)=COS(AZ)
      ROTMAT(2,3)=0
      ROTMAT(3,1)=0
      ROTMAT(3,2)=0
      ROTMAT(3,3)=1
*
* Place OUT_MAT matrix into IN_MAT matrix, then zero OUT_MAT.
            DO I=1,3
              DO J=1,3
                IN_MAT(I,J)=OUT_MAT(I,J)
                OUT_MAT(I,J)=0. 
              ENDDO
            ENDDO
*
* Do matrix multiplication.
*
      DO I=1,3
        DO K=1,3
          DO J=1,3
            OUT_MAT(I,K)=OUT_MAT(I,K)+IN_MAT(I,J)*ROTMAT(J,K)
          ENDDO
        ENDDO
      ENDDO
*
* Convert back to degrees.
      AZ=180.*AZ/3.1415926
*
      RETURN
*
      END

