
	subroutine gen_array()
*
* This subroutine outputs the normal (non-Geant) rotation matrix
* for the placement of the NaI array in Geant.  It also outputs the
* x,y,and z coordinates of the NaI array in the Geant frame.
        integer i,j,k,l,index
        real x(64),y(64),z(64),x0,y0,z0,xg(64),yg(64),zg(64)
	real alpha,d,p,h,y_temp,x_temp,z_temp,pi,x0g,y0g,z0g
	real theta_swing,phi_swing,ry,rx,rz
	real theta_geant(64),phi_geant(64),r_geant(64),r_lab(64)
	real theta_box, phi_box, r_box
        include '../common.inc'

	alpha=180.  ! angle of NaI detector with the -Z axis in the lab frame.
  	d=100. ! (cm) horizontal distance between centers of detectors
	p=6.3   ! (cm) dist between centers of NaI crystals.
	h=0.   ! (cm) vertical separation between sphere and NaI centers
        pi=3.1415926
	theta_swing = 63.4  ! as written in logbook, in degrees.
	phi_swing = 0.0     ! as written in logbook, in degrees.

*
* begin calculations..
	x0=d*cosd(alpha-90.)
	y0=h
 	z0=d*sind(alpha-90.)
        index = 0

	do 45 i=-4,3
          y_temp = y0 + (i+0.5)*p
	  do 44 j=-4,3
            index = index+1 
            x_temp = x0 + (j+0.5)*p*cosd(180-alpha)
	    z_temp = z0 - (j+0.5)*p*sind(180-alpha)
	    x(index) = x_temp	
	    y(index) = y_temp	
	    z(index) = z_temp	
 44       continue
 45 	continue

* First, initialize rotation matrix to "1".
        DO K=1,3
          DO L=1,3
            IF (L.EQ.K) THEN
              OUT_MAT(K,L)=1.
            ELSE
              OUT_MAT(K,L)=0.
            ENDIF
          ENDDO
        ENDDO

***************** ROTATION MATRIX CONSTRUCTION ******************
** Warning:  these rotations happen in the reverse order as entered.
*
*   Rotate the NaI about the y-axis. ('theta' in swing lingo.)
       ry= -180.-theta_swing
       CALL ROTY(RY,OUT_MAT)
*
**   Rotate the NaI about the x-axis. ('phi' in swing language)
        rx= -phi_swing
       CALL ROTX(RX,OUT_MAT)
*
**  Rotate the NaI about the Z-axis for (Geant sys --> lab sys.)
        rz=-90.  ! All runs.
       CALL ROTZ(RZ,OUT_MAT)
*
*************** END ROTATION MATRIX CONTRUCTION *****************

* Transform lab coord's of NaI BOX to geant frame.
	x0g=out_mat(1,1)*x0+out_mat(1,2)*y0+out_mat(1,3)*z0
	y0g=out_mat(2,1)*x0+out_mat(2,2)*y0+out_mat(2,3)*z0
	z0g=out_mat(3,1)*x0+out_mat(3,2)*y0+out_mat(3,3)*z0

* Find theta, phi, and r of NaI box in geant.
	r_box = (x0g**2+y0g**2+z0g**2)**0.5
	call calc_theta(x0g,y0g,z0g,theta_box)
	call calc_phi(x0g,y0g,z0g,phi_box)
	print *, 'theta and phi of NaI box are', theta_box,phi_box
	print *, 'r of box is ', r_box


* Transform lab coord's of xtals to geant frame, using rotation matrix.
	do 77 i=1,64
          xg(i)=out_mat(1,1)*x(i)+out_mat(1,2)*y(i)+out_mat(1,3)*z(i)
          yg(i)=out_mat(2,1)*x(i)+out_mat(2,2)*y(i)+out_mat(2,3)*z(i)
          zg(i)=out_mat(3,1)*x(i)+out_mat(3,2)*y(i)+out_mat(3,3)*z(i)
          r_geant(i)=(xg(i)**2.+yg(i)**2.+zg(i)**2.)**0.5
	  r_lab(i) = (x(i)**2.+y(i)**2.+z(i)**2.)**0.5
*         Find theta and phi of each NaI crystal
          call calc_theta(xg(i),yg(i),zg(i),theta_geant(i))
          call calc_phi(xg(i),yg(i),zg(i),phi_geant(i)) 
 77 	continue ! with transformation, crystal by crystal.

* Now make a rotation matrix for the NaI box.
* First, initialize rotation matrix to "1".
        DO K=1,3
          DO L=1,3
            IF (L.EQ.K) THEN
              OUT_MAT(K,L)=1.
            ELSE
              OUT_MAT(K,L)=0.
            ENDIF
          ENDDO
        ENDDO

***************** ROTATION MATRIX CONSTRUCTION ******************
** Warning:  these rotations happen in the reverse order as entered.
*
**  Rotate the NaI box about the z-axis
        rz=phi_box
       CALL ROTZ(RZ,OUT_MAT)

*   Rotate the NaI box about the y-axis.
       ry= theta_box
       CALL ROTY(RY,OUT_MAT)
*
c construct geant rotation from normal rotation matrix (out_mat)
      do 10 i=1,3
        rowmat(1)=out_mat(i,1)
        rowmat(2)=out_mat(i,2)
        rowmat(3)=out_mat(i,3)
        call GFANG(rowmat,box_costh,box_sinth,box_cosph,
     +        box_sinph,rotate)
        box_theta(i)=atan2(box_sinth,box_costh)
        box_phi(i)=atan2(box_sinph,box_cosph)
        box_theta(i)=box_theta(i)*3.1415926/180.
        box_phi(i)=box_phi(i)*3.1415926/180.
 10   continue

        end			! gen_array subroutine
************************************************************************

*
      SUBROUTINE ROTX(AX,OUT_MAT)
*     This subroutine produces a rotation about the X-axis.
      real ROTMAT(3,3),IN_MAT(3,3),OUT_MAT(3,3)
      real AX
      real PI
      INTEGER I,J,K
*
*     Convert to radians
      PI=3.14159265359
      AX=PI*AX/180.
*
      ROTMAT(1,1)=1
      ROTMAT(1,2)=0
      ROTMAT(1,3)=0
      ROTMAT(2,1)=0
      ROTMAT(2,2)=COS(AX)
      ROTMAT(2,3)=-SIN(AX)
      ROTMAT(3,1)=0
      ROTMAT(3,2)=SIN(AX)
      ROTMAT(3,3)=COS(AX)
*
* Place OUT_MAT matrix into IN_MAT matrix, and zero OUT_MAT.
            DO I=1,3
              DO J=1,3
                IN_MAT(I,J)=OUT_MAT(I,J)
                OUT_MAT(I,J)=0.
              ENDDO
            ENDDO
*
* Do matrix multiplication.
*
      DO I=1,3
        DO K=1,3
          DO J=1,3
            OUT_MAT(I,K)=OUT_MAT(I,K)+IN_MAT(I,J)*ROTMAT(J,K)
          ENDDO
        ENDDO
      ENDDO
*
* Convert back to degrees.
      AX=180.*AX/PI
*
      RETURN
*
      END
*
******************************************************************
*
      SUBROUTINE ROTY(AY,OUT_MAT)
*     This subroutine produces a rotation about the Y-axis.
      real ROTMAT(3,3),IN_MAT(3,3),OUT_MAT(3,3)
      real AY
      INTEGER I,J,K
      real PI
*
*     Convert to radians
      PI=3.14159265359 
      AY=PI*AY/180.
*
      ROTMAT(1,1)=COS(AY)
      ROTMAT(1,2)=0
      ROTMAT(1,3)=SIN(AY)
      ROTMAT(2,1)=0
      ROTMAT(2,2)=1
      ROTMAT(2,3)=0
      ROTMAT(3,1)=-SIN(AY)
      ROTMAT(3,2)=0
      ROTMAT(3,3)=COS(AY)
*
* Place OUT_MAT matrix into IN_MAT matrix, and zero OUT_MAT
*

            DO I=1,3
              DO J=1,3
                IN_MAT(I,J)=OUT_MAT(I,J)
                OUT_MAT(I,J)=0.
              ENDDO
            ENDDO

*
* Do matrix multiplication.
*
      DO I=1,3
        DO K=1,3
          DO J=1,3
            OUT_MAT(I,K)=OUT_MAT(I,K)+IN_MAT(I,J)*ROTMAT(J,K)
          ENDDO
        ENDDO
      ENDDO

*
* Convert back to degrees.
      AY=180.*AY/PI

*
      RETURN
*
      END
*
*****************************************************************
*
      SUBROUTINE ROTZ(AZ,OUT_MAT)
*     This subroutine produces a rotation about the Z-axis.
      real ROTMAT(3,3),IN_MAT(3,3),OUT_MAT(3,3)
      real AZ
      INTEGER I,J,K
      real PI
*
*     Convert to radians
      PI=3.14159265359
      AZ=PI*AZ/180.
*
      ROTMAT(1,1)=COS(AZ)
      ROTMAT(1,2)=-SIN(AZ)
      ROTMAT(1,3)=0
      ROTMAT(2,1)=SIN(AZ)
      ROTMAT(2,2)=COS(AZ)
      ROTMAT(2,3)=0
      ROTMAT(3,1)=0
      ROTMAT(3,2)=0
      ROTMAT(3,3)=1
*
* Place OUT_MAT matrix into IN_MAT matrix, then zero OUT_MAT.
            DO I=1,3
              DO J=1,3
                IN_MAT(I,J)=OUT_MAT(I,J)
                OUT_MAT(I,J)=0.
              ENDDO
            ENDDO
*
* Do matrix multiplication.
*
      DO I=1,3
        DO K=1,3
          DO J=1,3
            OUT_MAT(I,K)=OUT_MAT(I,K)+IN_MAT(I,J)*ROTMAT(J,K)
          ENDDO
        ENDDO
      ENDDO
*
* Convert back to degrees.
      AZ=180.*AZ/PI
*
      RETURN
*
      END
********************************************************************
	SUBROUTINE CALC_THETA(x,y,z,theta)
        real pi,x,y,z,theta
        pi = 3.1415926

       if ((z.ne.0).and.((x**2+y**2)**0.5.ne.0)) then
         theta=atan((x**2+y**2)**0.5/z)
         if (z.lt.0) then
           theta=theta+pi
         endif
       else
         if (z.eq.0) then
           if ((x**2+y**2)**0.5.ne.0) then
             theta=pi/2
           else
             theta=0
           endif
         else
           if (z.gt.0) then
             theta=0
           else
             theta=pi
           endif
         endif
       endif
       theta=180*theta/pi
	END

********************************************************************

	SUBROUTINE CALC_PHI(x,y,z,phi)
        real pi,x,y,z,phi
	pi = 3.1415926

       if ((x.ne.0).and.(y.ne.0)) then
         phi=atan(y/x)
         if ((x.lt.0).and.(y.gt.0)) then
           phi=phi+pi
         endif
         if ((x.lt.0).and.(y.lt.0)) then
           phi=phi+pi
         endif
         if ((x.gt.0).and.(y.lt.0)) then
           phi=phi+2*pi
         endif
       else
         if (y.eq.0) then
           if (x.ge.0) then
             phi=0.
           else
             phi=pi
           endif
         else
           if (y.gt.0) then
             phi=pi/2
           else
             phi=3*pi/2
           endif
         endif
       endif
       phi=180.*phi/pi
	END


	
