************************************************************************    
*
       SUBROUTINE NTP150
*
*      History
*      -------
*
*      27OCT95 SR created
*      20NOV96 TF update (approximation to ntp101.f)
*
*      Contents
*      --------
*
*      This routines books the Column-Wise N-Tuple #150
*
************************************************************************    
*
      IMPLICIT NONE

      INCLUDE '../common.inc'

*
*       Define /EVENTINFO/ common block. This block contains all
*       information about the current event obtained during event
*       generation and tracking except those variables which can
*       be obtained online during the experiment (they will go
*       into /EVENTDATA/)
*
*       A common block /ADDITIONS/ was added to fulfill the needs of
*       1996 data analysis 
*

      INTEGER NR_
      REAL TB_
      REAL      IP(3),V(3)
     +         ,PX(3),PY(3),PZ(3),T(3)
           
      COMMON /EVENTINFO/ NR_,TB_     
     +                ,IP,V
     +                ,PX,PY,PZ,T
          
*
*       Define maximum array sizes for /EVENTDATA/ common block
*
*       CAL    : 220 calorimeter CsI modules
*       CAV    : 20 calorimeter veto modules
*       PLVETO : 20 plastic veto staves
*       TARG   : 69 active target fibers
*       COSV   : 5 cosmic veto planes
*       MWPC   : up to 50 multi-wire-proportional-chamber hits (ADC+Wire)
*       CLUS   : 8 cluster
*
*       Target will be reduced to 3 entries (degr;target;tv)
*       TARG(1)=TGT,TARG(2)=DEGR,TARG(3)=TARV (IDTYPES: 261,330,499)

      INTEGER MAXCAL, MAXCALV, MAXPLVETO, MAXTARG, MAXCV
      PARAMETER(MAXCAL=220, MAXCALV=20, MAXTARG=3, MAXCV=5)
      INTEGER MAXMWPC, MAXCLUS
      PARAMETER(MAXMWPC=50, MAXCLUS=8)

      INTEGER MAXPV
      PARAMETER(MAXPV=20)

      INTEGER MAXNai
      PARAMETER(MAXNai=64)

*
*       Define variable arrays for detectors
*
*       Nxxx   : number of valid entries in arrays
*       Cxxx   : numbers of fired channels
*       Exxx   : energy (ADC-value) of fired channels
*       Txxx   : timing (TDC-value) of fired channels
*
*       NAMWPCx : number of cathode hits in MWPC
*       NWMWPCx : number of hit anode wires
*       CAMWPCx : channel numbers of fired cathode ADCs
*       AMMWPCx : energy (ADC-value) of fired cathode strips
*       WMWPC1x : wire numbers of fired wires
*
*       NCLUSL  : number of fired clusters - low threshold
*       CCLUSL  : channel number of fired clusters
*       TCLUSL  : timing (TDC-value) of fired clusters
*
*       NCLUSH  : same for high threshold
*

      INTEGER NCAL, CCAL, NCALV, CCALV, NTARG, CTARG, NCOSV, CCOSV
      REAL ECAL, TCAL, ECALV, TCALV, ETARG, TTARG, ECOSV, TCOSV
      INTEGER NAMWPC1, NWMWPC1, CAMWPC1, AMWPC1, WMWPC1
      INTEGER NAMWPC2, NWMWPC2, CAMWPC2, AMWPC2, WMWPC2
      INTEGER NCLUSL, CCLUSL, NCLUSH, CCLUSH
      REAL TCLUSL, TCLUSH

      COMMON /EVENTDATA/
     + NCAL, CCAL(MAXCAL), ECAL(MAXCAL), TCAL(MAXCAL),       
     + NCALV, CCALV(MAXCALV), ECALV(MAXCALV), TCALV(MAXCALV),
     + NTARG, CTARG(MAXTARG), ETARG(MAXTARG), TTARG(MAXTARG),
     + NCOSV, CCOSV(MAXCV), ECOSV(MAXCV), TCOSV(MAXCV)
*
*     + NAMWPC1, NWMWPC1, CAMWPC1(MAXMWPC), AMWPC1(MAXMWPC), WMWPC1(50),
*     + NAMWPC2, NWMWPC2, CAMWPC2(MAXMWPC), AMWPC2(MAXMWPC), WMWPC2(50),
*
*     + ,NCLUSL, CCLUSL(MAXCLUS), TCLUSL(MAXCLUS),
*     + NCLUSH, CCLUSH(MAXCLUS), TCLUSH(MAXCLUS)

      INTEGER NPVET,CPVET 
      REAL EPVET,TPVET,etot,e_track,Weight,MESquare


      COMMON /ADDITIONS/
     + NPVET, CPVET(MAXPV), EPVET(MAXPV), TPVET(MAXPV)       
     +, etot, e_track(3),Weight,MEsquare     

      INTEGER NNAI,CNAI
      REAL ENAI,TNAI,etotNAI,enaipvet

     
      COMMON /NaI/
     + NNAI, CNAI(MAXNAI), ENAI(MAXNAI), TNAI(MAXNAI)       
     +, etotNAI,enaipvet

    

*
*       Column-wise Ntuple Booking
*

      print *,'start booking'
       
      CALL hbook2(98,'thet pos',100,90.,140.,66,0.,65.,0.)
      CALL hbook2(99,'phi pos',140,320.,390.,66,0.,65.,0.)
*      CALL HBNT(151,'NaI Angles',' ')
      CALL HBNT(150,'True Single Events',' ')

*
*       Define /EVENTINFO/ block
*

      
*      CALL HBNAME(151,'NaI_temp',naimax,'naimax','thet_thr','phi_thr') 
      CALL HBNAME(150, 'EVNTINFO', NR_, 
     +   'NR:I, TINC:R'//
     +   ',IP(3):I,V(3)'//
     +   ',PX(3),PY(3),PZ(3),T(3)')


*
*         Define /EVENTDATA/ block
*

      CALL HBNAME(150,'EVNTDATA',NCAL,
     + 'NCAL[0,220]:I, CCAL(NCAL):I,ECAL(NCAL):R,TCAL(NCAL):R,'//
     + 'NCALV[0,20]:I, CCALV(NCALV):I,ECALV(NCALV):R,TCALV(NCALV):R,'//
     + 'NTARG[0,3]:I, CTARG(NTARG):I,ETARG(NTARG):R,TTARG(NTARG):R,'//
     + 'NCOSV[0,5]:I, CCOSV(NCOSV):I,ECOSV(NCOSV):R,TCOSV(NCOSV):R')

*
*     + 'NAMWPC1[0,50]:I, NWMWPC1[0,50]:I, CAMWPC1(NAMWPC1):I,'//
*     + 'AMWPC1(NAMWPC1):R, WMWPC1(NWMWPC1):R,'//
*
*     + 'NAMWPC2[0,50]:I, NWMWPC2[0,50]:I, CAMWPC2(NAMWPC1):I,'//
*     + 'AMWPC2(NAMWPC1):R, WMWPC2(NWMWPC1):R,'//
*
*     + ',NCLUSL[0,8]:I, CCLUSL(NCLUSL):I, TCLUSL(NCLUSL):R,'//
*     + 'NCLUSH[0,8]:I, CCLUSH(NCLUSH):I, TCLUSH(NCLUSH):R')

*      CALL HBNAME(150,'ADDITION',NPVET,
*     + 'NPVET[0,20]:I, CPVET(NPVET):I,EPVET(NPVET):R,TPVET(NPVET):R'//
*     + ',ETOT,E_TRACK(3),WT,SQME')

      IF (ISWIT(1).EQ.1997) THEN
      CALL HBNAME(150,'NAI',NNAI,
     + 'NNAI[0,64]:I, CNAI(NNAI):I,ENAI(NNAI):R,TNAI(NNAI):R'//
     + ',ETOTNAI')
      ENDIF
      
       print *,'ntuple booked'
      return
      END   

************************************************************************    
*
       SUBROUTINE FILL150
*
*
*      History
*      -------
*
*      27OCT95 ST created
*
*      Contents
*      --------
*
*      Fill N-Tuple #150
*
************************************************************************    
*
      IMPLICIT NONE

      INCLUDE '../common.inc'

*--------
      INTEGER NR_
      REAL TB_
      REAL     thet_throw,phi_throw,naimax,e_
      REAL      IP(3),V(3)
     +         ,PX(3),PY(3),PZ(3),T(3)

      COMMON /EVENTINFO/ NR_,TB_     
     +                ,IP,V
     +                ,PX,PY,PZ,T
     
*--------
      INTEGER MAXCAL, MAXCALV, MAXPLVETO, MAXTARG, MAXCV
      PARAMETER(MAXCAL=220, MAXCALV=20, MAXTARG=3, MAXCV=5)
      INTEGER MAXMWPC, MAXCLUS
      PARAMETER(MAXMWPC=50, MAXCLUS=8)

      INTEGER MAXPV
      PARAMETER(MAXPV=20)

      INTEGER MAXNai
      PARAMETER(MAXNai=64)


      INTEGER NCAL, CCAL, NCALV, CCALV, NTARG, CTARG, NCOSV, CCOSV
      REAL ECAL, TCAL, ECALV, TCALV, ETARG, TTARG, ECOSV, TCOSV
      INTEGER NAMWPC1, NWMWPC1, CAMWPC1, AMWPC1, WMWPC1
      INTEGER NAMWPC2, NWMWPC2, CAMWPC2, AMWPC2, WMWPC2
      INTEGER NCLUSL, CCLUSL, NCLUSH, CCLUSH
      REAL TCLUSL, TCLUSH

      COMMON /EVENTDATA/
     + NCAL, CCAL(MAXCAL), ECAL(MAXCAL), TCAL(MAXCAL),       
     + NCALV, CCALV(MAXCALV), ECALV(MAXCALV), TCALV(MAXCALV),
     + NTARG, CTARG(MAXTARG), ETARG(MAXTARG), TTARG(MAXTARG),
     + NCOSV, CCOSV(MAXCV), ECOSV(MAXCV), TCOSV(MAXCV)
*
*     + NAMWPC1, NWMWPC1, CAMWPC1(MAXMWPC), AMWPC1(MAXMWPC), WMWPC1(50),
*     + NAMWPC2, NWMWPC2, CAMWPC2(MAXMWPC), AMWPC2(MAXMWPC), WMWPC2(50),
*
*     + NCLUSL, CCLUSL(MAXCLUS), TCLUSL(MAXCLUS),
*     + NCLUSH, CCLUSH(MAXCLUS), TCLUSH(MAXCLUS)

      INTEGER NPVET,CPVET 
      REAL EPVET,TPVET,etot,e_track,Weight,MEsquare

  
      COMMON /ADDITIONS/
     + NPVET, CPVET(MAXPV), EPVET(MAXPV), TPVET(MAXPV)       
     +,ETOT,e_track(3),Weight,MEsquare

      INTEGER NNAI,CNAI
      REAL ENAI,TNAI,etotNAI,enaipvet

      COMMON /NAI/
     + NNAI, CNAI(MAXNAI), ENAI(MAXNAI), TNAI(MAXNAI)       
     +, etotNAI,Enaipvet


*--------

      INTEGER I,J

*
*       Before the CWNT variables are stored directly in the 
*       /EVENTINFO/ and /EVENTDATA/ common blocks, we have to copy 
*       the relevant information manually
*
    
      etot=0.
      ncal=0

      nnai=0
      etotnai=0.
      enaipvet=0. 

*      call vzero(ncal,848)

*      call vzero(ecal,220)
*      call vzero(ecalv,20)
*      call vzero(tcal,220)
*      call vzero(tcalv,20)
*      call vzero(ccal,220)      
*      call vzero(ccalv,20)
*      call vzero(epvet,20)
*      call vzero(cpvet,20)  
*      call vzero(tpvet,20)
*      call vzero(c


      NR_ = NR
      TB_ = TINC(1)


      Do i=1,3
       IP(i)=IPARTICLE(I)
        V(I)=VERTEX(I)
       PX(I)=PART(1,I,NR)
       PY(I)=PART(2,I,NR)
       PZ(I)=PART(3,I,NR)
        T(I)=PART(4,I,NR)
      ENDDO

       e_track(1)=edepcal1 
       e_track(2)=edepcal2
       e_track(3)=edepcal3 

*---- fill CAL
      J=0
      DO I=1,220
        IF (EDEP(I) .GT. 0) THEN
          J=J+1
          CCAL(J) = I
          ECAL(J) = EDEP(I)
          TCAL(J) = TDEP(I)
          ETOT=ETOT+edep(i)
        ENDIF
      ENDDO
      NCAL=J
*       write(6,'(7f8.3)')
*     +   etot,edepcal,edeptot,edepcal2,edepcal1,t(2)*1000.,t(1)*1000.

*---- fill CALV
      J=0
      DO I=1,20
        IF (EDEP(220+I) .GT. 0) THEN
          J=J+1
          CCALV(J) = I
          ECALV(J) = EDEP(I+220)
          TCALV(J) = TDEP(I+220)
          ETOT=ETOT+EDEP(I+220)
        ENDIF
      ENDDO
      NCALV=J

*---- fill PVET
      J=0
      DO I=1,20
        IF (EDEP(240+I) .GT. 0) THEN
          J=J+1
          CPVET(J) = I
          EPVET(J) = EDEP(I+240)
          TPVET(J) = TDEP(I+240)
        ENDIF
      ENDDO
      NPVET=J
*      print *,'fill the TUPLE !',idevt,NR,etot
*      print *,'j',j 
*      print *,'hfnt',npvet 

*---- fill TARG
*      J=0
*      DO I=1,20
*        IF (EDEP(260+I) .GT. 0) THEN
*          J=J+1
*          CTARG(J) = I
*          ETARG(J) = EDEP(I+260)
*          TTARG(J) = TDEP(I+260)
*        ENDIF
*      ENDDO
*      NTARG=J

*---- fill 1996 TARG
       J=0 
       IF (EDEP(261) .GT. 0) THEN
          J=J+1
          CTARG(1) = 1
          ETARG(1) = EDEP(261)
          TTARG(1) = TDEP(261)
        ENDIF
       IF (EDEP(330) .GT. 0) THEN
          J=J+1
          CTARG(2) = 2
          ETARG(2) = EDEP(330)
          TTARG(2) = TDEP(330)
        ENDIF
       IF (EDEP(499) .GT. 0) THEN
          J=J+1
          CTARG(3) = 3
          ETARG(3) = EDEP(499)
          TTARG(3) = TDEP(499)
        ENDIF
       NTARG=J

*---- fill COSV
      J=0
      DO I=1,5
        IF (EDEP(230+I) .GT. 0) THEN
          J=J+1
          CCOSV(J) = I
          ECOSV(J) = EDEP(I+230)
          TCOSV(J) = TDEP(I+230)
        ENDIF
      ENDDO
      NCOSV=J
*      print *,'fill the TUPLE mor!',idevt,NR,etot
*      print *,'j',j 
*      print *,'hfnt',ncosv 


*---- fill NaI (1997)
  
      IF (ISWIT(1).EQ.1997) THEN 
*       thet_throw=0.
*       phi_throw=0.
*
*       thet_throw=acosd(pz(1)/t(1))
**       phi_throw=acosd(px(1)/t(1)/sin(thet_throw))
*       phi_throw=360.+asind(py(1)/t(1)/sind(thet_throw))
**       phi_throw_ii=360.+atan2d(py(1),px(1))
**	write(6,*) thet_throw,phi_throw

         
       naimax=0
       J=0
        DO I=1,64  ! 400:NaIPVET
         IF (edep(i+400) .GT. 0) THEN
          J=J+1
*          if (edep(i).gt.edep(naimax+400)) 
*     &             naimax=i
          CNAI(J) = NO_1997NAI_G(I)
          ENAI(J) = EDEP(I+400)
          TNAI(J) = TDEP(I+400)
          ETOTNAI=ETOTNAI+edep(i+400)
         ENDIF
        ENDDO
       NNAI=J
*        etotnai=edepnai
*        if (edep(400).gt.0) enaipvet=edep(400)          

*         naimax=no_1997nai_g(naimax+400)-400
*         if (edep(naimax).le.0.) naimax=0

      ENDIF

*       write(6,'(7f8.3)')
*     +   etot,edepcal,edeptot,edepcal2,edepcal1,t(2)*1000.,t(1)*1000.

**********************************************************************
       Weight=WT
       MEsquare=SQME

      CALL HFNT(150)

      RETURN
      END   
