************************************************************************    
*
*       init.f
*
*       Geant initialization, read data cards, book histograms
*
*       History
*       -------
*       16DEC91 KAA created
*       13JUN95 KAA enlarged
*       4AUG95  SR  Added parameter data cards in /GPARAM/
*                   Added variable seed for random generator
*       04OCT95 EF  Put in data cards for new event generators
*       09SEP00 WL  Added more variables for clump            
************************************************************************    
*
      SUBROUTINE UGINIT 
*   
************************************************************************    
*
*       Initialize Geant, read data cards
*
************************************************************************    
*   
      IMPLICIT NONE
      INCLUDE 'common.inc'

      COMMON/HADR_PAR/IGHEISHA
      INTEGER IGHEISHA
      INTEGER I,J,K
      REAL X,Y,Z
      REAL BX,BY
      REAL HRNDM1
c     Teflon wrapping or painted crystals
c      IF (IYEAR.LT.1997) THEN
c         INCLUDE 'databases/calo_data_t.inc' ! teflon
c      ELSE
         INCLUDE 'databases/calo_data_p.inc' ! painted crystals
c      ENDIF

*   
*-----------------------------------------------------------------------
*   
*             Initialize GEANT  
*   
      CALL GINIT    
*
*             Prints version number 
*
      PRINT *, '**** PIBETA Geant Version ',VERSION,' ****'  
*   
*             Read data cards with FFREAD   
*
      PRINT *, '=================================================='
      PRINT *, 'Type in the data cards now, finish with ''STOP'''
      PRINT *, 'Read in ''geant.inp'' with ''READ 4''.'
      PRINT *, ' '
*
*             Open data card file
*
      OPEN(4,FILE='geant.inp',STATUS='UNKNOWN')
*
*    FIX CSI GAINS
* 
      OPEN(21,FILE=
     +'/home/pibeta/geant/databases/csi_gain_rasta.dat',STATUS='OLD')
c      OPEN(21,FILE=
c     +'/home/pibeta/geant/databases/e70+0.dat',STATUS='UNKNOWN')   
c      OPEN(22,FILE=
c     +'/home/pibeta/geant/databases/e70_r.dat',STATUS='UNKNOWN')

c pile-up file, 800k pistops, single random crystal
      OPEN(37,FILE=
     +'/home/pibeta/geant/databases/h294005_800k.txt',STATUS='OLD')
      CALL HBOOK1(294005,'CSI SINGLE ERAND',400,0.,100.,0.)
      DO I=1,400
         READ(37,*) ERAND(I)
         X=0.25*(I-1)+0.125
         CALL HFILL(294005,X,0.,ERAND(I))
      ENDDO
      EPILEUP=HRNDM1(294005)      

c pile-up file, individual random events
      OPEN(38,FILE=
     +'/home/pibeta/geant/databases/calo_800k_rand3.dat',STATUS='OLD')

cc beam ``potato'' x-y profile, done at ef2p@vesna:articles/beam/rms
      OPEN(77,FILE=
     +'/home/pibeta/geant/databases/beam_xy2.txt',STATUS='OLD')
      CALL HBOOK1(750001,'Beam X Profile',192,-3.2,3.2,0.)
      CALL HBOOK1(750002,'Beam Y Profile',192,-3.2,3.2,0.)
      DO I=1,192
        READ(77,*) BX,BY
        X=-3.2+0.0333333/2.+(I-1)*0.0333333
        Y=-3.2+0.0333333/2.+(I-1)*0.0333333
        CALL HFILL(750001,X,0.,BX)
        CALL HFILL(750002,Y,0.,BY)  
      ENDDO
      BX=HRNDM1(750001)      
      BY=HRNDM1(750002)

C-- open data file for radiative pion decay
      OPEN(29,FILE=
     +'/home/pibeta/geant/production1/pienug0.dat',STATUS='NEW')

C--   Nearest Neighbors File
       OPEN(UNIT=25,FILE='/home/pibeta/geant/electronics/neighbors.dat',
     + STATUS='OLD')

      DO J=1,240
         READ(25,*) (NN240(I,J),I=1,7)
      ENDDO

      CLOSE(25)

      DO I=1,240
        READ(21,*) GAIN_CSI_G(I)
c        READ(21,*) x,z
c        READ(22,*) y,z
c        IF(Y.GT.0.) THEN
c          GAIN_CSI_G(I)=X/Y
c        ELSE
c          GAIN_CSI_G(I)=1.
c        ENDIF
      ENDDO
*
*             Define user keys
*
*             Year-specific CsI crystal set-up
*
      CALL FFKEY('YEAR',    IYEAR,  1, 'INTEGER')
*
*             Hadronic interaction only
*
      CALL FFKEY('IGHAD',   IGHAD,  1, 'INTEGER')

*     Photonuclear reaction switch, GEISHA/FLUKA switch

      CALL FFKEY('IPHNUCL', IPHOTONUCLEAR, 1, 'INTEGER')
      CALL FFKEY('GHEISHA', IGHEISHA,      1, 'INTEGER')
*
*             Ouput format
*
      CALL FFKEY('FILE',    IFILE,   1, 'INTEGER')
      CALL FFKEY('FORMAT',  IFORMAT, 1, 'INTEGER')
*
*             Luxary RANDOM Number Generator Parameters
*
      CALL FFKEY('RLENGTH', ILEN,   1, 'INTEGER')
      CALL FFKEY('RLUXARY', ILUX,   1, 'INTEGER')
      CALL FFKEY('RSTART' , ISTART, 1, 'INTEGER')
      CALL FFKEY('SEQ',     ISEQ,   1, 'INTEGER')
      CALL FFKEY('SED1',    ISEED1, 1, 'INTEGER')
      CALL FFKEY('SED2',    ISEED2, 1, 'INTEGER')
*
*             Geometry flags
*
      CALL FFKEY('GDEGR',   IGDEGR,  1, 'INTEGER')
      CALL FFKEY('GTGT',    IGTGT,   1, 'INTEGER')
      CALL FFKEY('GMWPC',   IGMWPC,  1, 'INTEGER')
      CALL FFKEY('GPV',     IGPV,    1, 'INTEGER')
      CALL FFKEY('GCALO',   IGCALO,  1, 'INTEGER')
      CALL FFKEY('GCOSM',   IGCOSM,  1, 'INTEGER')
      CALL FFKEY('GPMT',    IPMT,    1, 'INTEGER')
      CALL FFKEY('GKUGEL',  KUGEL,   1, 'INTEGER')

      CALL FFKEY('RCALO',  RCALO, 1, 'REAL')   ! CALO Radius scaling
*
*             Event generator parameter
*
      CALL FFKEY('COSMIC',  WCOSMIC,        2, 'REAL')
      CALL FFKEY('GAMMA',   WGAMMA,         2, 'REAL')
      CALL FFKEY('POSITRON',WPOSITRON,      2, 'REAL')
      CALL FFKEY('PISTOP',  WPISTOP,        2, 'REAL')
      CALL FFKEY('PIMUNU',  WPI_MUNU,       2, 'REAL')
      CALL FFKEY('PIGMUNU', WPI_MUNUG,      2, 'REAL')
      CALL FFKEY('PIENU',   WPI_ENU,        2, 'REAL')
      CALL FFKEY('PIEGNU',  WPI_ENUG,       2, 'REAL')
      CALL FFKEY('PI3ENU',  WPI_3ENU,       2, 'REAL')
      CALL FFKEY('PIE3NU',  WPI_E3NU,       2, 'REAL')
      CALL FFKEY('PIBETA',  WPIBETA,        2, 'REAL')
      CALL FFKEY('PI2EMUNU',WPI_MU2ENU,     2, 'REAL')
      CALL FFKEY('MICHEL',  WMICHEL,        2, 'REAL')
      CALL FFKEY('MUG2NUE', WMU_E2NUG,      2, 'REAL')
      CALL FFKEY('MU2NU3E', WMU_3E2NU,      2, 'REAL')
      CALL FFKEY('MU3E',    WMU_3E,         2, 'REAL')
      CALL FFKEY('MUGE',    WMU_GE,         2, 'REAL')
      CALL FFKEY('MUE2G',   WMU_E2G,        2, 'REAL')
      CALL FFKEY('MUEGG',   WMUE_GG,        2, 'REAL')
      CALL FFKEY('NG',      WPIMP_NG,       2, 'REAL')
      CALL FFKEY('NGG',     WPIMP_NGG,      2, 'REAL')
      CALL FFKEY('PIZN',    WPIMP_PI0N,     2, 'REAL')
      CALL FFKEY('PZP',     WPIPP_PIPPI0P,  2, 'REAL')
      CALL FFKEY('PPN',     WPIPP_PIPPIPN,  2, 'REAL')
      CALL FFKEY('ZZN',     WPIMP_PI0PI0N,  2, 'REAL')
      CALL FFKEY('MZP',     WPIMP_PIMPI0P,  2, 'REAL')
      CALL FFKEY('MPN',     WPIMP_PIMPIPN,  2, 'REAL')

      CALL FFKEY('PLANAR',    IPLANAR,   1, 'INTEGER')
      CALL FFKEY('TGAMMA',    EGAMMA,    2, 'REAL')
      CALL FFKEY('TPOSITRON', EPOSITRON, 2, 'REAL')
      CALL FFKEY('TPION',     TINC,      2, 'REAL')
      CALL FFKEY('ZXCOSMIC',  ZXCOSMIC,  2, 'REAL')
*
*              Event GENERATOR Parameters
*
      CALL FFKEY('HISTO', IHISTO,   1, 'INTEGER')
      CALL FFKEY('MATRIX',IMATRIX, 30, 'INTEGER')
      CALL FFKEY('HCALL', IHCALL,  30, 'INTEGER')
*
*              Beam Parameters PINC,DPINC,DX,DY,DZ,DPX,DPY,DPZ
*
      CALL FFKEY('PBEAM',  BEAM,    8, 'REAL')
      CALL FFKEY('ZBEAM',  ZBEAM,   1, 'REAL')
      CALL FFKEY('DBEAM',  DIVBEAM, 2, 'REAL')
      CALL FFKEY('CBEAM',  CONBEAM, 2, 'REAL')
      CALL FFKEY('FBEAM',  FBEAM,   1, 'REAL')
*
*     CsI crystal and electronics temperature coefficients
*
      CALL FFKEY('CTEMP',  CTEMP,   2, 'REAL')
*
*     Axial and transverse oprical uniformity, number of photoelectrons/MeV
*
      CALL FFKEY('UNIFORMITY',     UNIFORMITY,   2, 'REAL')
      CALL FFKEY('NPHOTOEL',    PHOTOELECTRON,   2, 'REAL')
*
*     CsI ADC energy scale   
* 
      CALL FFKEY('ECSI',     ECSI,   1, 'REAL')

*              TDC, lower and upper level threshold in MeV

      CALL FFKEY('THRESHOLD',THRESHOLD,3, 'REAL')
*
*              ADC width in ns

      CALL FFKEY('WADC',WADC,1, 'REAL')
*
*     Method of energy averaging in CsI calorimeter
*
      CALL FFKEY('EMETHOD', METHOD, 1, 'INTEGER')
*
*     MWPC Efficiencies
*
      CALL FFKEY('EMWPC', EMWPC, 2, 'REAL')
*
*     Weighting method for clump
*
      CALL FFKEY('WEIGHT', IWEIGHT, 1, 'INTEGER')
      CALL FFKEY('ALPHA', ALPHA, 1, 'REAL')
      CALL FFKEY('A0', A0, 1, 'REAL')
 
*
*     Switches to activate different code
*
*     VADCTDC: Version of ADC/TDC simulation
*
      CALL FFKEY('VADCTDC', IADCTDC, 1, 'INTEGER')
*
*     COINCIDENCES: Enables/Disables Coincidence Code 1/0
*
      CALL FFKEY('COINCIDENCES', ICOINCID, 1, 'INTEGER')
*
*     CALO GEOMETRY parameters
*
      CALL FFKEY('GCSI',ON_MAT(1),1, 'INTEGER')
      CALL FFKEY('GTEFLON',ON_MAT(2),1, 'INTEGER')
      CALL FFKEY('GMYLAR',ON_MAT(3),1, 'INTEGER')
      CALL FFKEY('GBKPAPER',ON_MAT(4),1, 'INTEGER')
      CALL FFKEY('GDUMMY',ON_MAT(5),1, 'INTEGER')
*
*             Read data cards
*
      CALL GFFGO
#ifdef DEBUG
*WL debug -- make sure input data are right while leaving
*   the warning messages unattended
      PRINT *, "YEAR = ", IYEAR
      PRINT *, "IGHAD= ",  IGHAD
      PRINT *, "IPHNUCL= ", IPHOTONUCLEAR
      PRINT *, "GHEISHA= ", IGHEISHA
      PRINT *, "FILE= ", IFILE
      PRINT *, "FORMAT= ", IFORMAT
      PRINT *, "RLENGTH= ", ILEN
      PRINT *, "RLUXARY= ", ILUX
      PRINT *, "RSTART= ", ISTART
      PRINT *, "SEQ= ", ISEQ
      PRINT *, "SED1= ", ISEED1
      PRINT *, "SED2= ", ISEED2
      PRINT *, "GDEGR= ", IGDEGR
      PRINT *, "GTGT= ", IGTGT
      PRINT *, "GMWPC= ", IGMWPC
      PRINT *, "GPV= ", IGPV
      PRINT *, "GCALO= ", IGCALO
      PRINT *, "GCOSM= ", IGCOSM
      PRINT *, "GPMT= ", IPMT
      PRINT *, "GKUGEL ", KUGEL
      PAUSE
      PRINT *, "--------------------------------"
      PRINT *, "RCALO ", RCALO
      PRINT *, "COSMIC ", WCOSMIC
      PRINT *, "GAMMA ", WGAMMA
      PRINT *, "POSITRON ", WPOSITRON
      PRINT *, "PISTOP ", WPISTOP
      PRINT *, "PIMUNU ", WPI_MUNU
      PRINT *, "PIGMUNU ", WPI_MUNUG
      PRINT *, "PIENU ", WPI_ENU
      PRINT *, "PIEGNU ",WPI_ENUG
      PRINT *, "PI3ENU ", WPI_3ENU
      PRINT *, "PIE3NU ", WPI_E3NU
      PRINT *, "PIBETA ", WPIBETA
      PRINT *, "PI2EMUNU ", WPI_MU2ENU
      PRINT *, "MICHEL ", WMICHEL
      PRINT *, "MUG2NUE ", WMU_E2NUG
      PRINT *, "MU2NU3E ", WMU_3E2NU
      PRINT *, "MU3E ", WMU_3E
      PRINT *, "MUGE ", WMU_GE
      PRINT *, "MUE2G ", WMU_E2G
      PRINT *, "MUEGG ", WMUE_GG
      PRINT *, "NG ", WPIMP_NG
      PRINT *, "NGG ", WPIMP_NGG
      PRINT *, "PIZN ", WPIMP_PI0N
      PRINT *, "PZP ", WPIPP_PIPPI0P
      PRINT *, "PPN ", WPIPP_PIPPIPN
      PRINT *, "ZZN ", WPIMP_PI0PI0N
      PRINT *, "MZP ", WPIMP_PIMPI0P
      PRINT *, "MPN ", WPIMP_PIMPIPN
      PAUSE
      PRINT *, "----------------------"
      PRINT *, "PLANAR ", IPLANAR
      PRINT *, "TGAMMA ", EGAMMA
      PRINT *, "TPOSITRON ", EPOSITRON
      PRINT *, "TPION ", TINC
      PRINT *, "ZXCOSMIC " , ZXCOSMIC
      PRINT *, "----EVENT GENERATOR PARAMETERS-----"
      PRINT *, "HISTO ", IHISTO
      PRINT *, "MATRIX ", IMATRIX
      PRINT *, "HCALL ", IHCALL
      PRINT *, "PBEAM ", BEAM
      PRINT *, "ZBEAM ", ZBEAM
      PRINT *, "DBEAM ", DIVBEAM
      PRINT *, "CBEAM ", CONBEAM
      PRINT *, "FBEAM ", FBEAM
      PRINT *, "CTEMP ", CTEMP
      PRINT *, "UNIFORMITY ", UNIFORMITY
      PRINT *, "NPHOTOEL ", PHOTOELECTRON
      PRINT *, "ECSI ", ECSI
      PRINT *, "THRESHOLD ", THRESHOLD
      PRINT *, "WADC ", WADC
      PRINT *, "EMETHOD ", METHOD
      PRINT *, "EMWPC ", EMWPC
      PRINT *, "VADCTDC ", IADCTDC
      PRINT *, "COINCIDENCES ", ICOINCID
      PRINT *, "GCSI ", ON_MAT(1)
      PRINT *, "GTEFLON ", ON_MAT(2)
      PRINT *, "GMYLAR ", ON_MAT(3)
      PRINT *, "GBKPAPER ", ON_MAT(4)
      PRINT *, "GDUMMY ", ON_MAT(5)

      print *, "weight ", IWEIGHT
      PRINT *, "ALPHA ", ALPHA
      PRINT *, "A0 ", A0
      PAUSE
*WL END OF DEBUG CODE
#endif
 
*
      IF (IGHEISHA.EQ.1) THEN
        PRINT *, '**** GHEISHA HADRONIC PACKAGE ****'  
        PRINT *, ' '
      ELSEIF (IGHEISHA.EQ.2) THEN
        PRINT *, '**** FLUKA HADRONIC PACKAGE ****'  
        PRINT *, ' '
      ELSE
        PRINT *, '**** NO HADRONIC PACKAGE DEFINED ****'  
        PRINT *, ' '
        PAUSE
      ENDIF
*             Set seeds for number generator if requested
*
      IF(ISEED1.EQ.0) THEN
        CALL GRNDMQ(IACTSEED1,IACTSEED2,ISEQ,'Q')
        CALL GRNDMQ(IACTSEED1,IACTSEED2,ISEQ,'S')
      ELSEIF(ISEED1.EQ.-1) THEN
        CONTINUE
      ELSE
        CALL GRNDMQ(ISEED1,ISEED2,ISEQ,'S')
      ENDIF

*     Initialize PIBETA CALORIMETER parameters
*      
      CALL CALO_FILL
*
*             Set seeds for LUXARY number generator
*
      CALL RLUXGO(ILUX,ISTART,0,0)

*   
*             Initialize GEANT/ZEBRA data structures    
*   
      CALL GZINIT   
*   
*             Initialize graphics package   
*
      IF(INTER.GT.0) THEN  
        CALL GDINIT
      ENDIF   
*
*   
*     Variables zeroed at the start of the NEW RUN
*
      CALL VZERO (CSITHT,240)
      CALL VZERO (CSIPHI,240)
      CALL VZERO (CSIANG,240)
      CALL VZERO (WEIGTHMAX,50)
      CALL VZERO (G_CSI_G,240)
*   
*             Geometry and materials description.   
*   
      CALL GEPIBETA
*   
*             Particle table definition and energy loss initialization. 
*   
      CALL GPART    
      CALL GPHYSI   
*
*             Book histograms and Ntples
*
      CALL UHINIT    

*      CALL UNIF_TABLE
c
c      DO 88 I=-8,8
c        DO 88 J=-8,8
c          DO 88 K=1,24
c 88          WRITE(99,*) I,J,K,UNIF_VAL(I,J,K)

      END   

      include 'electronics/unif_table.f'
      include 'databases/calo_fill.f'





