************************************************************************    
*
*       geom.f
*
*       Definition of the PI0 Spectrometer detector geometry
*
*       History
*       -------
*       16DEC91 KAA created
*       15SEPT97 added the elements of the PI0 spectrometer  
*       
************************************************************************    
*
      SUBROUTINE GEPIBETA
*   
      IMPLICIT NONE
      INCLUDE 'common.inc'
*
*-----------------------------------------------------------------------
*
      INTEGER I,J,JJ,K,L,ISTATUS,IVOLU,ID,IV
      REAL R0,ZH,ZV,ZC1J,ZC2J,ZC3J,ZS1J,ZS2J,ZS3J,ZBJ
      REAL          ZC1K,ZC2K,ZC3K,ZS1K,ZS2K,ZS3K,ZBK
      INTEGER NJ,NK,IB,JB
      REAL XB,YB
      REAL ZKC
*
*-----------------------------------------------------------------------
*
*       Parameter for materials
*
      REAL ZLF5(6),ALF5(6),WLF5(6) ! Lead Glass LF5, NIM 180 (1981) 445
      DATA ZLF5/82.00,19.00,14.00,11.00,8.00,33.00/
      DATA ALF5/207.19,39.102,28.088,22.99,15.999,74.922/
      DATA WLF5/0.65994,0.00799,0.126676,0.0040073,0.199281,0.00200485/

      REAL ZSF3(5),ASF3(5),WSF3(5) ! Lead Glass SF3, NIM A275 (1989) 49
      DATA ZSF3/10.00,45.00,10.00,15.333,18.00/
      DATA ASF3/20.028,111.600,20.660,31.399,39.568/
      DATA WSF3/0.3183,0.6397,0.0150,0.0250,0.002/

      REAL ZF2(6),AF2(6),WF2(6) ! Lead Glass F2, NIM A275 (1989) 59
      DATA ZF2/82.00,8.00,14.00,11.00,19.00,58.00/
      DATA AF2/207.19,15.9994,28.0855,22.9898,39.0983,140.115/
      DATA WF2/0.418,0.297,0.215,0.037,0.033,0.0035/

      REAL ZSF5(4),ASF5(4),WSF5(4) ! Lead Glass SF5, NIM A332 (1993) 57
      DATA ZSF5/45.00,10.00,15.333,10.00/
      DATA ASF5/111.600,20.028,31.399,20.660/
      DATA WSF5/0.55,0.38,0.05,0.01/

      REAL APYR(4),ZPYR(4),WPYR(4)    ! Pyrex glass
C--   Standard shilding blocks from Phys .Rev.D, 50 (1994) 1241-1242
      REAL ACON(6),ZCON(6),WCON(6)  
      REAL Z1(2),Z2(2),Z3(3)
      REAL A1(2),A2(2),A3(3)
      REAL WMAT1(2),WMAT2(2),WMAT3(3)
      REAL DENS1,DENS2,DENS3
      INTEGER NLMAT1,NLMAT2,NLMAT3
*
      REAL AMYL(3),ZMYL(3),WMYL(3),DMYL
      REAL AGAS(2),ZGAS(2),WGAS(2),DGAS
      INTEGER NMYL,NGAS
*
      REAL WCH2(2)
*
      REAL PMAM(3),PLEP(3),CAVE(3)
      REAL PHAR(3),PVET(3),PBLO(3),PCRA(3),PCON(3)
      REAL PCO1(3),PCO2(3),PCO3(3)
      REAL PSC1(3), PSC2(3),PSC3(3)
      REAL PTU0(3),PTU1(3)
      DATA PTU0/0.0,15.850,212.5/
      DATA PTU1/15.850,16.0,212.5/

      DATA PHAR/20.,32.,0.4047/
      DATA PVET/20.,32.,0.15/
      DATA PBLO/7.5,7.5,30./
      DATA PCRA/22.5,37.5,300./
      DATA PCON/20.,32.,1.2/
      DATA PCO1,PCO2,PCO3
     +     /12.69,21.14,1.2,15.13,25.22,1.2,17.51,29.19,1.2/
      DATA PSC1,PSC2,PSC3
     +     /12.69,21.14,0.15,15.13,25.22,0.15,17.51,29.19,0.15/

      DATA APYR,ZPYR,WPYR/28.09,10.82,23.00,16.00,
     +                    14.00,5.00,11.00,8.00,
     +                    0.385,0.039,0.038,0.538/
      DATA ACON,ZCON,WCON/16.00,28.09,40.08,22.99,55.85,26.98,
     +                    8.,14.,20.,11.,26.,13.,
     +                    0.52,0.325,0.06,0.015,0.04,0.04/
      DATA Z1,Z2,A1,A2/6.0,1.0,55.0,53.0,12.01115,1.00797,
     1                 132.905,126.9044/ 
      DATA WMAT1,WMAT2/0.91549,0.08451,0.511548,0.488452/
*
      DATA DENS1,DENS3,NLMAT1,NLMAT3/1.049,1.181,2,3/
      DATA DENS2,NLMAT2/4.526,2/
      DATA WMAT3/0.59985,0.08054,0.31961/
      DATA Z3/6.0,1.0,8.0/
      DATA A3/12.01115,1.00797,15.9994/
      DATA AMYL,ZMYL,WMYL,DMYL/12.01,1.01,16.,6.,1.,8.,5.,4.,2.,1.39/
      DATA NMYL/-3/
      DATA WCH2/1.0,2.0/
      DATA AGAS,ZGAS,WGAS/40.0,58.0,18.0,34.0,0.6765,0.3235/
      DATA DGAS,NGAS/1.85E-03,2/
*
      CHARACTER*4 NAMESH(2)
      INTEGER NBITSH(2)
      REAL ORIG(2),FACT(2)
      DATA NAMESH,NBITSH,ORIG,FACT/'EDEP','TDEP',32,32,0.,0.,1.,1./
      DATA NUMBV /1,19*0/

      REAL SIZE(3)
      DATA SIZE/3.9,3.9,0.3885/

      REAL AWA(2),ZWA(2),DWA,WWA(2) ! water
      INTEGER NLWA
      DATA AWA,ZWA,DWA,NLWA,WWA/1.,16.,1.,8.,1.0,-2,2,1/
*
*=======================================================================
*
*     Define materials
*
      CALL GSMATE( 1,'AIR$',14.610,7.300,1.205e-03,3.04e+04,1.e+16,0,0)
      CALL GSMIXT( 2,'PLAST SC$',A1,Z1,DENS1,NLMAT1,WMAT1)
      CALL GSMIXT( 3,'CsI$',A2,Z2,DENS2,NLMAT2,WMAT2)
      CALL GSMIXT( 4,'ACRYLIC$',A3,Z3,DENS3,NLMAT3,WMAT3) 
      CALL GSMATE( 5,'CARBON$',12.010,6.0,2.265,18.8,0.0,0,0)
      CALL GSMIXT( 6,'MYLAR$',AMYL,ZMYL,DMYL,NMYL,WMYL)
      CALL GSMIXT( 7,'MAGIC GAS$',AGAS,ZGAS,DGAS,NGAS,WGAS)
      CALL GSMATE( 8,'TUNGSTEN$',183.850,74.0,19.3,0.35,0.0,0,0)
      CALL GSMATE( 9,'LEAD$',207.190,82.0,11.35,0.59,0.0,0,0)
      CALL GSMIXT(10,'CH2$',A1,Z1,0.935,-2,WCH2)
      CALL GSMATE(11,'VACUUM$',1E-16,1E-16,1E-16,1E16,0.0,0,0)
      CALL GSMATE(12,'IRON$',55.850,26.0,7.870,1.760,0.0,0,0)
      CALL GSMIXT(13,'PYREX$',APYR,ZPYR,2.23,4,WPYR)
      CALL GSMIXT(14,'SHIELD$',ACON,ZCON,2.50,6,WCON)
      CALL GSMIXT(15,'LEAD GLASS LF5$',ALF5,ZLF5,3.23,6,WLF5)
      CALL GSMIXT(16,'LEAD GLASS SF3$',ASF3,ZSF3,4.64,5,WSF3)
      CALL GSMIXT(17,'LEAD GLASS F2$',AF2,ZF2,4.00,6,WF2)
      CALL GSMIXT(18,'LEAD GLASS SF5$',ASF5,ZSF5,4.08,4,WSF5)
      CALL GSMATE(19,'LH2$',1.010,1.,0.071,865.000,0.0,0,0)
      CALL GSMIXT(20,'H2O$',AWA,ZWA,DWA,NLWA,WWA)
*
*=======================================================================
*              
*     Define media
*
      EPSIL=1.0e-04
*
      CALL GSTMED( 1,'VACUUM$',11,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 2,'AIR$',1,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 3,'PLASTIC SCINT$',2,1,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 4,'ACRYLIC$',4,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 5,'WAVE L. SHI$',2,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 6,'MYLAR$',6,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 7,'CARBON FIBER$',5,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 8,'MAGIC GAS$',7,1,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 9,'CH2$',10,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 10,'CsI$',3,1,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
* 
      CALL GSTMED( 11,'TUNGSTEN$',8,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 12,'IRON$',12,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 13,'LEAD$',9,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 14,'PYREX$',13,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 15,'SHIELD$',14,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 16,'LEAD GLASS LF5$',15,1,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )
*    
      CALL GSTMED( 17,'LEAD GLASS SF3$',16,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 18,'LEAD GLASS F2$',17,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
*
      CALL GSTMED( 19,'LEAD GLASS SF5$',18,0,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
* 
      CALL GSTMED( 20,'LH2$',19,0,0,
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
      CALL GSTMED( 21,'PLASTIC SCINT$',2,1,0,  
     1            0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )    
      CALL GSTMED( 22,'H2O$',20,1,0,
     1     0.0,TMAXFD,STEMAX,DEEMAX,EPSIL,STMIN,0,0 )
            
*=======================================================================
*
*       Defines experiment volume ('MAMA')
*   
      DATA PMAM,PLEP/3*1000.,3*800./
*
      CALL GSVOLU ('MAMA','BOX ',1,PMAM,3,ISTATUS)    ! Universe
      CALL GSVOLU ('CLEP','BOX ',22,PLEP,3,ISTATUS)   ! Fe56 Air 

      CALL GSROTM(1,90.,0.,0.,0.,90.,270.)    ! to NEG Y
      CALL GSROTM(2,90.,0.,180.,0.,90.,90.)   ! to pos Y
      CALL GSROTM(3,90.,315.,90.,45.,0.,0.)   ! 45 deg z ROT

      CALL GSPOS ('CLEP',1,'MAMA',0.0,0.0,0.0,0,'ONLY')
      CALL GSATT ('CLEP','SEEN',0) 
*
*-----------------------------------------------------------------------
*
*     Define and position Stainless Steel Cylinder
*
      CALL GSVOLU('TUB0','TUBE', 1,PTU0,3,ISTATUS)
      CALL GSVOLU('TUB1','TUBE',12,PTU1,3,ISTATUS)

c      CALL GSPOS ('TUB0',1,'CLEP',0.,0.,0.,0,'ONLY')
c      CALL GSPOS ('TUB1',1,'CLEP',0.,0.,0.,0,'ONLY')      

*       Close the geometry package
*
      CALL GGCLOS   
*
*       Hide containers
*
      call gsatt('MAMA','SEEN',0)
*
*      Print information of geometry 
*
*      CALL GPVOLU(0)
*      CALL GPMATE(0)
*      CALL GPTMED(0)
*   
      END   

