************************************************************************    
*
*       track.f
*
*       Do the energy summing after each tracking step
*
*       History
*       -------
*       16DEC91 KAA created
*       13JUN95 EF  Added MWPC hits
*
************************************************************************    
*
      SUBROUTINE GUTREV 
*   
************************************************************************    
*
*       User routine to control tracking of one event
*       Called by GRUN
*
*       History
*       -------
*       16DEC91 KAA created
*       20OCT95 SR  added zeroing of tracking information
*
************************************************************************    
*   
      IMPLICIT NONE
      INCLUDE 'common.inc'
*
*-----------------------------------------------------------------------
*
*     Zeroing all common block information for tracking
*
*
      NGPHOTS=0
      EDEPTOT=0.
      EDEPCAL=0.
      EDEPCAL1=0.
      EDEPCAL2=0.
      EDEP(500)=0.
      MAXNST = 100000

      CALL GTREVE   
*   
      END   
*
*=======================================================================
*
*
      SUBROUTINE GUPHAD 

      COMMON/HADR_PAR/IGHEISHA
      INTEGER IGHEISHA
*  
************************************************************************
*
*       GEANT3 user routine called at each step
*       to evaluate the next hadronic interaction point
*
*       (TATINA) uses R.Barlow cross-sections tables
*       (GHEISHA)uses the GHEISHA cross-sections
*
************************************************************************
*  
      IF (IGHEISHA.EQ.1) THEN
        CALL GPGHEI   
      ELSEIF (IGHEISHA.EQ.2) THEN
        CALL FLDIST
      ELSE
        PAUSE
      ENDIF
*   
      END   
*
*=======================================================================
*
*
      SUBROUTINE GUHADR 

      COMMON/HADR_PAR/IGHEISHA
      INTEGER IGHEISHA
*  
************************************************************************
*
*       GEANT3 user routine called when a hadronic process
*       has been selected in the current step.
*
************************************************************************
*  
      IF (IGHEISHA.EQ.1) THEN
        CALL GHEISH   
      ELSEIF (IGHEISHA.EQ.2) THEN
        CALL FLUFIN
      ELSE
        PAUSE
      ENDIF
*   
      END   
*
*=======================================================================
*
*
      SUBROUTINE GUSTEP 
*   
************************************************************************    
*
*       User routine called at the end of each tracking step
*       MEC   is the mechanism origin of the step
*       INWVOL is different from 0 when the track has reached
*       a volume boundary
*       ISTOP is different from 0 if the track has stopped
*
************************************************************************    
*   
*   
      IMPLICIT NONE
      INCLUDE 'common.inc'
*
*-----------------------------------------------------------------------
*
      INTEGER I,IHIT
      REAL HITS(2)
*
*-----------------------------------------------------------------------
*
      IF(NUMED.EQ.3.AND.DESTEP.GT.0.) THEN
         IF (VECT(2).GT.0.) EDEPTOT=EDEPTOT+1000.*DESTEP
         IF (VECT(2).LT.0.) EDEPCAL=EDEPCAL+1000.*DESTEP
      ENDIF

      IF(NUMED.EQ.16.AND.DESTEP.GT.0.) THEN
         IF (VECT(2).GT.0.) EDEPCAL1=EDEPCAL1+1000.*DESTEP
         IF (VECT(2).LT.0.) EDEPCAL2=EDEPCAL2+1000.*DESTEP
      ENDIF

      IF(NUMED.EQ.21.AND.DESTEP.GT.0.) THEN
         EDEP(500)=EDEP(500)+1000.*DESTEP
      ENDIF

*       Put secondary track on the stack (standard GEANT procedure)
*
      IF(NGKINE.GT.0) THEN  
        DO 5 I=1,NGKINE 
          IF(GKIN(5,I).NE.4) CALL GSKING(I)
   5    CONTINUE    
      ENDIF 
*
*       Debug/plot event  
*   
      IF(INTER.GT.0) THEN
        CALL GDCXYZ  
      ENDIF
*
      END   
*
*       Include ADC/TDC code
*
      INCLUDE 'adc1.f'
      INCLUDE 'tdc1.f'
      INCLUDE 'adc2.f'
      INCLUDE 'tdc2.f'

