************************************************************************    
*
*       track.f
*
*       Do the energy summing after each tracking step
*
*       History
*       -------
*       16DEC91 KAA created
*       13JUN95 EF  Added MWPC hits
*
************************************************************************    
*
      SUBROUTINE GUTREV 
*   
************************************************************************    
*
*       User routine to control tracking of one event
*       Called by GRUN
*
*       History   
*       -------
*       16DEC91 KAA created
*       20OCT95 SR  added zeroing of tracking information
*
************************************************************************    
*   
      IMPLICIT NONE
      INCLUDE 'common.inc'
*WL
      INCLUDE 'dtor.inc'

*
*-----------------------------------------------------------------------
*
*     Zeroing all common block information for tracking
*
      CALL VZERO(EDEP, NSDET)
      CALL VZERO(TDEP, NSDET)
*WL use VSUB instead of VZERO to set REAL array to be zero
*   refer to documents at http://consult.cern.ch/shortwrups
*      CALL VZERO(ITDEP,NSDET)
      CALL VSUB(ITDEP, ITDEP, ITDEP, NSDET)
      CALL VZERO(RPMT, NSDET)

      EDEPCAL  =0.      ! Energy deposited in CsI Calorimeter
      EDEPTOT  =0.      ! Total Energy deposited everywhere
      EDEPCAL1 =0.      ! Energy Deposition of FIRST track in CALO
      EDEPCAL2 =0.      ! Energy Deposition of SECOND track in CALO
      EDEPCAL3 =0.      ! Energy Deposition of THIRD track in CALO
      EDEPNAI=  0.      ! Energy deposited in NaI Calorimeter
      EDEPNAIOUT= 0.    ! Energy deposited in outer NaI Crystals       

C--   MWPC Initialization
      CALL VZERO(WPC1,3*NCHPART)
      CALL VZERO(WPC2,3*NCHPART)
*WL use VSUB instead of VZERO to set REAL array to be zero
*   refer to documents at http://consult.cern.ch/shortwrups
*      CALL VZERO(IMWPC1,NCHPART)
*      CALL VZERO(IMWPC2,NCHPART)
      CALL VSUB(IMWPC1, IMWPC1, IMWPC1, NCHPART)
      CALL VSUB(IMWPC2, IMWPC2, IMWPC2, NCHPART)
      NMWPC1=0
      NMWPC2=0
      NEWP1=-1
      NEWP2=-1

      CALL VZERO(THISTO,240*NSDET)
*
      MAXNST = 100000

C--   Reset the tracking flags (neccesary in case of hadronic version)
      IEOTRI =0
      HADFLAG=0
      PI0FLAG=0
      GAMFLAG=0
      NEUFLAG=0
      RPHOT0=0.
      RPHOT2=0.

      CALL VZERO(COUNTER,50)

      CALL GTREVE   
*   
      END   
*
*=======================================================================
*
*
      SUBROUTINE GUPHAD 

      COMMON/HADR_PAR/IGHEISHA
      INTEGER IGHEISHA
*  
************************************************************************
*
*       GEANT3 user routine called at each step
*       to evaluate the next hadronic interaction point
*
*       (TATINA) uses R.Barlow cross-sections tables
*       (GHEISHA)uses the GHEISHA cross-sections
*
************************************************************************
*  
      IF (IGHEISHA.EQ.1) THEN
        CALL GPGHEI   
      ELSEIF (IGHEISHA.EQ.2) THEN
        CALL FLDIST
      ELSE
        PAUSE
      ENDIF
*   
      END   
*
*=======================================================================
*
*
      SUBROUTINE GUHADR 

      COMMON/HADR_PAR/IGHEISHA
      INTEGER IGHEISHA
*  
************************************************************************
*
*       GEANT3 user routine called when a hadronic process
*       has been selected in the current step.
*
************************************************************************
*  
      IF (IGHEISHA.EQ.1) THEN
        CALL GHEISH   
      ELSEIF (IGHEISHA.EQ.2) THEN
        CALL FLUFIN
      ELSE
        PAUSE
      ENDIF
*   
      END   
*
*=======================================================================
*
*
      SUBROUTINE GUSTEP 
*   
************************************************************************    
*
*       User routine called at the end of each tracking step
*       MEC   is the mechanism origin of the step
*       INWVOL is different from 0 when the track has reached
*       a volume boundary
*       ISTOP is different from 0 if the track has stopped
*
************************************************************************    
*   
*   
      IMPLICIT NONE
      INCLUDE 'common.inc'
*WL
      INCLUDE 'dtor.inc'
      INCLUDE 'geometry/cryscommon.inc'
*
*-----------------------------------------------------------------------
*
      integer position_write
      INTEGER I,IHIT
      REAL HITS(2),X
      REAL SHOWERPHI,SHOWERRHO
*
*-----------------------------------------------------------------------
*
*  Determine the identificantion number of the current crystal
*  for jason's calo
*
      IF (IGCALO.EQ.2) THEN
       CALL FIND_CRYSTAL
c       CALL CRYSTAL_IDENTIFICATION
      ENDIF
*
C--   Photonuclear Interactions
      IF (IPART.EQ.1.AND.IPHOTONUCLEAR.EQ.1) CALL gen_photonuclear

C--   Do we want to record just hadronic interactions?
      IF(IGHAD.EQ.1) CALL ABORT_NONHADR
*
************************************************************************
*
*       Multi Wire Proportional Chambers
*
************************************************************************
*
      CALL MWPC_TRACK
*
************************************************************************
*
*       ADC and TDC information
*
************************************************************************
*
      IF (IADCTDC.EQ.1) THEN
        CALL ADC1
        CALL TDC1
      ELSEIF (IADCTDC.EQ.2) THEN
        CALL ADC2
        CALL TDC2
      ENDIF
*
************************************************************************
*
*       Total energy depositions
*
************************************************************************
*
Ctmp
      IF (IDTYPE.GE.1.AND.IDTYPE.LE.220.AND.DESTEP.GT.0.
     +  AND.EDEPCAL.EQ.0.) THEN    
        RPHOT0=SQRT(VECT(1)**2+VECT(2)**2+VECT(3)**2)
      ENDIF
      IF (IDTYPE.GE.1.AND.IDTYPE.LE.220.AND.DESTEP.GT.0.
     +  AND.EDEPCAL.LT.2.) THEN    
        RPHOT2=SQRT(VECT(1)**2+VECT(2)**2+VECT(3)**2)
      ENDIF
Ctmp
      EDEPTOT=EDEPTOT+1000.*DESTEP
      IF (IDTYPE.GE.1.AND.IDTYPE.LE.220) EDEPCAL=EDEPCAL+1000.*DESTEP
C
C--   Energy in NaI Calorimeter (1997)
C
      IF(ISWIT(1).EQ.1997.AND.NUMED.EQ.16) EDEPNAI=EDEPNAI+1000.*DESTEP

C--   PIBETA reaction: first (second) PI0 gamma can be distinguished
C--   by IVERT (1 or 2) or ITRA (1 or 2) common variables

      IF (IDTYPE.GE.1.AND.IDTYPE.LE.240) THEN    ! CSI CALO P1,P2,P3 EDEP !
        IF (IVERT.EQ.1) EDEPCAL1=EDEPCAL1+1000.*DESTEP
        IF (IVERT.EQ.2) EDEPCAL2=EDEPCAL2+1000.*DESTEP
        IF (IVERT.EQ.3) EDEPCAL3=EDEPCAL3+1000.*DESTEP
      ENDIF
*      
*     CsI Shower Radial Profiles
      IF (IDTYPE.GE.1.AND.IDTYPE.LE.240.AND.DESTEP.GT.0.)THEN
       SHOWERPHI=(PART(1,1,NR)*VECT(1)+PART(2,1,NR)*VECT(2)+
     +            PART(3,1,NR)*VECT(3) )/( SQRT(PART(1,1,NR)**2+
     +            PART(2,1,NR)**2+PART(3,1,NR)**2)*SQRT(VECT(1)**2+
     +            VECT(2)**2+VECT(3)**2) )
       IF(ABS(SHOWERPHI).LE.1.) THEN
*WL ACOSD > ACOS
         SHOWERPHI=(1/dtor)*ACOS(SHOWERPHI)
       ELSEIF (SHOWERPHI.LT.-1.) THEN
         SHOWERPHI=180.
       ELSEIF (SHOWERPHI.GT.1.) THEN
         SHOWERPHI=0.
       ENDIF

       IF(SHOWERPHI.NE.90..AND.SHOWERPHI.NE.270.)THEN
*WL TAND > TAN
         SHOWERRHO=SQRT(VECT(1)**2+VECT(2)**2+VECT(3)**2)*
     +             TAN(dtor*SHOWERPHI)
       ELSE
         SHOWERRHO=1.E4
       ENDIF

*WL I hasn't been assigned any value before this, I temperarily 
*   set I to be 0
       I = 0
       CALL HFILL(701,SHOWERPHI,0.,EDEP(I)*WT*SQME)
       CALL HFILL(702,SHOWERPHI,0.,SHOWERRHO*WT*SQME)
*WL COSD > COS
       CALL HFILL(704,COS(dtor*SHOWERPHI),0.,EDEP(I)*WT*SQME)
       CALL HFILL(705,COS(dtor*SHOWERPHI),0.,SHOWERRHO*WT*SQME)

      ENDIF 

C     pi+ Beam z-STOPPING PROFILE
c      if(NR.EQ.4) write (99,*) ipart,gekin,idtype,vect(3),edep(idtype)
c      write (99,*) ipart,gekin,vect(3)
      IF(IDTYPE.GE.261.AND.IDTYPE.LE.269.AND.IPART.EQ.8.AND.
     +   GEKIN.LT.0.00002) THEN
       CALL HFILL(41009,VECT(3),0.,WT*SQME)
       X=IDTYPE-261.
       CALL HFILL(41010,X,0.,WT*SQME)
      ENDIF

c find pi->munu decay vertex
      IF(IPART.EQ.5.AND.GEKIN.LT.0.00002.
     +   AND.IDTYPE.GE.261.AND.IDTYPE.LE.269) THEN
         WRITE(55,3732) IDEVT,VECT(1),VECT(2),VECT(3),
     +   VERTEX(1),VERTEX(2),VERTEX(3)
      ENDIF
 3732 FORMAT (I8,6F14.4)
*
**************************************
*        temp. test code --EF
**************************************
*
c      IF (ISVOL.NE.0.AND.DESTEP.GT.0.) THEN
c        CALL GSCHIT(ISET,IDET,ITRA,NUMBV,HITS,1,IHIT)
c      ENDIF
*
*       Put secondary track on the stack (standard GEANT procedure)
*
      IF(NGKINE.GT.0) THEN  
        DO 5 I=1,NGKINE 
          IF(GKIN(5,I).NE.4) CALL GSKING(I)
C--   Secondary PI0
          IF(HADFLAG.EQ.1.AND.GKIN(5,I).EQ.7) PI0FLAG=1
   5    CONTINUE    
      ENDIF 
*
*       Debug/plot event  
*   
      IF(INTER.GT.0) THEN
        CALL GDCXYZ  
      ENDIF
*
      END   
*
*       Include ADC/TDC code in electronics/ directory
*
      INCLUDE 'electronics/adc1.f'
      INCLUDE 'electronics/tdc1.f'
      INCLUDE 'electronics/adc2.f'
      INCLUDE 'electronics/tdc2.f'
      INCLUDE 'electronics/mwpc.f'
      INCLUDE 'generators/abort_nonhadr.f'
      INCLUDE 'generators/gen_photonuclear.f'
      INCLUDE 'geometry/find_crystal.f'
c      INCLUDE 'geometry/crysid.f'







